@@ -1,7 +1,7 @@
 /*****************************************************************
  * drkonki - The KDE Crash Handler
  * 
- * $Id: krashconf.cpp,v 1.6 2000/05/07 10:49:09 bieker Exp $
+ * $Id: krashconf.cpp,v 1.9 2000/05/14 11:54:58 bieker Exp $
  *
  * Copyright (C) 2000 Hans Petter Bieker <bieker@kde.org>
  *****************************************************************/
@@ -10,6 +10,7 @@
 #include <kglobal.h>
 #include <kaboutdata.h>
 #include <kcmdlineargs.h>
+#include <klocale.h>
 
 #include "krashconf.h"
 
@@ -26,7 +27,6 @@ KrashConfig :: ~KrashConfig()
 QString KrashConfig :: debugger() const
 {
   return m_debugger;
-  return QString::fromLatin1("konsole -e gdb %appname %pid");
 }
 
 void KrashConfig :: readConfig()
@@ -35,8 +35,12 @@ void KrashConfig :: readConfig()
   m_signalnum = args->getOption( "signal" ).toInt();
   m_pid = args->getOption( "pid" ).toInt();
 
+  QCString programname = args->getOption("programname");
+  if (programname.isEmpty()) programname.setStr(I18N_NOOP("unknown"));
+  // leak some memory... Well. It's only done once anyway :-)
+  const char * progname = qstrdup(programname);
   m_aboutData = new KAboutData(args->getOption("appname"),
-		    args->getOption("programname"),
+		    progname,
 		    args->getOption("appversion"),
 		    0, 0, 0, 0,	0,
 		    args->getOption("bugaddress"));
