@@ -1,4 +1,4 @@
-#include <stream.h>
+#include <iostream>
 
 
 #include <kinstance.h>
