@@ -1,6 +1,6 @@
 /* vi: ts=8 sts=4 sw=4
  *
- * $Id: advanced.h,v 1.3 1999/11/13 17:53:58 jansen Exp $
+ * $Id: advanced.h,v 1.4 2000/06/06 21:40:55 wgreven Exp $
  *
  * This file is part of the KDE project, module kcmdisplay.
  * Copyright (C) 1999 Geert Jansen <g.t.jansen@stud.tue.nl>
@@ -21,6 +21,7 @@ class KGlobalBackgroundSettings;
 
 /**
  * The Desktop/Advanced tab in kcontrol.
+ * TODO: Merge with background settings.
  */
 class KAdvanced: public KCModule
 {
@@ -42,13 +43,11 @@ private slots:
     void slotLimitCache(bool);
     void slotCacheSize(int);
     void slotExportBackground(bool);
-    void slotDockPanel(bool);
 
 private:
     void apply();
 
     QCheckBox *m_pCBLimit, *m_pCBExport;
-    QCheckBox *m_pCBDock;
     QSpinBox *m_pCacheBox;
 
     KGlobalBackgroundSettings *m_pSettings;
