@@ -1,6 +1,6 @@
 /* vi: ts=8 sts=4 sw=4
  *
- * $Id: backgnd.cpp,v 1.105 2000/05/08 05:33:40 mcbride Exp $
+ * $Id: backgnd.cpp,v 1.108 2000/06/06 19:27:10 faure Exp $
  *
  * This file is part of the KDE project, module kcmdisplay.
  * Copyright (C) 1999 Geert Jansen <g.t.jansen@stud.tue.nl>
@@ -41,6 +41,7 @@
 #include <kglobal.h>
 #include <kstddirs.h>
 #include <kiconloader.h>
+#include <kdebug.h>
 #include <kcolorbtn.h>
 #include <klocale.h>
 #include <kmessagebox.h>
@@ -110,7 +111,7 @@ KBackground::KBackground(QWidget *parent, const char *name)
     top->setColStretch(1, 2);
 
     // A nice button size. Translators can adapt this
-    QPushButton *pbut = new QPushButton(i18n("abcdefgh"), this);
+    QPushButton *pbut = new QPushButton(i18n("some nonsense string as example string", "abcdefgh"), this);
     QSize bsize = pbut->sizeHint();
     delete pbut;
 
@@ -345,7 +346,7 @@ void KBackground::init()
 	m_pDeskList->insertItem(m_pGlobals->deskName(i));
 
     // Background modes: make sure these match with kdesktop/bgrender.cc !!
-    m_pBackgroundBox->insertItem(i18n("Flat"));
+    m_pBackgroundBox->insertItem(i18n("Simple Color", "Flat"));
     m_pBackgroundBox->insertItem(i18n("Pattern"));
     m_pBackgroundBox->insertItem(i18n("Background Program"));
     m_pBackgroundBox->insertItem(i18n("Horizontal Gradient"));
@@ -507,7 +508,7 @@ void KBackground::load()
 
 void KBackground::save()
 {
-    qDebug("Saving stuff...");
+    kdDebug() << "Saving stuff..." << endl;
     m_pGlobals->writeSettings();
     for (int i=0; i<m_Max; i++)
 	m_Renderer[i]->writeSettings();
@@ -893,7 +894,7 @@ void KBackground::slotSetupMulti()
 
 void KBackground::slotPreviewDone(int desk_done)
 {
-    qDebug("Preview for desktop %d done", desk_done);
+    kdDebug() << "Preview for desktop " << desk_done << " done" << endl;
 
     int desk = m_Desk;
     if (m_pGlobals->commonBackground())
