@@ -1,6 +1,6 @@
 /* vi: ts=8 sts=4 sw=4
  *
- * $Id: bgdialogs.cpp,v 1.7 2000/02/22 17:48:07 coolo Exp $
+ * $Id: bgdialogs.cpp,v 1.9 2000/06/06 19:27:10 faure Exp $
  *
  * This file is part of the KDE project, module kcmdisplay.
  * Copyright (C) 1999 Geert Jansen <g.t.jansen@stud.tue.nl>
@@ -25,6 +25,7 @@
 #include <qdragobject.h>
 
 #include <kapp.h>
+#include <kdebug.h>
 #include <kglobal.h>
 #include <klocale.h>
 #include <kstddirs.h>
@@ -574,7 +575,7 @@ void KPatternSelectDialog::slotHelp()
 void KPatternSelectDialog::slotItemClicked(QListViewItem *item)
 {
     m_Current = item->text(1);
-    qDebug("current: %s", m_Current.latin1());
+    kdDebug() << "current: " << m_Current << endl;
 }
 
 
