@@ -12,6 +12,7 @@
 
 #include <qgroupbox.h>
 #include <qlabel.h>
+#include <qlineedit.h>
 #include <qpushbutton.h>
 #include <qslider.h>
 #include <qcombobox.h>
@@ -27,6 +28,7 @@
 #include <kmessagebox.h>
 #include <kcursor.h>
 #include <kglobal.h>
+#include <kglobalsettings.h>
 #include <kstddirs.h>
 #include <kipc.h>
 #include <kcolordlg.h>
@@ -207,11 +209,11 @@ KColorScheme::KColorScheme(QWidget *parent, const char *name)
        " of the current color scheme. Contrast does not affect all of the"
        " colors, only the edges of 3D objects."));
 
-    QLabel *label = new QLabel(sb, i18n("&Low"), group);
+    QLabel *label = new QLabel(sb, i18n("Low Contrast", "&Low"), group);
     groupLayout->addWidget(label);
     groupLayout->addWidget(sb, 10);
     label = new QLabel(group);
-    label->setText(i18n("High"));
+    label->setText(i18n("High Contrast", "High"));
     groupLayout->addWidget( label );
 
     load();
@@ -275,7 +277,7 @@ void KColorScheme::save()
     // Write some Qt root property.
     QByteArray properties;
     QDataStream d(properties, IO_WriteOnly);
-    d << createPalette() << KGlobal::generalFont();
+    d << createPalette() << KGlobalSettings::generalFont();
     Atom a = XInternAtom(qt_xdisplay(), "_QT_DESKTOP_PROPERTIES", false);
     XChangeProperty(qt_xdisplay(),  qt_xrootwin(), a, a, 8, PropModeReplace,
 		    (unsigned char*) properties.data(), properties.size());
