@@ -299,7 +299,7 @@ KScreenSaver::KScreenSaver(QWidget *parent, const char *name)
     mPrioritySlider->setEnabled(false);
 #endif
     
-    lbl = new QLabel(i18n("High"), group);
+    lbl = new QLabel(i18n("High Priority", "High"), group);
     hbox->addWidget(lbl);
     
 #ifndef HAVE_SETPRIORITY
@@ -380,7 +380,7 @@ void KScreenSaver::readSettings()
     mEnabled = config->readBoolEntry("Enabled", false);
     mLock = config->readBoolEntry("Lock", false);
     mTimeout = config->readNumEntry("Timeout", 300);
-    mPriority = config->readNumEntry("Priority", 0);
+    mPriority = config->readNumEntry("Priority", 19);
     mPasswordStars = config->readBoolEntry("PasswordAsStars", true);
     mSaver = config->readEntry("Saver");
 
