@@ -5,6 +5,7 @@
 #include <qgroupbox.h>
 #include <qlistbox.h>
 #include <qwhatsthis.h>
+#include <qlabel.h>
 
 #include <dcopclient.h>
 #include <krun.h>
@@ -20,6 +21,7 @@
 #include <kuserprofile.h>
 #include <kdesktopfile.h>
 #include <kopenwith.h>
+#include <kdebug.h>
 
 #include "typeslistitem.h"
 #include "newtypedlg.h"
@@ -27,6 +29,24 @@
 
 #include "filetypesview.h"
 
+class ServiceListItem : public QListBoxText 
+{
+public:
+	ServiceListItem( QString &desktopPath );
+
+	QString desktopPath;
+};
+
+ServiceListItem::ServiceListItem( QString &_desktopPath ) 
+	: QListBoxText(), desktopPath(_desktopPath)
+{
+    KService::Ptr pService = KService::serviceByDesktopPath( _desktopPath );
+
+	ASSERT(pService);
+
+	setText( pService->name() );
+}
+
 FileTypesView::FileTypesView(QWidget *p, const char *name)
   : KCModule(p, name)
 {
@@ -36,14 +56,29 @@ FileTypesView::FileTypesView(QWidget *p, const char *name)
   QHBoxLayout *topLayout = new QHBoxLayout(this, KDialog::marginHint(),
 					   KDialog::spacingHint());
 
-  QGridLayout *leftLayout = new QGridLayout(2, 2);
+  QGridLayout *leftLayout = new QGridLayout(3, 2);
   topLayout->addLayout(leftLayout, 2);
 
+  QLabel *patternFilterLBL = new QLabel( i18n("Find filename pattern"), this );
+  leftLayout->addWidget(patternFilterLBL, 0, 0);
+  
+  patternFilterLE = new QLineEdit(this);
+  leftLayout->addWidget(patternFilterLE, 0, 1);
+  
+  connect(patternFilterLE, SIGNAL(textChanged(const QString &)),
+	  this, SLOT(slotFilter(const QString &)));
+  
+  wtstr = i18n("Enter a part of a filename pattern. Only file types with a "
+	       "matching file pattern will appear in the list.");
+  
+  QWhatsThis::add( patternFilterLE, wtstr );
+  QWhatsThis::add( patternFilterLBL, wtstr );
+
   typesLV = new QListView(this);
   typesLV->setRootIsDecorated(true);
 
   typesLV->addColumn(i18n("Known Types"));
-  leftLayout->addMultiCellWidget(typesLV, 0, 0, 0, 1);
+  leftLayout->addMultiCellWidget(typesLV, 1, 1, 0, 1);
   connect(typesLV, SIGNAL(selectionChanged(QListViewItem *)),
           this, SLOT(updateDisplay(QListViewItem *)));
 
@@ -56,14 +91,14 @@ FileTypesView::FileTypesView(QWidget *p, const char *name)
   QPushButton *addTypeB = new QPushButton(i18n("&Add..."), this);
   connect(addTypeB, SIGNAL(clicked()),
           this, SLOT(addType()));
-  leftLayout->addWidget(addTypeB, 1, 0);
+  leftLayout->addWidget(addTypeB, 2, 0);
 
   QWhatsThis::add( addTypeB, i18n("Click here to add a new file type.") );
 
   QPushButton *removeTypeB = new QPushButton(i18n("&Remove"), this);
   connect(removeTypeB, SIGNAL(clicked()),
           this, SLOT(removeType()));
-  leftLayout->addWidget(removeTypeB, 1, 1);
+  leftLayout->addWidget(removeTypeB, 2, 1);
 
   QWhatsThis::add( removeTypeB, i18n("Click here to remove the selected file type.") );
 
@@ -83,7 +118,7 @@ FileTypesView::FileTypesView(QWidget *p, const char *name)
   QWhatsThis::add( iconButton, i18n("This button displays the icon associated"
     " with the selected file type. Click on it to choose a different icon.") );
 
-  QGroupBox *gb = new QGroupBox(i18n("File Patterns"), this);
+  QGroupBox *gb = new QGroupBox(i18n("Filename Patterns"), this);
   hBox->addWidget(gb);
 
   QGridLayout *grid = new QGridLayout(gb, 3, 2, KDialog::marginHint(),
@@ -114,7 +149,7 @@ FileTypesView::FileTypesView(QWidget *p, const char *name)
           this, SLOT(removeExtension()));
   grid->addWidget(removeExtButton, 2, 1);
 
-  QWhatsThis::add( removeExtButton, i18n("Remove the selected file pattern.") );
+  QWhatsThis::add( removeExtButton, i18n("Remove the selected filename pattern.") );
 
   gb = new QGroupBox(i18n("Description"), this);
   rightLayout->addWidget(gb);
@@ -140,7 +175,7 @@ FileTypesView::FileTypesView(QWidget *p, const char *name)
 
   servicesLB = new QListBox(gb);
   connect(servicesLB, SIGNAL(highlighted(int)), SLOT(enableMoveButtons(int)));
-  grid->addMultiCellWidget(servicesLB, 1, 3, 0, 0);
+  grid->addMultiCellWidget(servicesLB, 1, 4, 0, 0);
 
   wtstr = i18n("This is a list of applications associated with files of the selected"
     " file type. This list is shown in Konqueror's context menus when you select"
@@ -155,18 +190,20 @@ FileTypesView::FileTypesView(QWidget *p, const char *name)
   connect(servUpButton, SIGNAL(clicked()), SLOT(promoteService()));
   grid->addWidget(servUpButton, 1, 1);
 
-  QWhatsThis::add( servUpButton, i18n("Assigns a higher priority to the selected"
-    " application, moving it up in the list. Note that this only affects the selected"
-    " file type if the same application is associated with other file types.") );
+  QWhatsThis::add( servUpButton, i18n("Assigns a higher priority to the selected\n"
+                              "application, moving it up in the list. Note:  This\n"
+                              "only affects the selected application if the file type is\n"
+			      "associated with more than one application."));   
 
   servDownButton = new QPushButton(i18n("Move &Down"), gb);
   servDownButton->setEnabled(false);
   connect(servDownButton, SIGNAL(clicked()), SLOT(demoteService()));
   grid->addWidget(servDownButton, 2, 1);
 
-  QWhatsThis::add( servDownButton, i18n("Assigns a lower priority to the selected"
-    " application, moving it down in the list. Note that this only affects the selected"
-    " file type if the same application is associated with other file types.") );
+  QWhatsThis::add( servDownButton, i18n("Assigns a lower priority to the selected\n"
+			  "application, moving it down on the list.  Note:  This \n"
+			  "only affects the selected application if the file type is\n"
+			  "associated with more than one application."));
 
   servNewButton = new QPushButton(i18n("Add..."), gb);
   servNewButton->setEnabled(false);
@@ -175,37 +212,77 @@ FileTypesView::FileTypesView(QWidget *p, const char *name)
 
   QWhatsThis::add( servNewButton, i18n( "Add a new application for this file type." ) );
 
+  servRemoveButton = new QPushButton(i18n("Remove"), gb);
+  servRemoveButton->setEnabled(false);
+  connect(servRemoveButton, SIGNAL(clicked()), SLOT(removeService()));
+  grid->addWidget(servRemoveButton, 4, 1);
+
+  QWhatsThis::add( servRemoveButton, i18n( "Remove the selected application from the list." ) );
+  
   init();
+  setDirty(false);
 }
 
 FileTypesView::~FileTypesView()
 {
 }
 
+void FileTypesView::setDirty(bool state)
+{
+	emit changed(state);
+	m_dirty = state;
+}
+
 void FileTypesView::init()
 {
-  KMimeType::List mimetypes = KMimeType::allMimeTypes();
-  QValueListIterator<KMimeType::Ptr> it2(mimetypes.begin());
-  for (; it2 != mimetypes.end(); ++it2) {
-    QString mimetype = (*it2)->name();
-    int index = mimetype.find("/");
-    QString maj = mimetype.left(index);
-    QString min = mimetype.right(mimetype.length() - index+1);
+  readFileTypes();
+}
 
-    QListViewItemIterator it(typesLV);
-    for (; it.current(); ++it) {
-      TypesListItem *current = (TypesListItem *) it.current();
-      if (current->majorType() == maj) {
-        new TypesListItem(current, (*it2));
-        break;
-      }
+void FileTypesView::slotFilter(const QString &patternFilter)
+{
+  readFileTypes(patternFilter);
+}
+
+void FileTypesView::readFileTypes(const QString &patternFilter)
+{
+    typesLV->clear();
+    
+    KMimeType::List mimetypes = KMimeType::allMimeTypes();
+    QValueListIterator<KMimeType::Ptr> it2(mimetypes.begin());
+    for (; it2 != mimetypes.end(); ++it2) {
+	bool add = true;
+	
+	if ( !patternFilter.isEmpty() ) {
+	    QStringList matches = (*it2)->patterns().grep( patternFilter, 
+							   false );
+	    add = !matches.isEmpty();
+	}
+	
+	if ( add ) {
+	    QString mimetype = (*it2)->name();
+	    int index = mimetype.find("/");
+	    QString maj = mimetype.left(index);
+	    QString min = mimetype.right(mimetype.length() - index+1);
+	    
+	    QListViewItemIterator it(typesLV);
+	    for (; it.current(); ++it) {
+		TypesListItem *current = (TypesListItem *) it.current();
+		if (current->majorType() == maj) {
+		    new TypesListItem(current, (*it2));
+		    break;
+		}
+	    }
+	    if (!it.current()) {
+		// insert at top level.
+		TypesListItem *i = new TypesListItem(typesLV, (*it2));
+		
+		if ( !patternFilter.isEmpty() )
+		    i->setOpen(true);
+		
+		new TypesListItem(i, (*it2));
+	    }
+	}
     }
-    if (!it.current()) {
-      // insert at top level.
-      TypesListItem *i = new TypesListItem(typesLV, (*it2));
-      new TypesListItem(i, (*it2));
-    }
-  }
 }
 
 void FileTypesView::addType()
@@ -247,6 +324,8 @@ void FileTypesView::addType()
         tli->parent()->setOpen(true);
       typesLV->setSelected(tli, true);
     }
+
+    setDirty(true);
   }
 }
 
@@ -267,6 +346,8 @@ void FileTypesView::removeType()
     current->parent()->takeItem(current);
   }
   typesLV->setSelected(li, true);
+
+  setDirty(true);
 }
 
 void FileTypesView::addExtension()
@@ -279,6 +360,8 @@ void FileTypesView::addExtension()
       QStringList patt = tli->patterns();
       patt += m.text();
       tli->setPatterns(patt);
+
+      setDirty(true);
     }
   }
 }
@@ -292,10 +375,14 @@ void FileTypesView::removeExtension()
   patt.remove(extensionLB->text(extensionLB->currentItem()));
   tli->setPatterns(patt);
   extensionLB->removeItem(extensionLB->currentItem());
+
+  setDirty(true);
 }
 
 void FileTypesView::updateDisplay(QListViewItem *item)
 {
+  bool wasDirty = m_dirty;
+
   if (!item)
     return;
 
@@ -309,19 +396,31 @@ void FileTypesView::updateDisplay(QListViewItem *item)
   removeExtButton->setEnabled(false);
   addExtButton->setEnabled(true);
   servNewButton->setEnabled(true);
+  servRemoveButton->setEnabled(false);
   extensionLB->insertStringList(tlitem->patterns());
 
 
   servicesLB->clear();
-  if (tlitem->defaultServices().count() == 0) {
+  
+  QStringList services = tlitem->defaultServices();
+  
+  if (services.count() == 0) {
     servicesLB->insertItem("None");
     servicesLB->setEnabled(false);
     servUpButton->setEnabled(false);
     servDownButton->setEnabled(false);
   } else {
-    servicesLB->insertStringList(tlitem->defaultServices());
+    for ( QStringList::Iterator it = services.begin();
+          it != services.end(); it++ ) 
+    {
+      servicesLB->insertItem( new ServiceListItem(*it) );
+    }
     servicesLB->setEnabled(true);
   }
+
+  // Updating the display indirectly called change(true)
+  if ( !wasDirty )
+    setDirty(false);
 }
 
 void FileTypesView::updateIcon(QString icon)
@@ -331,6 +430,8 @@ void FileTypesView::updateIcon(QString icon)
 
   TypesListItem *tli = (TypesListItem *) typesLV->currentItem();
   tli->setIcon(icon);
+
+  setDirty(true);
 }
 
 void FileTypesView::updateDescription(const QString &desc)
@@ -340,6 +441,8 @@ void FileTypesView::updateDescription(const QString &desc)
 
   TypesListItem *tli = (TypesListItem *) typesLV->currentItem();
   tli->setComment(desc);
+
+  setDirty(true);
 }
 
 void FileTypesView::promoteService()
@@ -355,11 +458,14 @@ void FileTypesView::promoteService()
     return;
   }
 
-  QString sel = servicesLB->text(selIndex);
-  servicesLB->removeItem(selIndex);
-  servicesLB->insertItem(sel, selIndex-1);
+  QListBoxItem *selItem = servicesLB->item(selIndex);
+  servicesLB->takeItem(selItem);
+  servicesLB->insertItem(selItem, selIndex-1);
   servicesLB->setCurrentItem(selIndex - 1);
+  
   updatePreferredServices();
+
+  setDirty(true);
 }
 
 void FileTypesView::demoteService()
@@ -375,11 +481,14 @@ void FileTypesView::demoteService()
     return;
   }
 
-  QString sel = servicesLB->text(selIndex);
-  servicesLB->removeItem(selIndex);
-  servicesLB->insertItem(sel, selIndex+1);
+  QListBoxItem *selItem = servicesLB->item(selIndex);
+  servicesLB->takeItem(selItem);
+  servicesLB->insertItem(selItem, selIndex+1);
   servicesLB->setCurrentItem(selIndex + 1);
+  
   updatePreferredServices();
+  
+  setDirty(true);
 }
 
 void FileTypesView::updatePreferredServices()
@@ -390,9 +499,10 @@ void FileTypesView::updatePreferredServices()
   QStringList sl;
   unsigned int count = servicesLB->count();
 
-  for (unsigned int i = 0; i < count; i++)
-    sl.append(servicesLB->text(i));
-
+  for (unsigned int i = 0; i < count; i++) {
+    ServiceListItem *sli = (ServiceListItem *) servicesLB->item(i);
+    sl.append( sli->desktopPath );
+  }
   tli->setDefaultServices(sl);
 }
 
@@ -425,12 +535,13 @@ bool FileTypesView::sync()
       didIt = true;
     }
   }
+  setDirty(false);
   return didIt;
 }
 
 void FileTypesView::enableMoveButtons(int index)
 {
-  if (servicesLB->count() == 1)
+  if (servicesLB->count() <= 1)
   {
     servUpButton->setEnabled(false);
     servDownButton->setEnabled(false);
@@ -450,6 +561,8 @@ void FileTypesView::enableMoveButtons(int index)
     servUpButton->setEnabled(true);
     servDownButton->setEnabled(true);
   }
+
+  servRemoveButton->setEnabled(true);
 }
 
 void FileTypesView::enableExtButtons(int /*index*/)
@@ -483,9 +596,29 @@ void FileTypesView::addService()
       servicesLB->removeItem(0);
       servicesLB->setEnabled(true);
   }
-  servicesLB->insertItem(service->name());
+  QString desktopPath = service->desktopEntryPath();
+  
+  servicesLB->insertItem( new ServiceListItem(desktopPath) );
 
   updatePreferredServices();
+
+  setDirty(true);
+}
+
+void FileTypesView::removeService()
+{
+	int selected = servicesLB->currentItem(); 
+
+	if ( selected >= 0 ) {
+		servicesLB->removeItem( selected );
+		updatePreferredServices();
+
+		setDirty(true);
+	}
+
+	if ( servicesLB->currentItem() == -1 ) 
+		servRemoveButton->setEnabled(false);
+
 }
 
 void FileTypesView::load()
@@ -513,7 +646,7 @@ QString FileTypesView::quickHelp()
     " (MIME is an acronym which stands for \"Multipurpose Internet Mail"
     " Extensions\".)<p> A file association consists of the following:"
     " <ul><li>Rules for determining the MIME-type of a file. For example,"
-    " the file pattern *.kwd, which means 'all files with names that end"
+    " the filename pattern *.kwd, which means 'all files with names that end"
     " in .kwd', is associated with the MIME type \"x-kword\".</li>"
     " <li>A short description of the MIME-type. For example, the description"
     " of the MIME type \"x-kword\" is simply 'KWord document'.)</li>"
@@ -524,7 +657,7 @@ QString FileTypesView::quickHelp()
     " given MIME-type. If more than one application can be used, then the"
     " list is ordered by priority.</li></ul>"
     " You may be surprised to find that some MIME types have no associated"
-    " file patterns! In these cases, Konqueror is able to determine the"
+    " filename patterns! In these cases, Konqueror is able to determine the"
     " MIME-type by directly examining the contents of the file.");
 }
 
