@@ -1,5 +1,6 @@
+#include <iostream.h>
 /*
- * $Id: info_fbsd.cpp,v 1.10 1998/11/09 09:14:30 garbanzo Exp $
+ * $Id: info_fbsd.cpp,v 1.16 2000/02/29 20:35:58 coolo Exp $
  *
  * info_fbsd.cpp is part of the KDE program kcminfo.  This displays
  * various information about the system (hopefully a FreeBSD system)
@@ -30,29 +31,22 @@
 #include <fstab.h>
 #include <stdlib.h>
 
+#include <qtextstream.h>
 #include <qfile.h>
 #include <qfontmetrics.h>
 
-/* stdio.h has NULL, but also a lot of extra cruft */
-#ifndef NULL
-#define NULL 0L
-#endif
+#include <kdebug.h>
 
-/* Again avoid the cruft in stdlib.h since malloc() isn't gonna change 
-   too often, unless someone decides to de-KNR FreeBSD */
-void    *malloc __P((size_t));
-
-bool GetInfo_CPU (KTabListBox *lBox)
+bool GetInfo_CPU (QListView *lBox)
 { 
   QString str;
 
   /* Stuff for sysctl */
-  char *buf, *mhz, *cpustring;
+  char *buf, *mhz;
+  QString cpustring;
   int mib[2], machspeed;
   size_t len;
 
-  cpustring=(char *)malloc(128);
-
   mib[0] = CTL_HW;
   mib[1] = HW_MODEL;
   sysctl(mib,2,NULL,&len,NULL,0);
@@ -70,43 +64,44 @@ bool GetInfo_CPU (KTabListBox *lBox)
 		   ((machspeed+4999)/10000)%100);
   if (strcmp(mhz,"0.00")==0)
  	/* We dunno how fast it's running */
- 	snprintf(cpustring,128,i18n("%s, unknown speed"),buf);
+	cpustring = i18n("%1, unknown speed").arg(buf);
   else
-	snprintf(cpustring,128,i18n("%s running at %s MHz"),buf,mhz);
+	cpustring = i18n("%1 running at %2 MHz").arg(buf).arg(mhz);
 
   /* Put everything in the listbox */
-  lBox->insertItem(cpustring);
+  new QListViewItem(lBox, cpustring);
   /* Clean up after ourselves, this time I mean it ;-) */
-  free(mhz); free(cpustring); free(buf);
+  free(mhz);
+  free(buf);
 
-  return TRUE;
+  return true;
 }
 
-bool GetInfo_IRQ (KTabListBox *)
+bool GetInfo_IRQ (QListView *)
 {
   /* systat lists the interrupts assigned to devices as well as how many were
      generated.  Parsing its output however is about as fun as a sandpaper
      enema.  The best idea would probably be to rip out the guts of systat.
      Too bad it's not very well commented */
-  return FALSE;
+  return false;
 }
 
-bool GetInfo_DMA (KTabListBox *)
+bool GetInfo_DMA (QListView *)
 {
-  return FALSE;
+  return false;
 }
 
-bool GetInfo_PCI (KTabListBox *)
+bool GetInfo_PCI (QListView *)
 {
-  return FALSE;
+  return false;
 }
 
-bool GetInfo_IO_Ports (KTabListBox *)
+bool GetInfo_IO_Ports (QListView *)
 {
-  return FALSE;
+  return false;
 }
 
-bool GetInfo_Sound (KTabListBox *lbox)
+bool GetInfo_Sound (QListView *lbox)
 {
   QFile *sndstat = new QFile("/dev/sndstat");
   QTextStream *t; QString s;
@@ -121,12 +116,11 @@ bool GetInfo_Sound (KTabListBox *lbox)
     return false;
   }
   
-  lbox->clear();
-  
   t = new QTextStream(sndstat);
 
-  while ((s=t->readLine())!="")
-    lbox->insertItem(s);
+  QListViewItem* olditem = 0;
+  while ((s=t->readLine()) != QString::null)
+      olditem = new QListViewItem(lbox, olditem, s);
 
   delete t;
   sndstat->close();
@@ -134,7 +128,7 @@ bool GetInfo_Sound (KTabListBox *lbox)
   return true;
 }
 
-bool GetInfo_Devices (KTabListBox *lbox)
+bool GetInfo_Devices (QListView *lbox)
 {
 	QFile *dmesg = new QFile("/var/run/dmesg.boot");
 
@@ -153,8 +147,10 @@ bool GetInfo_Devices (KTabListBox *lbox)
 	QTextStream *t = new QTextStream(dmesg);
 	QString s;
 
-	while ((s=t->readLine())!="")
-		lbox->insertItem(s);
+    QListViewItem* olditem;
+    
+	while ((s=t->readLine()) != QString::null)
+        olditem = new QListViewItem(lbox, olditem, s);
 
 	delete t;
 	dmesg->close();
@@ -162,20 +158,20 @@ bool GetInfo_Devices (KTabListBox *lbox)
 	return true;
 }
 
-bool GetInfo_SCSI (KTabListBox *lbox)
+bool GetInfo_SCSI (QListView *lbox)
 {
   /*
    * This code relies on the system at large having "the" CAM (see the FreeBSD
    * 3.0 Release notes for more info) SCSI layer, and not the older one.
    * If someone who has a system with the older SCSI layer and would like to
-   * tell me (garbanzo@hooked.net) how to extract that info, I'd be much
+   * tell me (jazepeda@pacbell.net) how to extract that info, I'd be much
    * obliged.
    */
   FILE *pipe;
   QFile *camcontrol = new QFile("/sbin/camcontrol");
   QTextStream *t;
   QString s;
-  
+
   if (!camcontrol->exists()) {
     delete camcontrol;
     return false;
@@ -189,77 +185,54 @@ bool GetInfo_SCSI (KTabListBox *lbox)
   }
 
   t = new QTextStream(pipe, IO_ReadOnly);
-
-  while ((s=t->readLine())!="")
-    lbox->insertItem(s);
   
+  QListViewItem* olditem = 0;
+
+  while (true) {
+    s = t->readLine();
+    if ( (s == "") || (s == QString::null) )
+      break;
+    olditem = new QListViewItem(lbox, olditem, s);
+  }
+
   delete t; delete camcontrol; pclose(pipe);
   
-  if (!lbox->count())
+  if (!lbox->childCount())
     return false;
   
   return true;
 }
 
-bool GetInfo_Partitions (KTabListBox *lbox)
+bool GetInfo_Partitions (QListView *lbox)
 {
-	int maxwidth[4]={0,0,0,0};
-
 	struct fstab *fstab_ent;
-	QFontMetrics fm(lbox->tableFont());
-	QString s;
 
 	if (setfsent() != 1) /* Try to open fstab */ {
-		kdebug(KDEBUG_ERROR, 0, i18n("Ahh couldn't open fstab!"));
+		kdError() << "Ahh couldn't open fstab!" << endl;
 		return false;
 	}
 
-	lbox->setNumCols(4);
-	lbox->setSeparator(';');
-
-	maxwidth[0]=fm.width(i18n("Device"));
-	lbox->setColumn(0, i18n("Device"), maxwidth[0]+2);
-
-	maxwidth[1]=fm.width(i18n("Mount Point"));
-	lbox->setColumn(1, i18n("Mount Point"), maxwidth[1]+2);
-
-	maxwidth[2]=fm.width(i18n("FS Type"));
-	lbox->setColumn(2, i18n("FS Type"), maxwidth[2]+2);
-
-	maxwidth[3]=fm.width(i18n("Mount Options"));
-	lbox->setColumn(3, i18n("Mount Options"), maxwidth[3]+2);
+	lbox->addColumn(i18n("Device"));
+	lbox->addColumn(i18n("Mount Point"));
+	lbox->addColumn(i18n("FS Type"));
+	lbox->addColumn(i18n("Mount Options"));
 
 
 	while ((fstab_ent=getfsent())!=NULL) {
-		if (fm.width(fstab_ent->fs_spec) > maxwidth[0]) {
-			maxwidth[0]=fm.width(fstab_ent->fs_spec);
-			lbox->setColumnWidth(0, maxwidth[0]+10);
-		}
-
-		if (fm.width(fstab_ent->fs_file) > maxwidth[1]) {
-			maxwidth[1]=fm.width(fstab_ent->fs_file);
-			lbox->setColumnWidth(1, maxwidth[1]+10);
-		}
-
-		if (fm.width(fstab_ent->fs_vfstype) > maxwidth[2]) {
-			maxwidth[2]=fm.width(fstab_ent->fs_vfstype);
-			lbox->setColumnWidth(2, maxwidth[2]+10);
-		}
-
-		if (fm.width(fstab_ent->fs_mntops) > maxwidth[3]) {
-			maxwidth[3]=fm.width(fstab_ent->fs_mntops);
-			lbox->setColumnWidth(3, maxwidth[3]+10);
-		}
-
-		s.sprintf("%s;%s;%s;%s", fstab_ent->fs_spec, fstab_ent->fs_file, fstab_ent->fs_vfstype, fstab_ent->fs_mntops);
-		lbox->insertItem(s);
+        new QListViewItem(lbox, fstab_ent->fs_spec,
+                          fstab_ent->fs_file, fstab_ent->fs_vfstype,
+                          fstab_ent->fs_mntops);
+        
 	}
 
+    lbox->setSorting(0);
+    lbox->header()->setClickEnabled(true);
+
 	endfsent(); /* Close fstab */
 	return true;
 }
 
-bool GetInfo_XServer_and_Video (KTabListBox *lBox)
+bool GetInfo_XServer_and_Video (QListView *lBox)
 {
 	return GetInfo_XServer_Generic( lBox );
 }
