@@ -24,7 +24,7 @@
  *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
  *
- *  $Id: memory.cpp,v 1.24 2000/01/29 22:07:13 bieker Exp $ 
+ *  $Id: memory.cpp,v 1.25 2000/06/07 06:28:46 hoelzer Exp $ 
  */
 
 #include <sys/param.h>	/* for BSD */
@@ -78,7 +78,7 @@ static QLabel	*GraphLabel[MEM_LAST];
 
 static QString format_MB( t_memsize value)
 {
-#ifdef linux
+#ifdef __linux
   double   mb = value / 1024000.0; /* with Linux divide by (1024*1000) */
 #elif hpux	
   double   mb = value / 1048576.0; /* with hpux divide by (1024*1024) */
@@ -303,7 +303,7 @@ void KMemoryWidget::update_Values()
 
 /* Include system-specific code */
 
-#ifdef linux
+#ifdef __linux
 #include "memory_linux.cpp"
 #elif sgi
 #include "memory_sgi.cpp"
