@@ -1,8 +1,10 @@
-// $Id: memory_fbsd.cpp,v 1.7 1998/10/11 05:33:32 garbanzo Exp $
+// $Id: memory_fbsd.cpp,v 1.10 1999/06/23 02:42:43 deller Exp $
 
 #include <sys/types.h>
 #include <sys/sysctl.h>
 #include <stdlib.h>	// For atoi()
+#include <stdio.h>
+#include <unistd.h>
 
 void KMemoryWidget::update()
 {
@@ -19,12 +21,24 @@ void KMemoryWidget::update()
   
   snprintf(blah, 10, "%d", memory);
   // Numerical values
-  totalMem->setText(format(memory));
+  Memory_Info[TOTAL_MEM]    = MEMORY(memory); // total physical memory (without swaps)
   /*	To: questions@freebsd.org
 		Anyone have any ideas on how to calculate this */
-  freeMem->setText(i18n("Not available"));
-  sharedMem->setText(i18n("Not available"));
-  bufferMem->setText(i18n("Not available"));
+  Memory_Info[SHARED_MEM]   = NO_MEMORY_INFO; 
+
+  int buffers;
+  len = sizeof (buffers);
+  if ((sysctlbyname("vfs.bufspace", &buffers, &len, NULL, 0) == -1) || !len)
+    Memory_Info[BUFFER_MEM]   = NO_MEMORY_INFO;  // Doesn't work under FreeBSD v2.2.x
+  else
+    Memory_Info[BUFFER_MEM]   = MEMORY(buffers);
+
+  int free;
+  len = sizeof (buffers);
+  if ((sysctlbyname("vm.stats.vm.v_free_count", &free, &len, NULL, 0) == -1) || !len)
+    Memory_Info[FREE_MEM]     = NO_MEMORY_INFO;	// Doesn't work under FreeBSD v2.2.x
+  else
+    Memory_Info[FREE_MEM]     = MEMORY(free*getpagesize());// total free physical memory (without swaps)
 
   /* Q&D hack for swap display. Borrowed from xsysinfo-1.4 */
   if ((pipe = popen("/usr/sbin/pstat -ks", "r")) == NULL) {
@@ -45,6 +59,6 @@ void KMemoryWidget::update()
   total = atoi(total_str); 
 
   _free=total-used;
-  swapMem->setText(format(1024*total));
-  freeSwapMem->setText(format(1024*_free));
+  Memory_Info[SWAP_MEM]     = MEMORY(1024*total); // total size of all swap-partitions
+  Memory_Info[FREESWAP_MEM] = MEMORY(1024*_free); // free memory in swap-partitions
 }
