@@ -1,22 +1,22 @@
 /*
   Copyright (c) 1999 Matthias Hoelzer-Kluepfel <hoelzer@kde.org>
-  Copyright (c) 2000 Matthias Elter <elter@kde.org> 
+  Copyright (c) 2000 Matthias Elter <elter@kde.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.
- 
+
   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.
- 
+
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
- 
-*/                                                                            
+
+*/
 
 #ifndef __TOPLEVEL_H__
 #define __TOPLEVEL_H__
@@ -27,6 +27,7 @@ class QTabWidget;
 class QSplitter;
 
 class KToggleAction;
+class KAction;
 
 class DockContainer;
 class IndexWidget;
@@ -46,7 +47,7 @@ public:
   void showModule(QString desktopFile);
 
 protected:
-  void setupActions(); 
+  void setupActions();
 
 protected slots:
   void activateModule(const QString& name);
@@ -55,10 +56,14 @@ protected slots:
   void activateIconView();
   void activateTreeView();
 
+  void reportBug();
+
   void activateSmallIcons();
   void activateMediumIcons();
   void activateLargeIcons();
 
+  void deleteDummyAbout();
+
 private:
   QTabWidget     *_tab;
   DockContainer  *_dock;
@@ -66,6 +71,7 @@ private:
 
   KToggleAction *tree_view, *icon_view;
   KToggleAction *icon_small, *icon_medium, *icon_large;
+  KAction *report_bug;
 
   IndexWidget  *_indextab;
   SearchWidget *_searchtab;
@@ -73,6 +79,13 @@ private:
 
   ConfigModule     *_active;
   ConfigModuleList *_modules;
+
+  /**
+   * if someone wants to report a bug
+   * against a module with no about data
+   * we construct one for him
+   **/
+  KAboutData *dummyAbout;
 };
 
 #endif
