@@ -18,20 +18,24 @@
 */
 
 
-#include <qdragobject.h>
-#include <qlayout.h>
+#include <qbuttongroup.h>
 #include <qcombobox.h>
+#include <qdragobject.h>
 #include <qgroupbox.h>
 #include <qlabel.h>
+#include <qlayout.h>
+#include <qradiobutton.h>
 #include <qtooltip.h>
+#include <qwhatsthis.h>
 
+#include <kdialog.h>
+#include <kglobal.h>
 #include <kio/job.h>
 #include <klocale.h>
-#include <kglobal.h>
 #include <klineedit.h>
 #include <kmessagebox.h>
-#include <kstddirs.h>
 #include <ksimpleconfig.h>
+#include <kstddirs.h>
 
 #include "kdm-appear.moc"
 
@@ -39,49 +43,93 @@
 KDMAppearanceWidget::KDMAppearanceWidget(QWidget *parent, const char *name)
   : KCModule(parent, name)
 {
-  QVBoxLayout *vbox = new QVBoxLayout(this, 6,6, "vbox");
-
+  QString wtstr;
+  QVBoxLayout *vbox = new QVBoxLayout(this, KDialog::marginHint(), 
+				      KDialog::spacingHint(), "vbox");
   QGroupBox *group = new QGroupBox(i18n("Appearance"), this);
   vbox->addWidget(group);
 
-  QVBoxLayout *vvbox = new QVBoxLayout(group, 6,6, "vvbox");
-  vvbox->addSpacing(group->fontMetrics().height());
-
-  QGridLayout *grid = new QGridLayout(vvbox, 5,3, 6, "grid");
+  QGridLayout *grid = new QGridLayout( group, 5, 3, KDialog::spacingHint(), 
+				       KDialog::spacingHint(), "grid");
+  grid->addRowSpacing(0,group->fontMetrics().height());
   grid->setColStretch(2,1);
 
   QLabel *label = new QLabel(i18n("Greeting string:"), group);
-  grid->addWidget(label, 1,0);
-
   greetstr_lined = new KLineEdit(group);
+  connect(greetstr_lined, SIGNAL(textChanged(const QString&)), 
+	  this, SLOT(changed()));
+  grid->addWidget(label, 1,0 );
   grid->addMultiCellWidget(greetstr_lined, 1,1, 1,2);
-  connect(greetstr_lined, SIGNAL(textChanged(const QString&)), this, SLOT(changed()));
+  wtstr = i18n("This is the string KDM will display in the login window. "
+	       "You may want to put here some nice greeting or information "
+	       "about the operating system.<p> KDM will replace the string "
+	       "[HOSTNAME] with the actual host name of the computer "
+	       "running the X server. Especially in networks this is a good "
+	       "idea." );
+  QWhatsThis::add( label, wtstr );
+  QWhatsThis::add( greetstr_lined, wtstr );
 
-  label = new QLabel(i18n("KDM logo:"), group);
-  grid->addWidget(label, 2,0);
 
+  label = new QLabel(i18n("Logo area:"), group);
+  QWidget *helper = new QWidget( group );
+  QHBoxLayout *hlay = new QHBoxLayout( helper, KDialog::spacingHint() );
+  logoRadio = new QRadioButton( i18n("Show KDM logo"), helper );
+  clockRadio = new QRadioButton( i18n("Show clock"), helper );
+  QButtonGroup *buttonGroup = new QButtonGroup( helper );
+  connect( buttonGroup, SIGNAL(clicked(int)), 
+	   this, SLOT(slotRadioClicked(int)) );
+  connect( buttonGroup, SIGNAL(clicked(int)), 
+	   this, SLOT(changed()) );
+  buttonGroup->insert(logoRadio, KdmLogo);
+  buttonGroup->insert(clockRadio, KdmClock);
+  buttonGroup->hide();
+  hlay->addWidget(logoRadio);
+  hlay->addWidget(clockRadio, 1, AlignLeft);
+  grid->addWidget(label,2,0);
+  grid->addMultiCellWidget(helper, 2,2, 1,2);
+  wtstr = i18n("You can choose to display the KDM logo or a clock");
+  QWhatsThis::add( label, wtstr );
+  QWhatsThis::add( logoRadio, wtstr );
+  QWhatsThis::add( clockRadio, wtstr );
+
+  logoLabel = new QLabel(i18n("KDM logo:"), group);
   logopath = "kdelogo.png";
   logobutton = new KIconButton(group);
+  logobutton->setAutoDefault(false);
   logobutton->setAcceptDrops(true);
   logobutton->installEventFilter(this); // for drag and drop
   logobutton->setMinimumSize(24,24);
   logobutton->setMaximumSize(80,80);
-  grid->addWidget(logobutton, 2,1, QWidget::AlignCenter);
-  grid->addRowSpacing(2, 80);
   logobutton->setIcon("kdelogo");
-  connect(logobutton, SIGNAL(iconChanged(QString)), SLOT(slotLogoPixChanged(QString)));
-  connect(logobutton, SIGNAL(iconChanged(const QString&)), this, SLOT(changed()));
+  connect(logobutton, SIGNAL(iconChanged(QString)), 
+	  this, SLOT(slotLogoPixChanged(QString)));
+  connect(logobutton, SIGNAL(iconChanged(const QString&)), 
+	  this, SLOT(changed()));
+  grid->addRowSpacing(3, 80);
+  grid->addWidget(logoLabel, 3,0);
+  grid->addWidget(logobutton, 3,1, AlignVCenter|AlignLeft);
+  wtstr = i18n("Click here to choose an image that KDM will display. "
+	       "You can also drag and drop an image onto this button "
+	       "(e.g. from Konqueror).");
+  QWhatsThis::add( logoLabel, wtstr );
+  QWhatsThis::add( logobutton, wtstr );
+
 
-  QToolTip::add(logobutton, i18n("Click or drop an image here"));
 
   label = new QLabel(i18n("GUI Style:"), group);
-  grid->addWidget(label, 4,0);
-
   guicombo = new QComboBox(false, group);
   guicombo->insertItem(i18n("Motif"), 0);
   guicombo->insertItem(i18n("Windows"), 1);
-  grid->addWidget(guicombo, 4, 1);
+  //guicombo->insertItem(i18n("Platinum"), 2);
+  //guicombo->insertItem(i18n("CDE"), 3);
   connect(guicombo, SIGNAL(activated(int)), this, SLOT(changed()));
+  grid->addWidget(label, 4,0);
+  grid->addWidget(guicombo, 4, 1);
+  wtstr = i18n("You can choose a basic GUI style here that will be "
+		"used by KDM only.");
+  QWhatsThis::add( label, wtstr );
+  QWhatsThis::add( guicombo, wtstr );
+
 
   // The Language group box
   group = new QGroupBox(i18n("Language"), this);
@@ -92,7 +140,7 @@ KDMAppearanceWidget::KDMAppearanceWidget(QWidget *parent, const char *name)
   hbox->addRowSpacing(5, 10);
   hbox->addColSpacing(0, 10);
   hbox->addColSpacing(3, 10);
-  hbox->setColStretch(2, 1);        
+  hbox->setColStretch(2, 1);
 
   label = new QLabel(i18n("Language:"), group);
   hbox->addWidget(label, 1, 1);
@@ -101,6 +149,11 @@ KDMAppearanceWidget::KDMAppearanceWidget(QWidget *parent, const char *name)
   hbox->addWidget(langcombo, 1, 2);
   connect(langcombo, SIGNAL(activated(int)), this, SLOT(changed()));
 
+  wtstr = i18n("Here you can choose the language used by KDM. This setting doesn't affect"
+    " a user's personal settings that will take effect after login.");
+  QWhatsThis::add( label, wtstr );
+  QWhatsThis::add( langcombo, wtstr );
+
   label = new QLabel(i18n("Country:"), group);
   hbox->addWidget(label, 2, 1);
 
@@ -108,6 +161,11 @@ KDMAppearanceWidget::KDMAppearanceWidget(QWidget *parent, const char *name)
   hbox->addWidget(countrycombo, 2, 2);
   connect(countrycombo, SIGNAL(activated(int)), this, SLOT(changed()));
 
+  wtstr = i18n("Here you can choose a country setting for KDM. This setting doesn't affect"
+    " a user's personal settings that will take effect after login.");
+  QWhatsThis::add( label, wtstr );
+  QWhatsThis::add( countrycombo, wtstr );
+
   loadLocaleList(langcombo, QString::null, QStringList());
   loadLocaleList(countrycombo, QString::fromLatin1("l10n/"), QStringList());
   load();
@@ -169,6 +227,13 @@ void KDMAppearanceWidget::setLogo(QString logo)
 }
 
 
+void KDMAppearanceWidget::slotRadioClicked(int id)
+{
+  logobutton->setEnabled( id == KdmLogo );
+  logoLabel->setEnabled( id == KdmLogo );
+}
+
+
 void KDMAppearanceWidget::slotLogoPixChanged(QString iconstr)
 {
   logopath = iconstr;
@@ -202,7 +267,7 @@ void KDMAppearanceWidget::iconLoaderDropEvent(QDropEvent *e)
   if (QUriDrag::decodeToUnicodeUris( e, uris) && (uris.count() > 0)) {
     KURL url(*uris.begin());
 
-    QString filename = url.filename();
+    QString fileName = url.fileName();
     QString msg;
     QStringList dirs = KGlobal::dirs()->findDirs("data", "kdm/pics/");
     QString local = KGlobal::dirs()->saveLocation("data", "kdm/pics/", false);
@@ -210,7 +275,7 @@ void KDMAppearanceWidget::iconLoaderDropEvent(QDropEvent *e)
     if ((*it).left(local.length()) == local)
       it++;
     QString pixurl("file:"+ *it);
-    int last_dot_idx = filename.findRev('.');
+    int last_dot_idx = fileName.findRev('.');
     bool istmp = false;
 
     // CC: Now check for the extension
@@ -222,19 +287,19 @@ void KDMAppearanceWidget::iconLoaderDropEvent(QDropEvent *e)
     ext += " .jpg";
 #endif
 
-    if( !ext.contains(filename.right(filename.length()-
+    if( !ext.contains(fileName.right(fileName.length()-
 				     last_dot_idx), false) ) {
       msg =  i18n("Sorry, but %1\n"
 		  "does not seem to be an image file\n"
 		  "Please use files with these extensions:\n"
 		  "%2")
-	.arg(filename)
+	.arg(fileName)
 	.arg(ext);
       KMessageBox::sorry( this, msg);
     } else {
       // we gotta check if it is a non-local file and make a tmp copy at the hd.
       if(url.protocol() != "file") {
-	pixurl += url.filename();
+	pixurl += url.fileName();
 	KIO::file_copy(url, pixurl);
 	url = pixurl;
 	istmp = true;
@@ -265,6 +330,11 @@ void KDMAppearanceWidget::save()
   // write greeting string
   c->writeEntry("GreetString", greetstr_lined->text(), true);
 
+  // write logo or clock
+  QString logoArea = logoRadio->isChecked() ? "KdmLogo" : "KdmClock";
+  c->writeEntry("LogoArea", logoArea );
+  printf("WRITE: logoArea=%s\n", logoArea.latin1() );
+
   // write logo path
   c->writeEntry("LogoPixmap", logopath, true);
 
@@ -296,6 +366,15 @@ void KDMAppearanceWidget::load()
   // Read the greeting string
   greetstr_lined->setText(c->readEntry("GreetString", "KDE System at [HOSTNAME]"));
 
+  // Regular logo or clock
+  QString logoArea = c->readEntry("LogoArea", "KdmLogo" );
+  printf("READ: logoArea=%s\n", logoArea.latin1() );
+
+  int mode = logoArea == "KdmLogo" ? KdmLogo : KdmClock;
+  logoRadio->setChecked( mode == KdmLogo );
+  clockRadio->setChecked( mode == KdmClock );
+  slotRadioClicked(mode);
+
   // See if we use alternate logo
   QString logopath = c->readEntry("LogoPixmap");
   if(!logopath.isEmpty())
@@ -333,12 +412,23 @@ void KDMAppearanceWidget::load()
 void KDMAppearanceWidget::defaults()
 {
   greetstr_lined->setText("KDE System at [HOSTNAME]");
+  logoRadio->setChecked( true );
+  clockRadio->setChecked( false );
+  slotRadioClicked( KdmLogo );
   setLogo("kdelogo");
   guicombo->setCurrentItem(0);
   langcombo->setCurrentItem("C");
   countrycombo->setCurrentItem("C");
 }
 
+QString KDMAppearanceWidget::quickHelp()
+{
+  return i18n("<h1>KDM - Appearance</h1> Here you can configure the basic appearance"
+    " of the KDM login manager, i.e. a greeting string, an icon etc.<p>"
+    " For further refinement of KDM's appearance, see the \"Font\" and \"Background\" "
+    " tabs.");
+}
+
 
 void KDMAppearanceWidget::changed()
 {
