@@ -21,31 +21,35 @@
 #define __KDMFONT_H__
 
 
-#include <kfontdialog.h>
 
-class KDMFontWidget : public KConfigWidget
+#include <kfontdialog.h>
+#include <kcmodule.h>
+
+
+class KDMFontWidget : public KCModule
 {
 	Q_OBJECT
 
 public:
-	KDMFontWidget(QWidget *parent, const char *name, bool init = false);
-	~KDMFontWidget();
+	KDMFontWidget(QWidget *parent=0, const char *name=0);
+
+        void load();
+        void save();
+	void defaults();
 
-        void loadSettings();
-        void applySettings();
-	void setupPage(QWidget*);
 
 private slots:
         void slotGetFont();
         void slotSetFont(int);
 
+
 private:
 
         KIconLoader *iconloader;
         QFont        tmpfont, stdfont, greetfont, failfont;
         QLabel       *fontlabel;
 	QComboBox    *fontcombo;
-        bool         gui;
+
 };
 
 
