@@ -37,6 +37,7 @@ public:
         virtual void load();
         virtual void save();
         virtual void defaults();
+        virtual QString quickHelp();
 
 private slots:
 
@@ -49,6 +50,7 @@ private:
         // Checkboxes
         QCheckBox *showHiddenBox;
         QCheckBox *VertAlignBox;
+        QCheckBox *topLevelBox;
 
         // Combo for the menus
         void fillMenuCombo( QComboBox * combo );
