@@ -108,7 +108,9 @@ void KLocaleConfigMoney::load()
   KConfig *config = KGlobal::config();
   KConfigGroupSaver saver(config, QString::fromLatin1("Locale"));
 
-  KSimpleConfig ent(locate("locale", QString::fromLatin1("l10n/") + locale->money() + QString::fromLatin1("/entry.desktop")), true);
+  KSimpleConfig ent(locate("locale",
+			   QString::fromLatin1("l10n/%1/entry.desktop")
+			   .arg(locale->country())), true);
   ent.setGroup(QString::fromLatin1("KCM Locale"));
 
   // different tmp variables
@@ -132,6 +134,7 @@ void KLocaleConfigMoney::load()
   str = config->readEntry(QString::fromLatin1("MonetaryThousendSeparator"));
   if (str.isNull())
     str = ent.readEntry(QString::fromLatin1("MonetaryThousandsSeparator"), QString::fromLatin1(","));
+  str.replace(QRegExp(QString::fromLatin1("$0")), QString::null);
   locale->setMonetaryThousandsSeparator(str);
 
   // Fract digits
@@ -195,7 +198,9 @@ void KLocaleConfigMoney::save()
   KConfigBase *config = new KConfig;
   config->setGroup(QString::fromLatin1("Locale"));
 
-  KSimpleConfig ent(locate("locale", QString::fromLatin1("l10n/") + locale->money() + QString::fromLatin1("/entry.desktop")), true);
+  KSimpleConfig ent(locate("locale",
+			   QString::fromLatin1("l10n/%1/entry.desktop")
+			   .arg(locale->country())), true);
   ent.setGroup(QString::fromLatin1("KCM Locale"));
 
   QString str;
@@ -214,6 +219,7 @@ void KLocaleConfigMoney::save()
 
   str = ent.readEntry(QString::fromLatin1("MonetaryThousandsSeparator"), QString::fromLatin1(","));
   str = config->readEntry(QString::fromLatin1("MonetaryThousandsSeparator"), str);
+  str.replace(QRegExp(QString::fromLatin1("$0")), QString::null);
   if (str != locale->monetaryThousandsSeparator())
     config->writeEntry(QString::fromLatin1("MonetaryThousandsSeparator"), QString::fromLatin1("$0")+locale->monetaryThousandsSeparator()+QString::fromLatin1("$0"), true, true);
 
@@ -313,12 +319,16 @@ void KLocaleConfigMoney::slotMonNegMonSignPosChanged(int i)
  */
 void KLocaleConfigMoney::reset()
 {
-  KSimpleConfig ent(locate("locale", QString::fromLatin1("l10n/") + locale->money() + QString::fromLatin1("/entry.desktop")), true);
+  KSimpleConfig ent(locate("locale",
+			   QString::fromLatin1("l10n/%1/entry.desktop")
+			   .arg(locale->country())), true);
   ent.setGroup(QString::fromLatin1("KCM Locale"));
 
   locale->setCurrencySymbol(ent.readEntry(QString::fromLatin1("CurrencySymbol"), QString::fromLatin1("$")));
   locale->setMonetaryDecimalSymbol(ent.readEntry(QString::fromLatin1("MonetaryDecimalSymbol"), QString::fromLatin1(".")));
-  locale->setMonetaryThousandsSeparator(ent.readEntry(QString::fromLatin1("MonetaryThousandsSeparator"), QString::fromLatin1(",")));
+  QString str = ent.readEntry(QString::fromLatin1("MonetaryThousandsSeparator"), QString::fromLatin1(","));
+  str.replace(QRegExp(QString::fromLatin1("$0")), QString::null);
+  locale->setMonetaryThousandsSeparator(str);
   locale->setFracDigits(ent.readNumEntry(QString::fromLatin1("FractDigits"), 2));
   locale->setPositivePrefixCurrencySymbol(ent.readBoolEntry(QString::fromLatin1("PositivePrefixCurrencySymbol"), true));
   locale->setNegativePrefixCurrencySymbol(ent.readBoolEntry(QString::fromLatin1("NegativePrefixCurrencySymbol"), true));
