@@ -24,8 +24,8 @@ public:
   virtual void loadSettings();
   virtual void applySettings();
 
-public slots:
-  virtual void slotThemeChanged( Theme *theme);
+protected slots:
+  virtual void slotThemeChanged();
 
 protected:
   QLabel *lblTheme, *lblAuthor, *lblVersion, *lblHomepage;
