@@ -16,16 +16,15 @@
 #include <qlabel.h>
 #include <qpixmap.h>
 #include <qpushbt.h>
-#include <qfiledlg.h>
 #include <qslider.h>
 #include <qradiobt.h>
-#include <qmsgbox.h>
 #include <qscrbar.h>
 #include <qdrawutl.h>
 #include <qchkbox.h>
 #include <qcombo.h>
 #include <kapp.h>
-#include <kmsgbox.h>
+#include <kmessagebox.h>
+#include <kipc.h>
 
 #include <X11/Xlib.h>
 #include <X11/X.h>
@@ -48,11 +47,6 @@
 #endif
 
 
-int dropError(Display *, XErrorEvent *)
-{
-  return 0;
-}
-
 WidgetCanvas::WidgetCanvas( QWidget *parent)
   : QWidget( parent  )
 {
@@ -244,11 +238,6 @@ KColorScheme::KColorScheme( QWidget *parent, int mode, int desktop )
   if ( mode == Init )
     return;
 	
-  kde_display = x11Display();
-  KDEChangePalette = XInternAtom( kde_display, "KDEChangePalette", False);
-  screen = DefaultScreen(kde_display);
-  root = RootWindow(kde_display, screen);
-    
   setName( i18n("Color Scheme") );
 	
   sampleWidgets = new WidgetCanvas( this );
@@ -370,16 +359,16 @@ void KColorScheme::slotSave()
     // against dereferencing null pointers
 		
     if ( str == "KDE Default" ) {
-      KMsgBox::message(0,  i18n("Error"), 
-		       i18n( "You have chosen a name used by a supplied color scheme"), 2 );
+      KMessageBox::sorry(0, i18n("You have chosen a name used by a "
+                                 "supplied color scheme"));
       return;
     }
 		
     int i;
     for ( i = 1; it.current(); ++it ) {
       if ( str == it.current() && i <= SUPPLIED_SCHEMES) {
-	KMsgBox::message(0, i18n("Error"), 
-	i18n( "You have chosen a name used by a supplied color scheme"), 2 );
+          KMessageBox::sorry(0, i18n("You have chosen a name used by a "
+                                     "supplied color scheme"));
 	return;
       }
       i++;
@@ -690,17 +679,16 @@ void KColorScheme::readSettings( int )
   else {
     schemes = 0;
     if(
-       QMessageBox::query(i18n("Display Setup"),
-			  i18n("No desktop color schemes were found.\nDo you want to install the default color schemes now ?"), 
-			  i18n("Yes"), 
-			  i18n("No") )
-       ) {
-      installSchemes();
-      config = KApplication::getKApplication()->getConfig();
-      config->setGroup( "ColorSchemeInfo" );
-      str = config->readEntry( "Number" );
-      if ( !str.isNull() )
-	schemes = atoi(str.data());
+       KMessageBox::questionYesNo(this,
+                                  i18n("No desktop color schemes were found.\n"
+                                       "Do you want to install the default color schemes now ?"))
+       == KMessageBox::Yes) {
+        installSchemes();
+        config = KApplication::getKApplication()->getConfig();
+        config->setGroup( "ColorSchemeInfo" );
+        str = config->readEntry( "Number" );
+        if ( !str.isNull() )
+            schemes = atoi(str.data());
     }
 			
   }
@@ -881,37 +869,8 @@ void KColorScheme::apply( bool  )
   if ( !changed )
     return;
 	
-  XEvent ev;
-  unsigned int i, nrootwins;
-  Window dw1, dw2, *rootwins;
-  int (*defaultHandler)(Display *, XErrorEvent *);
+  KIPC::sendMessageAll("KDEChangePalette");
 
-
-  defaultHandler=XSetErrorHandler(dropError);
-	
-  XQueryTree(kde_display, root, &dw1, &dw2, &rootwins, &nrootwins);
-	
-  // Matthias
-  Atom a = XInternAtom(qt_xdisplay(), "KDE_DESKTOP_WINDOW", False);
-  for (i = 0; i < nrootwins; i++) {
-    long result = 0;
-    getSimpleProperty(rootwins[i],a, result);
-    if (result){
-      ev.xclient.type = ClientMessage;
-      ev.xclient.display = kde_display;
-      ev.xclient.window = rootwins[i];
-      ev.xclient.message_type = KDEChangePalette;
-      ev.xclient.format = 32;
-	    
-      XSendEvent(kde_display, rootwins[i] , False, 0L, &ev);
-    }
-  }
-
-  XFlush(kde_display);
-  XSetErrorHandler(defaultHandler);
-	
-  XFree((void *) rootwins);
-	
   changed=FALSE;
 }
 
