@@ -1,6 +1,6 @@
 /* vi: ts=8 sts=4 sw=4
  *
- * $Id: bgmanager.cc,v 1.33 2000/05/01 23:58:53 waba Exp $
+ * $Id: bgmanager.cc,v 1.37 2000/06/06 21:43:17 wgreven Exp $
  *
  * This file is part of the KDE project, module kdesktop.
  * Copyright (C) 1999 Geert Jansen <g.t.jansen@stud.tue.nl>
@@ -30,6 +30,7 @@
 #include <kwm.h>
 #include <kwin.h>
 #include <kapp.h>
+#include <kdebug.h>
 #include <kipc.h>
 #include <kpixmap.h>
 #include <kpopupmenu.h>
@@ -47,158 +48,12 @@
 template class QVector<KBackgroundRenderer>;
 template class QVector<KBackgroundCacheEntry>;    
 
-/**** KBackgroundDockWidget ****/
-
-
-KBackgroundDockWidget::KBackgroundDockWidget()
-{
-    m_bCommon = m_bExport = false;
-
-    m_pMainMenu = new KPopupMenu(this);
-    m_pMainMenu->insertTitle(SmallIcon("background"), i18n("Desktop Background"));
-    m_pMainMenu->insertItem(i18n("Background Settings"), this,
-	    SLOT(slotBackgroundSettings()));
-    m_pMainMenu->insertItem(i18n("Advanced Settings"), this,
-	    SLOT(slotAdvancedSettings()));
-    m_pMainMenu->insertSeparator();
-    m_Common = m_pMainMenu->insertItem(i18n("Common Background"),
-	    this, SLOT(slotCommon()));
-    m_Export = m_pMainMenu->insertItem(i18n("Export Background"),
-	    this, SLOT(slotExport()));
-    m_pMainMenu->insertSeparator();
-    m_pMainMenu->insertItem(i18n("Undock"), this, SLOT(slotUndock()));
-
-    m_pModeMenu = new KPopupMenu(this);
-    m_pModeMenu->insertTitle(SmallIcon("background"), i18n("Arrangement"));
-    m_pModeMenu->insertItem(i18n("Centred"), KBackgroundSettings::Centred);
-    m_pModeMenu->insertItem(i18n("Tiled"), KBackgroundSettings::Tiled);
-    m_pModeMenu->insertItem(i18n("CenterTiled"), KBackgroundSettings::CenterTiled);
-    m_pModeMenu->insertItem(i18n("Maxpect"), KBackgroundSettings::CentredMaxpect);
-    m_pModeMenu->insertItem(i18n("Scaled"), KBackgroundSettings::Scaled);
-    connect(m_pModeMenu, SIGNAL(activated(int)), SLOT(slotModeSelected(int)));
-
-    setPixmap(SmallIcon("background"));
-    setAlignment(AlignCenter);
-    setAcceptDrops(true);
-
-    QToolTip::add(this, i18n("Desktop Background"));
-    QWhatsThis::add(this, i18n(
-	    "<qt><h2>Desktop background control</h2>\n"
-	    "You can control some features of the desktop background with \n"
-	    "this dock window. You can:\n"
-	    "<ul><li>Left click on it. This will change the wallpaper if \n"
-	    "you are using multi wallpaper mode.</li>\n"
-	    "<li>Right click on it. This will give you a context menu where \n"
-	    "you can set export, common and docking mode.</li>\n"
-	    "<li>Drop an image onto it. This will set the image as the desktop \n"
-	    "wallpaper.</li></ul></qt>"));
-}
-
-
-/*
- * Drag enter event: accept if it's an image.
- */
-void KBackgroundDockWidget::dragEnterEvent(QDragEnterEvent *e)
-{
-    if (QUriDrag::canDecode(e))
-	e->accept(rect());
-    else
-	e->ignore(rect());
-}
-
-/*
- * Handle a wallpaper dropped on the docking icon.
- */
-void KBackgroundDockWidget::dropEvent(QDropEvent *e)
-{
-    QStringList uris;
-
-    if (QUriDrag::decodeLocalFiles(e, uris) && (uris.count() > 0)) {
-        m_Wallpaper = *uris.begin();
-        m_pModeMenu->popup(mapToGlobal(e->pos()));
-        m_pModeMenu->exec();
-    }
-}
-
-
-void KBackgroundDockWidget::mousePressEvent(QMouseEvent *e)
-{
-    if (e->button() == LeftButton) {
-	emit changeWallpaper();
-        return;
-    }
-    if (e->button() == RightButton) {
-        m_pMainMenu->popup(mapToGlobal(e->pos()));
-        m_pMainMenu->exec();
-    }
-}
-
-
-void KBackgroundDockWidget::slotModeSelected(int m)
-{
-    emit wallpaperDropped(m_Wallpaper, m);
-}
-
-
-void KBackgroundDockWidget::slotUndock()
-{
-    emit unDocked();
-}
-
-
-void KBackgroundDockWidget::slotCommon()
-{
-    m_bCommon = !m_bCommon;
-    m_pMainMenu->setItemChecked(m_Common, m_bCommon);
-    emit commonChanged(m_bCommon);
-}
-
-
-void KBackgroundDockWidget::slotExport()
-{
-    m_bExport = !m_bExport;
-    m_pMainMenu->setItemChecked(m_Export, m_bExport);
-    emit exportChanged(m_bExport);
-}
-
-
-void KBackgroundDockWidget::setCommon(bool common)
-{
-    m_bCommon = common;
-    m_pMainMenu->setItemChecked(m_Common, m_bCommon);
-}
-
-
-void KBackgroundDockWidget::setExport(bool _export)
-{
-    m_bExport = _export;
-    m_pMainMenu->setItemChecked(m_Export, m_bExport);
-}
-
-
-void KBackgroundDockWidget::slotBackgroundSettings()
-{
-    KShellProcess proc;
-    proc << "kcmshell LookNFeel/Desktop/background";
-    proc.start(KShellProcess::DontCare);
-}
-
-
-void KBackgroundDockWidget::slotAdvancedSettings()
-{
-    KShellProcess proc;
-    proc << "kcmshell LookNFeel/Desktop/advanced";
-    proc.start(KShellProcess::DontCare);
-}
-
-
 /**** KBackgroundManager ****/
 
-
-
 KBackgroundManager::KBackgroundManager(QWidget *desktop, KWinModule* kwinModule)
     : DCOPObject("KBackgroundIface")
 {
+    m_bBgInitDone = false;
     if (desktop == 0L)
         m_pDesktop = QApplication::desktop();
     else
@@ -214,7 +69,7 @@ KBackgroundManager::KBackgroundManager(QWidget *desktop, KWinModule* kwinModule)
 
     m_Serial = 0; m_Hash = 0;
     m_pConfig = KGlobal::config();
-    m_bDock = m_bExport = m_bCommon = m_bInit = false;
+    m_bExport = m_bCommon = m_bInit = false;
     m_pKwinmodule = kwinModule;
     m_pPixmapServer = new KPixmapServer();
 
@@ -227,14 +82,6 @@ KBackgroundManager::KBackgroundManager(QWidget *desktop, KWinModule* kwinModule)
         connect(m_Renderer[i], SIGNAL(imageDone(int)), SLOT(slotImageDone(int)));
     }
 
-    m_pDockWidget = new KBackgroundDockWidget();
-    connect(m_pDockWidget, SIGNAL(wallpaperDropped(QString,int)),
-	    SLOT(slotWallpaperDropped(QString,int)));
-    connect(m_pDockWidget, SIGNAL(changeWallpaper()), SLOT(slotChangeWallpaper()));
-    connect(m_pDockWidget, SIGNAL(unDocked()), SLOT(slotUnDocked()));
-    connect(m_pDockWidget, SIGNAL(exportChanged(bool)), SLOT(slotExport(bool)));
-    connect(m_pDockWidget, SIGNAL(commonChanged(bool)), SLOT(slotCommon(bool)));
-
     configure();
 
     m_pTimer = new QTimer(this);
@@ -253,7 +100,6 @@ KBackgroundManager::~KBackgroundManager()
     
     delete m_pConfig;
     delete m_pPixmapServer;
-    delete m_pDockWidget;
     delete m_pTimer;
 
     if (m_bExport)
@@ -264,19 +110,6 @@ KBackgroundManager::~KBackgroundManager()
 }
 
 
-void KBackgroundManager::applyDocking(bool dock)
-{
-    if (dock == m_bDock)
-	return;
-    m_bDock = dock;
-
-    if (m_bDock && m_bInit)
-	m_pDockWidget->show();
-    else
-	m_pDockWidget->hide();
-}
-
-
 void KBackgroundManager::applyExport(bool exp)
 {
     if (exp == m_bExport)
@@ -292,7 +125,6 @@ void KBackgroundManager::applyExport(bool exp)
 	m_Hash = 0;
 
     m_bExport = exp;
-    m_pDockWidget->setExport(m_bExport);
 }
 
 
@@ -310,8 +142,6 @@ void KBackgroundManager::applyCommon(bool common)
 	for (unsigned i=1; i<m_Cache.size(); i++)
 	    removeCache(i);
     }
-
-    m_pDockWidget->setCommon(m_bCommon);
 }
 
 
@@ -342,7 +172,6 @@ void KBackgroundManager::configure()
     m_pConfig->reparseConfiguration();
     m_pConfig->setGroup("Background Common");
 
-    applyDocking(m_pConfig->readBoolEntry("Dock", _defDock));
     applyExport(m_pConfig->readBoolEntry("Export", _defExport));
     applyCommon(m_pConfig->readBoolEntry("CommonDesktop", _defCommon));
 
@@ -493,7 +322,7 @@ void KBackgroundManager::renderBackground(int desk)
 {
     KBackgroundRenderer *r = m_Renderer[desk];
     if (r->isActive()) {
-        qDebug("renderer %d already active", desk);
+        kdDebug() << "renderer " << desk << " already active" << endl;
         return;
     }
 
@@ -521,7 +350,14 @@ void KBackgroundManager::slotImageDone(int desk)
     // If current: paint it
     bool current = (r->hash() == m_Renderer[effectiveDesktop()]->hash());
     if (current)
+    {
         setPixmap(pm, r->hash(), desk);
+        if (!m_bBgInitDone)
+        {
+            m_bBgInitDone = true;
+            emit initDone();
+        }
+    }
     if (m_bExport || !m_bCommon)
 	addCache(pm, r->hash(), desk);
     if (current)
@@ -648,12 +484,6 @@ void KBackgroundManager::slotWallpaperDropped(QString wallpaper, int mode)
 }
 
 
-void KBackgroundManager::slotUnDocked()
-{
-    setDocking(false);
-}
-
-
 void KBackgroundManager::slotExport(bool _export)
 {
     setExport(_export);
@@ -666,16 +496,6 @@ void KBackgroundManager::slotCommon(bool common)
 }
 
 
-// DCOP exported
-void KBackgroundManager::setDocking(int dock)
-{
-    applyDocking(dock);
-    m_pConfig->setGroup("Background Common");
-    m_pConfig->writeEntry("Dock", m_bDock);
-    m_pConfig->sync();
-}
-
-
 // DCOP exported
 void KBackgroundManager::setExport(int _export)
 {
@@ -704,17 +524,6 @@ void KBackgroundManager::setCommon(int common)
  */
 void KBackgroundManager::slotTimeout()
 {
-    // First time init. It's done this way because kdesktop starts before
-    // kicker and it needs the latter for docking. Hacky indeed....
-
-    if (!m_bInit) {
-	m_bInit = true;
-	if (m_bDock)
-	    m_pDockWidget->show();
-	m_pTimer->start(60000);
-	return;
-    }
-
     for (unsigned i=0; i<m_Renderer.size(); i++) {
         KBackgroundRenderer *r = m_Renderer[i];
         bool change = false;
