@@ -56,6 +56,7 @@
 #include <kglobalaccel.h>
 #include <kwinmodule.h>
 #include <krun.h>
+#include <kdesktopfile.h>
 
 #include <kwm.h>
 // root window hack
@@ -125,28 +126,12 @@ KDesktop::KDesktop( const QString& _url, bool x_root_hack, bool auto_start, bool
     setGeometry( QApplication::desktop()->geometry() );
 
   // Geert Jansen: backgroundmanager belongs here
-  new KBackgroundManager(viewport(), m_pKwinmodule );
+  KBackgroundManager *bgMgr = new KBackgroundManager(viewport(), m_pKwinmodule );
+  connect( bgMgr, SIGNAL( initDone()), SLOT( backgroundInitDone()));
 
   lower();
-  show();
 
   splash = 0;
-  if (m_bWaitForKded)
-  {
-     splash = new QFrame(0, "intro_splash",
-	WStyle_Customize | WStyle_StaysOnTop | WStyle_NoBorder
-			 | WDestructiveClose );
-     splash->setFrameStyle( QFrame::Box | QFrame::Raised );
-     splash->setLineWidth(2);
-     KWM::setDecoration( splash->winId(), KWM::noDecoration );
-     QPixmap pm( locate("data", "kdesktop/pics/splash.png"));
-     splash->setBackgroundPixmap(pm);
-     int x = (QApplication::desktop()->width()- pm.width())/2;
-     int y = (QApplication::desktop()->height()- pm.height())/2;
-     splash->move(x,y);
-     splash->setFixedSize( pm.size());
-     splash->show();
-  }
 
   connect( this, SIGNAL( executed( QIconViewItem * ) ),
            SLOT( slotReturnPressed( QIconViewItem * ) ) );
@@ -168,6 +153,33 @@ KDesktop::KDesktop( const QString& _url, bool x_root_hack, bool auto_start, bool
      QTimer::singleShot(100, this, SLOT( slotStart()));
 
   m_dotDirectory = 0;
+
+  connect( kapp, SIGNAL( shutDown() ),
+	   this, SLOT( slotSaveIconPositions() ) );
+}
+
+void
+KDesktop::backgroundInitDone()
+{
+  show();
+  if (m_bWaitForKded)
+  {
+     splash = new QFrame(0, "intro_splash",
+	WStyle_Customize | WStyle_StaysOnTop | WStyle_NoBorder
+			 | WDestructiveClose );
+     splash->setFrameStyle( QFrame::Box | QFrame::Raised );
+     splash->setLineWidth(2);
+     KWM::setDecoration( splash->winId(), KWM::noDecoration );
+     QPixmap pm( locate("data", "kdesktop/pics/splash.png"));
+     splash->setBackgroundPixmap(pm);
+     int x = (QApplication::desktop()->width()- pm.width())/2;
+     int y = (QApplication::desktop()->height()- pm.height())/2;
+     splash->move(x,y);
+     splash->setFixedSize( pm.size());
+     splash->show();
+     if (!m_bInit)
+        QTimer::singleShot(3000, this, SLOT( slotSplashDone()));
+  }
 }
 
 void
@@ -197,6 +209,8 @@ KDesktop::slotStart()
            this, SLOT( slotNewItems( const KFileItemList & ) ) );
   connect( m_dirLister, SIGNAL( deleteItem( KFileItem * ) ),
            this, SLOT( slotDeleteItem( KFileItem * ) ) );
+  connect( m_dirLister, SIGNAL( refreshItems( const KFileItemList & ) ),
+           this, SLOT( slotRefreshItems( const KFileItemList & ) ) );
 
   // Start the directory lister !
   m_dirLister->openURL( m_url, m_bShowDot );
@@ -223,7 +237,8 @@ KDesktop::slotStart()
   (void) new KAction( i18n( "&Delete" ), deleteAction==2 ? deleteKey : 0, this, SLOT( slotDelete() ), &m_actionCollection, "del" );
   (void) new KAction( i18n( "&Shred" ), deleteAction==3 ? deleteKey : 0, this, SLOT( slotShred() ), &m_actionCollection, "shred" );
 
-  QTimer::singleShot(3000, this, SLOT( slotSplashDone()));
+  if (splash)
+     QTimer::singleShot(3000, this, SLOT( slotSplashDone()));
 
   new KRootWm( this ); // handler for root menu (used by kdesktop on RMB click)
 
@@ -308,6 +323,13 @@ void KDesktop::rearrangeIcons( int bAsk )
   slotSaveIconPositions();
 }
 
+// -----------------------------------------------------------------------------
+
+void KDesktop::lineupIcons()
+{
+  KonqIconViewWidget::lineupIcons();
+  slotSaveIconPositions();
+}
 
 // -----------------------------------------------------------------------------
 
@@ -383,8 +405,10 @@ void KDesktop::slotReturnPressed( QIconViewItem *item )
 {
   kapp->propagateSessionManager();
   m_lastIcon = 0L; // user action -> not renaming an icon
-  if (item)
+  if (item) {
+    visualActivate(item);
     ((KFileIVI*)item)->returnPressed();
+  }
 }
 
 // -----------------------------------------------------------------------------
@@ -509,7 +533,7 @@ void KDesktop::slotNewItems( const KFileItemList & entries )
     if ( m_dotDirectory )
     {
       QString group = m_iconPositionGroupPrefix;
-      group.append( it.current()->url().filename() );
+      group.append( it.current()->url().fileName() );
       //kdDebug() << "slotNewItems : looking for group " << group << endl;
       if ( m_dotDirectory->hasGroup( group ) )
       {
@@ -525,6 +549,25 @@ void KDesktop::slotNewItems( const KFileItemList & entries )
     m_lastIcon = fileIVI;
 }
 
+// -----------------------------------------------------------------------------
+
+void KDesktop::slotRefreshItems( const KFileItemList & entries )
+{
+    KFileItemListIterator rit(entries);
+    for (; rit.current(); ++rit)
+    {
+        QIconViewItem *it = firstItem();
+        for ( ; it ; it = it->nextItem() )
+        {
+            KFileIVI * fileIVI = static_cast<KFileIVI *>(it);
+            if ( fileIVI->item() == rit.current() ) // compare the pointers
+            {
+                fileIVI->refreshIcon( true );
+                break;
+            }
+        }
+    }
+}
 
 // -----------------------------------------------------------------------------
 
@@ -578,6 +621,7 @@ void KDesktop::slotCompleted()
     }
 
     slotSaveIconPositions();
+    viewport()->repaint();
 }
 
 // -----------------------------------------------------------------------------
@@ -604,8 +648,8 @@ void KDesktop::slotSaveDropPosition( QDropEvent *ev, const QValueList<QIconDragI
             if ( lst.count() == 1 )
             {
                 KURL u = lst.first();
-                kdDebug() << "Saving drop position for " << u.filename() << " at " << ev->pos().x() << "," << ev->pos().y() << endl;
-                m_dotDirectory->setGroup( QString( m_iconPositionGroupPrefix ).append( u.filename() ) );
+                kdDebug() << "Saving drop position for " << u.fileName() << " at " << ev->pos().x() << "," << ev->pos().y() << endl;
+                m_dotDirectory->setGroup( QString( m_iconPositionGroupPrefix ).append( u.fileName() ) );
                 m_dotDirectory->writeEntry( "X", ev->pos().x() );
                 m_dotDirectory->writeEntry( "Y", ev->pos().y() );
             }
@@ -646,8 +690,9 @@ void KDesktop::viewportWheelEvent( QWheelEvent * e )
 
 void KDesktop::clientAreaUpdated(QRect r)
 {
-//  qDebug("KDesktop::clientAreaAdjusted(%d, %d, %d, %d)", r.left(), r.right(), r.top(), r.bottom());
-  setGeometry(r);
+  // disabled until this is discussed
+//  kdDebug() << "KDesktop::clientAreaAdjusted(" << r.left() << ", " << r.right() << ", " << r.top() << ", " << r.bottom() << ")" << endl;
+//  setGeometry(r);
 }
 
 #include "desktop.moc"
