@@ -53,6 +53,10 @@ public:
    * @param bAsk if true a confirmation is asked first
    */
   virtual void rearrangeIcons( int bAsk );
+  /**
+   * Lineup the desktop icons.
+   */
+  virtual void lineupIcons();
   /**
    * Select icons in the rectangle given
    */
@@ -83,11 +87,18 @@ public:
 
   virtual void clientAreaUpdated(QRect);
 
+  virtual DCOPRef background() { return DCOPRef( "kdesktop", "KBackgroundIface" ); }
+  virtual DCOPRef screenSaver() { return DCOPRef( "kdesktop", "KScreensaverIface" ); }
 
   KWinModule* kwinModule() const { return m_pKwinmodule; }
 
 protected slots:
 
+  /**
+   * Background is ready.
+   */
+  void backgroundInitDone();
+
   /**
    * Activate the desktop.
    */
@@ -124,6 +135,7 @@ protected slots:
   void slotCompleted();
   void slotNewItems( const KFileItemList& );
   void slotDeleteItem( KFileItem * );
+  void slotRefreshItems( const KFileItemList& );
 
   // slots connected to the popupmenu (actions)
   void slotCut();
