@@ -36,6 +36,7 @@
 int ignoreXError(Display *, XErrorEvent *);
 static Window gVRoot = 0;
 static Atom   gXA_VROOT;
+static Atom   gXA_SCREENSAVER_VERSION;
 
 //===========================================================================
 //
@@ -80,6 +81,11 @@ SaverEngine::SaverEngine()
 
     // virtual root property
     gXA_VROOT = XInternAtom (qt_xdisplay(), "__SWM_VROOT", False);
+    gXA_SCREENSAVER_VERSION = XInternAtom (qt_xdisplay(), "_SCREENSAVER_VERSION", False);
+
+    XWindowAttributes attrs;
+    XGetWindowAttributes(qt_xdisplay(), winId(), &attrs);
+    mColorMap = attrs.colormap;
 
     createSaverWindow();
 
@@ -163,7 +169,7 @@ void SaverEngine::configure()
 
     mEnabled  = config->readBoolEntry("Enabled", false);
     mLock     = config->readBoolEntry("Lock", false);
-    mPriority = config->readNumEntry("Priority", 0);
+    mPriority = config->readNumEntry("Priority", 19);
     if (mPriority < 0) mPriority = 0;
     if (mPriority > 19) mPriority = 19;
     int timeout = config->readNumEntry("Timeout", 300);
@@ -225,13 +231,15 @@ void SaverEngine::readSaver(QString saver)
 //
 void SaverEngine::createSaverWindow()
 {
-    XWindowAttributes attrs;
-    XGetWindowAttributes(qt_xdisplay(), winId(), &attrs);
-    mColorMap = attrs.colormap;
-
     // We only create the window once, but we reset its attributes every
     // time.
 
+    // Some xscreensaver hacks check for this property
+    const char *version = "KDE 2.0";
+    XChangeProperty (qt_xdisplay(), winId(),
+                     gXA_SCREENSAVER_VERSION, XA_STRING, 8, PropModeReplace,
+                     (unsigned char *) version, strlen(version));
+
     // Set virtual root property
     saveVRoot();
     if (gVRoot)
