@@ -1,6 +1,6 @@
     /*
 
-    $Id: kdm-config.h,v 1.16 1999/12/12 18:00:44 jdolecek Exp $
+    $Id: kdm-config.h,v 1.17 2000/05/15 08:58:51 porten Exp $
 
     Copyright (C) 1997, 1998 Steffen Hansen
                              stefh@mip.ou.dk
@@ -93,7 +93,7 @@
 #ifdef __cplusplus
 extern "C" {
 #endif
-//int XdmcpAllocARRAY8();
+  /* int XdmcpAllocARRAY8(); */
 int Debug( char*, ...);
 int LogError( char*, ...);
 int LogOutOfMem( char*, ...);
