@@ -1,6 +1,6 @@
     /*
 
-    $Id: kdmusers.h,v 1.2 1998/09/04 15:33:01 bieker Exp $
+    $Id: kdmusers.h,v 1.4 2000/04/19 20:24:05 bieker Exp $
 
     Copyright (C) 1997, 1998 Steffen Hansen
                              stefh@mip.ou.dk
@@ -22,6 +22,8 @@
 
     */
  
+#ifndef _KDMUSERS_H_
+#define _KDMUSERS_H_
 
 # include "kdm-config.h"
 
@@ -29,8 +31,10 @@
 
 class KDMUserItem : public KDMViewItem {
 public:
-     setName( const char* name) { user_name = QString( name);}
-     const char* name() { return user_name.data()} cont;
+     setName( const QString &name) { user_name = name; }
+     const QString &name() { return user_name } const;
 private:
      QString user_name;
 };
+
+#endif // _KDMUSERS_H_
