@@ -1,6 +1,6 @@
 /* $XConsortium: policy.c,v 1.12 94/04/17 20:03:41 hersh Exp $ */
 /* $XFree86: xc/programs/xdm/policy.c,v 3.0 1994/06/28 12:32:38 dawes Exp $ */
-/* $Id: policy.c,v 1.6 1999/11/17 00:12:07 steffen Exp $ */
+/* $Id: policy.c,v 1.7 2000/05/23 12:28:54 kulow Exp $ */
 /*
 
 Copyright (c) 1988  X Consortium
@@ -197,7 +197,7 @@ static void Willing_msg( char* mbuf)
 
 	mbuf[255] = 0;
    }
-#elif BSD4_3
+#elif HAVE_GETLOADAVG
 #warning This code is untested...
      double load[3];
      getloadavg(load, 3);
