@@ -1,6 +1,6 @@
 /* $XConsortium: xdmcp.c,v 1.15 94/09/19 20:16:38 converse Exp $ */
 /* $XFree86: xc/programs/xdm/xdmcp.c,v 3.2 1995/01/12 05:57:08 dawes Exp $ */
-/* $Id: xdmcp.c,v 1.5 2000/04/21 20:37:31 waba Exp $ */
+/* $Id: xdmcp.c,v 1.6 2000/05/17 06:31:16 hoelzer Exp $ */
 /*
 
 Copyright (c) 1988  X Consortium
@@ -1136,7 +1136,7 @@ void send_failed (from, fromlen, name, sessionID, reason)
     XdmcpHeader	header;
     ARRAY8	status;
 
-    sprintf (buf, "Session %d failed for display %s: %s",
+    snprintf (buf, sizeof(buf), "Session %d failed for display %s: %s",
 	     (int)sessionID, name, reason);
     Debug ("Send failed %d %s\n", sessionID, buf);
     status.length = strlen (buf);
