@@ -78,9 +78,10 @@ void createHelpWindow(const QCString &appId)
 
   f.close();
 
-  kDebugInfo( "Calling stub.createBrowserWindowFromProfile" );
+  kdDebug() << "Calling stub.createBrowserWindowFromProfile\n";
   KonquerorIface_stub stub( appId, "KonquerorIface" );
   stub.createBrowserWindowFromProfile( tempProfile );
+  kdDebug() << "Call done\n";
 }
 
 
@@ -129,7 +130,7 @@ int main(int argc, char *argv[])
     if ((*it).left(9) == "konqueror")
       {
 	createHelpWindow(*it);
-	exit(0);
+	return 0;
       }
 
   // run a new konqueror instance
@@ -142,7 +143,7 @@ int main(int argc, char *argv[])
       return 1;
     }
 
-  app.exec();
+  return app.exec();
 }
 
 #include "khc_main.moc"
