@@ -72,11 +72,16 @@ AppletArea::AppletArea( Orientation orient, QWidget* parent, const char* name)
   
   KConfig* config = KGlobal::config();
   config->setGroup("layout");
-  if(!config->hasKey("applets")) // default layout
+  if(!config->hasKey("appletpositions")) // default layout
     {
       // kmenu
       KMenuButtonContainer *kmenu = new KMenuButtonContainer(viewport());
       addApplet(kmenu);
+
+	  // window list
+	  WindowListButtonContainer *wlist = new WindowListButtonContainer(viewport());
+      wlist->setFreeSpace(0.02);
+	  addApplet(wlist);
       
       QString appPath = KGlobal::dirs()->resourceDirs("apps").last();
       
@@ -84,50 +89,53 @@ AppletArea::AppletArea( Orientation orient, QWidget* parent, const char* name)
       URLButtonContainer *url;
 
       url = new URLButtonContainer(appPath + "/Home.desktop", viewport());
-      url->setFreeSpace(10);
+      url->setFreeSpace(0.04);
       addApplet(url);
 
       url = new URLButtonContainer(appPath + "/System/konsole.desktop", viewport());
-      url->setFreeSpace(0);
+      url->setFreeSpace(0.04);
+      addApplet(url);
+
+      url = new URLButtonContainer(appPath + "/KControl.desktop", viewport());
+      url->setFreeSpace(0.04);
       addApplet(url);
 
       url = new URLButtonContainer(appPath + "/Help.desktop", viewport());
-      url->setFreeSpace(0);
+      url->setFreeSpace(0.04);
+      addApplet(url);
+
+      url = new URLButtonContainer(appPath + "/Editors/kwrite.desktop", viewport());
+      url->setFreeSpace(0.04);
       addApplet(url);
-      
-      // system control quickbrowser button
-      BrowserButtonContainer *browser = new BrowserButtonContainer(appPath + "/Control/", viewport());
-      browser->setFreeSpace(0);
-      addApplet(browser);
 
       // pager applet
       InternalFrame *pager = new InternalFrame("kminipagerapplet",
                                                "kminipagerapplet.desktop", viewport());
-      pager->setFreeSpace(10);
+      pager->setFreeSpace(0.2);
       addApplet(pager);
 
       // taskbar applet
       InternalFrame *taskbar = new InternalFrame("ktaskbarapplet",
                                                  "ktaskbarapplet.desktop", viewport());
-      taskbar->setFreeSpace(10);
+      taskbar->setFreeSpace(0.3);
       addApplet(taskbar);
 
       // dock applet
       InternalFrame *dock = new InternalFrame("kdockapplet",
                                               "kdockapplet.desktop", viewport());
-      dock->setFreeSpace(70);
+      dock->setFreeSpace(1);
       addApplet(dock);
 
       // date applet
       InternalFrame *date = new InternalFrame("kdateapplet",
                                                "kdateapplet.desktop", viewport());
-      date->setFreeSpace(0);
+      date->setFreeSpace(1);
       addApplet(date);
     }
   else // restore layout
     {
       // read layout stringlist
-      QStringList appletLayout = config->readListEntry("applets");
+      QStringList appletLayout = config->readListEntry("appletpositions");
 
       // now restore the applets
       QStringList::Iterator it;
@@ -166,6 +174,8 @@ AppletArea::AppletArea( Orientation orient, QWidget* parent, const char* name)
           // create a matching applet container
           if (appletId.contains("KMenuButton") > 0)
             a = new KMenuButtonContainer(viewport());
+          if (appletId.contains("WindowListButton") > 0)
+            a = new WindowListButtonContainer(viewport());
           else if (appletId.contains("URLButton") > 0)
             a = new URLButtonContainer(data, viewport());
           else if (appletId.contains("BrowserButton") > 0)
@@ -180,11 +190,11 @@ AppletArea::AppletArea( Orientation orient, QWidget* parent, const char* name)
               QString command = data;
               command.truncate(index);
               freepos = (data.mid(index + 13)).toInt();
-
+              
               KProcess process;
-              process << command;
+              process << command << QString("--appletId") << appletId;
               process.start(KProcess::DontCare);
-
+              
             }
      
           if (a) {
@@ -253,6 +263,14 @@ void AppletArea::addKMenuButton()
   saveAppletConfig();
 }
 
+void AppletArea::addWindowListButton()
+{
+  WindowListButtonContainer *b = new WindowListButtonContainer(viewport());
+  addApplet(b);
+  moveToFirstFreePosition(b);
+  saveAppletConfig();
+}
+
 void AppletArea::addURLButton(const QString &url)
 {
   URLButtonContainer *b = new URLButtonContainer(url, viewport());
@@ -311,10 +329,13 @@ void AppletArea::addApplet(AppletContainer* a)
   if (a->inherits("ExternalFrame"))
       connect(a, SIGNAL(embeddedWindowDestroyed() ), this,
 			  SLOT( embeddedWindowDestroyed()));
-
   if (a->inherits("InternalFrame"))
     connect(a, SIGNAL(sigUpdateLayout() ), this,
 			  SLOT( slotLayoutChildren()));
+
+  a->setOrientation(orientation());
+  a->setPosition(PGlobal::panel->position());
+  a->configure();
 }
 
 void AppletArea::setUniqueId(AppletContainer* a)
@@ -367,7 +388,7 @@ void AppletArea::saveAppletConfig()
     }
   
   config->setGroup("layout");
-  config->writeEntry("applets", layoutList);
+  config->writeEntry("appletpositions", layoutList);
   config->sync();
 }
 
@@ -442,26 +463,12 @@ void AppletArea::stopAppletMove(AppletContainer *b)
   setCursor(arrowCursor);
   _movingAC = false;
   setMouseTracking(false);
-  AppletContainer *a = coversAppletContainer(_moveAC, true);
-  if (a)
-    {
-      int axmiddle = a->x() + a->width()/2;
-      int aymiddle = a->y() + a->height()/2;
-
-      if (orientation() == Horizontal) {
-        if (_moveAC->x() < axmiddle)
-          _moveAC->move(QPoint(a->x() - _moveAC->width() - 1, _moveAC->y()));
-        else
-          _moveAC->move(QPoint(a->x() + a->width() + 1, _moveAC->y()));
-      }
-      else {
-        if (_moveAC->y() < aymiddle)
-          _moveAC->move(QPoint(_moveAC->x(), a->y() - _moveAC->height() - 1));
-        else
-          _moveAC->move(QPoint(_moveAC->x(), a->y() + a->height() + 1));
-      }
-    }
   
+  // If the moving applet covers another applet it can be dropped on the
+  // dummywidget(shadow).
+  if ( coversAppletContainer(_moveAC, true) )
+    _moveAC->move(_dummyWidget->pos());
+ 
   if(_moveAC->inherits("ButtonContainer"))
     static_cast<ButtonContainer*>(_moveAC)->completeMoveOperation();
 
@@ -472,7 +479,7 @@ void AppletArea::stopAppletMove(AppletContainer *b)
 
   _block_relayout = false;
 
-  // Not necessary anymore when the move algorith is finished. 
+  // Not necessary anymore when the move algorithm is finished. 
   updateAppletContainerList();
   layoutChildren();
 
@@ -487,340 +494,346 @@ void AppletArea::mouseReleaseEvent(QMouseEvent *)
 
 void AppletArea::mouseMoveEvent(QMouseEvent *ev)
 {
-  if (_movingAC && _moveAC) {
+  if (!(_movingAC && _moveAC)) {
+    Panner::mouseMoveEvent(ev);
+    return;
+  }
+    
+  // horizontal panel
+  if (orientation() == Horizontal) {
 
-    // horizontal panel
-    if (orientation() == Horizontal) {
+    // calculate new position.
+    int x = ev->pos().x()-_moveAC->moveOffset().x();
+    
+    // make sure the new position is inside the appletarea
+    // scroll if needed
+    if (x < 0) {
+      x = 0;
+      //scrollBy( -10, 0 );
+    }
+    else if (x > width() - _moveAC->width()) {
+      x = width() - _moveAC->width();
+      //scrollBy( 10, 0 );
+    }
 
-      // calculate new position.
-      int x = ev->pos().x()-_moveAC->moveOffset().x();
+    // move the Applet to the calculated position, remember the old
+    // position.
+    int oldACx = _moveAC->x();
+    _moveAC->move(x, _moveAC->y());
+
+    if (oldACx < _moveAC->x()) { // left to right
+     
+      _applets.findRef(_moveAC);
+      AppletContainer *a = _applets.next();
+      AppletContainer *b = _moveAC;
+
+      while (a) 
+      {
+        if (isTopLevel(a)) {
+          a = _applets.next();
+          continue;
+        }
       
-      // make sure the new position is inside the appletarea
-      // scroll if needed
-      if (x < 0) {
-        x = 0;
-        //scrollBy( -10, 0 );
-      }
-      else if (x > width() - _moveAC->width()) {
-        x = width() - _moveAC->width();
-        //scrollBy( 10, 0 );
+        // '_moveAC' has completely passed applet 'a'.
+        if ( a->x() + a->width() <= _moveAC->x() ) {
+          a->move(a->x() - _moveAC->width(), a->y());
+          b = a;
+          a = _applets.next();
+          continue;
+        }
+        
+        // 'a' has not been completely passed by '_moveAC', but still may be
+        // covered by it.
+        int switchMargin = 0;
+          
+        // calculate the position and width of the 'virtual' container 
+        // containing moveAC and 'a'.
+        int tx = a->x() - _moveAC->width();
+        int twidth = _moveAC->width() + a->width();
+
+        // determine the middle of the containers.
+        int tmiddle = tx + twidth/2;
+        int moveACmiddle = _moveAC->x() + _moveAC->width()/2;
+        
+        // move 'a' from the right side of the virtual container to the left
+        // side if the middle of moveAC has moved far enough to the left, 
+        // i.e. past the middle of the virtual container plus the 
+        // switchMargin. The switchMargin prevents rapidly switching when 
+        // '_moveAC' and 'a' have the same size.
+        if (moveACmiddle >= tmiddle + switchMargin) {
+          a->move(a->x() - _moveAC->width(), a->y());
+          // store 'a', because it may become null in the next step.
+          b = a; 
+          a = _applets.next();
+          continue;
+        }
+
+        // '_moveAC' doesn't cover 'a', and hasn't passed it. We now know that
+        // this also yields for the rest of the applets, so break out of the
+        // loop.
+        break;
       }
 
-      // move the Applet to the calculated position, remember the old
-      // position.
-      int oldACx = _moveAC->x();
-      _moveAC->move(x, _moveAC->y());
-
-      if (oldACx < _moveAC->x()) { // left to right
-       
-        _applets.findRef(_moveAC);
-        AppletContainer *a = _applets.next();
-        AppletContainer *b = _moveAC;
- 
-        while (a) 
+      // visual feedback
+      AppletContainer *c = coversAppletContainer(_moveAC, true);
+      if (c)
         {
-          if (isTopLevel(a))
-            continue;
-        
-          // '_moveAC' has completely passed applet 'a'.
-          if ( a->x() + a->width() <= _moveAC->x() ) {
-            a->move(a->x() - _moveAC->width(), a->y());
-            b = a;
-            a = _applets.next();
-            continue;
-          }
+          int cxmiddle = c->x() + c->width()/2;
           
-          // 'a' has not been completely passed by '_moveAC', but still may be
-          // covered by it.
-          int switchMargin = 0;
-            
-          // calculate the position and width of the 'virtual' container 
-          // containing moveAC and 'a'.
-          int tx = a->x() - _moveAC->width();
-          int twidth = _moveAC->width() + a->width();
-
-          // determine the middle of the containers.
-          int tmiddle = tx + twidth/2;
-          int moveACmiddle = _moveAC->x() + _moveAC->width()/2;
-          
-          // move 'a' from the right side of the virtual container to the left
-          // side if the middle of moveAC has moved far enough to the left, 
-          // i.e. past the middle of the virtual container plus the 
-          // switchMargin. The switchMargin prevents rapidly switching when 
-          // '_moveAC' and 'a' have the same size.
-          if (moveACmiddle >= tmiddle + switchMargin) {
-            a->move(a->x() - _moveAC->width(), a->y());
-            // store 'a', because it may become null in the next step.
-            b = a; 
-            a = _applets.next();
-            continue;
-          }
-
-          // '_moveAC' doesn't cover 'a', and hasn't passed it. We now know that
-          // this also yields for the rest of the applets, so break out of the
-          // loop.
-          break;
+          if (_moveAC->x() < cxmiddle)
+            _dummyWidget->move(QPoint(c->x() - _moveAC->width(), _moveAC->y()));
+          else
+            _dummyWidget->move(QPoint(c->x() + c->width(), _moveAC->y()));
+         
+          _dummyWidget->show();
         }
+      else
+        _dummyWidget->hide();
 
-        // visual feedback
-        AppletContainer *c = coversAppletContainer(_moveAC, true);
-        if (c)
-          {
-            int cxmiddle = c->x() + c->width()/2;
-            
-            if (_moveAC->x() < cxmiddle)
-              _dummyWidget->move(QPoint(c->x() - _moveAC->width() - 1, _moveAC->y()));
-            else
-              _dummyWidget->move(QPoint(c->x() + c->width() + 1, _moveAC->y()));
-           
-            _dummyWidget->show();
-          }
-        else
-          _dummyWidget->hide();
-
-        // Finally move _moveAC to its new position in the applet list.
-        if (b != _moveAC) {
-          _applets.removeRef(_moveAC);
-          _applets.insert( _applets.findRef(b) + 1, _moveAC );
-        }
-      }
-      
-      else if (oldACx > _moveAC->x()) { // right to left
-        
-        _applets.findRef(_moveAC);
-        AppletContainer *a = _applets.prev();
-        AppletContainer *b = _moveAC;
- 
-        while (a) 
-        {
-          if (isTopLevel(a))
-            continue;
-        
-          if ( _moveAC->x() + _moveAC->width() <= a->x() ) {
-            a->move(a->x() + _moveAC->width(), a->y());
-            b = a;
-            a = _applets.prev();
-            continue;
-          }
-          
-          int switchMargin = 0;
-            
-          // calculate the position and width of the 'virtual' container 
-          // containing moveAC and a.
-          int tx = a->x();
-          int twidth = _moveAC->width() + a->width();
-
-          // determine the middle of the containers.
-          int tmiddle = tx + twidth/2;
-          int moveACmiddle = _moveAC->x() + _moveAC->width()/2;
- 
-          // move a from the left side of the virtual container to the right
-          // side if the middle of moveAC has moved past the middle of the
-          // virtual container plus the switchMargin. The switchMargin 
-          // prevents rapidly switching when moveAC and a have the same size.
-          if (moveACmiddle <= tmiddle + switchMargin) {
-            a->move(a->x() + _moveAC->width(), a->y());
-            b = a;
-            a = _applets.prev();
-            continue;
-          } 
-          
-          break;
-        }
-
-        // visual feedback
-        AppletContainer *c = coversAppletContainer(_moveAC, true);
-        if (c)
-          {
-            int cxmiddle = c->x() + c->width()/2;
-            
-            if (_moveAC->x() < cxmiddle)
-              _dummyWidget->move(QPoint(c->x() - _moveAC->width() - 1, _moveAC->y()));
-            else
-              _dummyWidget->move(QPoint(c->x() + c->width() + 1, _moveAC->y()));
-            
-            _dummyWidget->show();
-          }
-        else
-          _dummyWidget->hide();
-
-        // Finally move _moveAC to its new position in the applet list.
-        if (b != _moveAC) {
-          _applets.removeRef(_moveAC);
-          _applets.insert(_applets.findRef(b), _moveAC);
-        }
+      // Finally move _moveAC to its new position in the applet list.
+      if (b != _moveAC) {
+        _applets.removeRef(_moveAC);
+        _applets.insert( _applets.findRef(b) + 1, _moveAC );
       }
     }
     
-    // vertical panel
-    else if (orientation() == Vertical) {
-
-      // calculate new position.
-      int y = ev->pos().y()-_moveAC->moveOffset().y();
+    else if (oldACx > _moveAC->x()) { // right to left
       
-      // make sure the new position is inside the appletarea
-      // scroll if needed
-      if (y < 0) {
-        y = 0;
-        //scrollBy( -10, 0 );
-      }
-      else if (y > height() - _moveAC->height()) {
-        y = height() - _moveAC->height();
-        //scrollBy( 10, 0 );
-      }
+      _applets.findRef(_moveAC);
+      AppletContainer *a = _applets.prev();
+      AppletContainer *b = _moveAC;
 
-      // move the Applet to the calculated position, remember the old
-      // position.
-      int oldACy = _moveAC->y();
-      _moveAC->move(_moveAC->x(), y);
-     
-      if (oldACy < _moveAC->y()) { // top to bottom
-       
-        _applets.findRef(_moveAC);
-        AppletContainer *a = _applets.next();
-        AppletContainer *b = _moveAC;
- 
-        while (a) 
-        {
-          if (isTopLevel(a))
-            continue;
-        
-          if ( a->y() + a->height() <= _moveAC->y() ) {
-            a->move(a->x(), a->y() - _moveAC->height());
-            b = a;
-            a = _applets.next();
-            continue;
-          }
-          
-          int switchMargin = 0;
-            
-          // calculate the position and height of the 'virtual' container 
-          // containing moveAC and a.
-          int ty = a->y() - _moveAC->height();
-          int theight = _moveAC->height() + a->height();
-
-          // determine the middle of the containers.
-          int tmiddle = ty + theight/2;
-          int moveACmiddle = _moveAC->y() + _moveAC->height()/2;
-          
-          // move a from the bmottom of the virtual container to the top
-          // side if the middle of moveAC has moved past the middle of the
-          // virtual container plus the switchMargin. The switchMargin 
-          // prevents rapidly switching when moveAC and a have the same size.
-          if (moveACmiddle >= tmiddle + switchMargin) {
-            a->move(a->x(), a->y() - _moveAC->height());
-            b = a;
-            a = _applets.next();
-            continue;
-          }
-
-          break;
+      while (a) 
+      {
+        if (isTopLevel(a)) {
+          a = _applets.prev();
+          continue;
         }
-
-        // visual feedback
-        AppletContainer *c = coversAppletContainer(_moveAC, true);
-        if (c)
-          {
-            int cymiddle = c->y() + c->height()/2;
-            
-            if (_moveAC->y() < cymiddle)
-              _dummyWidget->move(QPoint(_moveAC->x(), c->y() - _moveAC->height() - 1));
-            else
-              _dummyWidget->move(QPoint(_moveAC->x(), c->y() + c->height() + 1));
-            
-            _dummyWidget->show();
-          }
-        else
-          _dummyWidget->hide();
-        
-        // Finally move _moveAC to its new position in the applet list.
-        if (b != _moveAC) {
-          _applets.removeRef(_moveAC);
-          _applets.insert( _applets.findRef(b) + 1, _moveAC );
-        }
-      }
       
-      else if (oldACy > _moveAC->y()) { // bottom to top
+        if ( _moveAC->x() + _moveAC->width() <= a->x() ) {
+          a->move(a->x() + _moveAC->width(), a->y());
+          b = a;
+          a = _applets.prev();
+          continue;
+        }
         
-        _applets.findRef(_moveAC);
-        AppletContainer *a = _applets.prev();
-        AppletContainer *b = _moveAC;
- 
-        while (a) 
-        {
-          if (isTopLevel(a))
-            continue;
-        
-          if ( _moveAC->y() + _moveAC->height() <= a->y() ) {
-            a->move(a->x(), a->y() + _moveAC->height());
-            b = a;
-            a = _applets.prev();
-            continue;
-          }
+        int switchMargin = 0;
           
-          int switchMargin = 0;
-            
-          // calculate the position and height of the 'virtual' container 
-          // containing moveAC and a.
-          int ty = a->y();
-          int theight = _moveAC->height() + a->height();
+        // calculate the position and width of the 'virtual' container 
+        // containing moveAC and a.
+        int tx = a->x();
+        int twidth = _moveAC->width() + a->width();
 
-          // determine the middle of the containers.
-          int tmiddle = ty + theight/2;
-          int moveACmiddle = _moveAC->y() + _moveAC->height()/2;
- 
-          // move a from the top of the virtual container to the bottom
-          // if the middle of moveAC has moved past the middle of the
-          // virtual container plus the switchMargin. The switchMargin 
-          // prevents rapidly switching when moveAC and a have the same size.
-          if (moveACmiddle <= tmiddle + switchMargin) {
-            a->move(a->x(), a->y() + _moveAC->height());
-            b = a;
-            a = _applets.prev();
-            continue;
-          } 
+        // determine the middle of the containers.
+        int tmiddle = tx + twidth/2;
+        int moveACmiddle = _moveAC->x() + _moveAC->width()/2;
+
+        // move a from the left side of the virtual container to the right
+        // side if the middle of moveAC has moved past the middle of the
+        // virtual container plus the switchMargin. The switchMargin 
+        // prevents rapidly switching when moveAC and a have the same size.
+        if (moveACmiddle <= tmiddle + switchMargin) {
+          a->move(a->x() + _moveAC->width(), a->y());
+          b = a;
+          a = _applets.prev();
+          continue;
+        } 
+        
+        break;
+      }
+
+      // visual feedback
+      AppletContainer *c = coversAppletContainer(_moveAC, true);
+      if (c)
+        {
+          int cxmiddle = c->x() + c->width()/2;
           
-          break;
-        }
-        
-        // visual feedback
-        AppletContainer *c = coversAppletContainer(_moveAC, true);
-        if (c)
-          {
-            int cymiddle = c->y() + c->height()/2;
-            
-            if (_moveAC->y() < cymiddle)
-              _dummyWidget->move(QPoint(_moveAC->x(), c->y() - _moveAC->height() - 1));
-            else
-                _dummyWidget->move(QPoint(_moveAC->x(), c->y() + c->height() + 1));
-            
-            _dummyWidget->show();
-          }
-        else
-          _dummyWidget->hide();
-        
-        // Finally move _moveAC to its new position in the applet list.
-        if (b != _moveAC) {
-          _applets.removeRef(_moveAC);
-          _applets.insert(_applets.findRef(b), _moveAC);
+          if (_moveAC->x() < cxmiddle)
+            _dummyWidget->move(QPoint(c->x() - _moveAC->width(), _moveAC->y()));
+          else
+            _dummyWidget->move(QPoint(c->x() + c->width(), _moveAC->y()));
+          
+          _dummyWidget->show();
         }
+      else
+        _dummyWidget->hide();
+
+      // Finally move _moveAC to its new position in the applet list.
+      if (b != _moveAC) {
+        _applets.removeRef(_moveAC);
+        _applets.insert(_applets.findRef(b), _moveAC);
+      }
+    }
+  }
+  
+  // vertical panel
+  else if (orientation() == Vertical) {
+
+    // calculate new position.
+    int y = ev->pos().y()-_moveAC->moveOffset().y();
+    
+    // make sure the new position is inside the appletarea
+    // scroll if needed
+    if (y < 0) {
+      y = 0;
+      //scrollBy( -10, 0 );
+    }
+    else if (y > height() - _moveAC->height()) {
+      y = height() - _moveAC->height();
+      //scrollBy( 10, 0 );
+    }
+
+    // move the Applet to the calculated position, remember the old
+    // position.
+    int oldACy = _moveAC->y();
+    _moveAC->move(_moveAC->x(), y);
+   
+    if (oldACy < _moveAC->y()) { // top to bottom
+     
+      _applets.findRef(_moveAC);
+      AppletContainer *a = _applets.next();
+      AppletContainer *b = _moveAC;
+
+      while (a) 
+      {
+        if (isTopLevel(a)) {
+          a = _applets.next();
+          continue;
+        }
+      
+        if ( a->y() + a->height() <= _moveAC->y() ) {
+          a->move(a->x(), a->y() - _moveAC->height());
+          b = a;
+          a = _applets.next();
+          continue;
+        }
+        
+        int switchMargin = 0;
+          
+        // calculate the position and height of the 'virtual' container 
+        // containing moveAC and a.
+        int ty = a->y() - _moveAC->height();
+        int theight = _moveAC->height() + a->height();
+
+        // determine the middle of the containers.
+        int tmiddle = ty + theight/2;
+        int moveACmiddle = _moveAC->y() + _moveAC->height()/2;
+        
+        // move a from the bmottom of the virtual container to the top
+        // side if the middle of moveAC has moved past the middle of the
+        // virtual container plus the switchMargin. The switchMargin 
+        // prevents rapidly switching when moveAC and a have the same size.
+        if (moveACmiddle >= tmiddle + switchMargin) {
+          a->move(a->x(), a->y() - _moveAC->height());
+          b = a;
+          a = _applets.next();
+          continue;
+        }
+
+        break;
+      }
+
+      // visual feedback
+      AppletContainer *c = coversAppletContainer(_moveAC, true);
+      if (c)
+        {
+          int cymiddle = c->y() + c->height()/2;
+          
+          if (_moveAC->y() < cymiddle)
+            _dummyWidget->move(QPoint(_moveAC->x(), c->y() - _moveAC->height()));
+          else
+            _dummyWidget->move(QPoint(_moveAC->x(), c->y() + c->height()));
+          
+          _dummyWidget->show();
+        }
+      else
+        _dummyWidget->hide();
+      
+      // Finally move _moveAC to its new position in the applet list.
+      if (b != _moveAC) {
+        _applets.removeRef(_moveAC);
+        _applets.insert( _applets.findRef(b) + 1, _moveAC );
+      }
+    }
+    
+    else if (oldACy > _moveAC->y()) { // bottom to top
+      
+      _applets.findRef(_moveAC);
+      AppletContainer *a = _applets.prev();
+      AppletContainer *b = _moveAC;
+
+      while (a) 
+      {
+        if (isTopLevel(a)) {
+          a = _applets.prev();
+          continue;
+        }
+      
+        if ( _moveAC->y() + _moveAC->height() <= a->y() ) {
+          a->move(a->x(), a->y() + _moveAC->height());
+          b = a;
+          a = _applets.prev();
+          continue;
+        }
+        
+        int switchMargin = 0;
+          
+        // calculate the position and height of the 'virtual' container 
+        // containing moveAC and a.
+        int ty = a->y();
+        int theight = _moveAC->height() + a->height();
+
+        // determine the middle of the containers.
+        int tmiddle = ty + theight/2;
+        int moveACmiddle = _moveAC->y() + _moveAC->height()/2;
+
+        // move a from the top of the virtual container to the bottom
+        // if the middle of moveAC has moved past the middle of the
+        // virtual container plus the switchMargin. The switchMargin 
+        // prevents rapidly switching when moveAC and a have the same size.
+        if (moveACmiddle <= tmiddle + switchMargin) {
+          a->move(a->x(), a->y() + _moveAC->height());
+          b = a;
+          a = _applets.prev();
+          continue;
+        } 
+        
+        break;
+      }
+      
+      // visual feedback
+      AppletContainer *c = coversAppletContainer(_moveAC, true);
+      if (c)
+        {
+          int cymiddle = c->y() + c->height()/2;
+          
+          if (_moveAC->y() < cymiddle)
+            _dummyWidget->move(QPoint(_moveAC->x(), c->y() - _moveAC->height()));
+          else
+              _dummyWidget->move(QPoint(_moveAC->x(), c->y() + c->height()));
+          
+          _dummyWidget->show();
+        }
+      else
+        _dummyWidget->hide();
+      
+      // Finally move _moveAC to its new position in the applet list.
+      if (b != _moveAC) {
+        _applets.removeRef(_moveAC);
+        _applets.insert(_applets.findRef(b), _moveAC);
       }
     }
-    QCursor::setPos(mapToGlobal(QPoint(_moveAC->x() + _moveAC->moveOffset().x(),
-                                       _moveAC->y() + _moveAC->moveOffset().y())));
   }
-  else
-    Panner::mouseMoveEvent(ev);
 }
 
 bool AppletArea::process(const QCString &fun, const QByteArray &data,
 	     QCString& replyType, QByteArray &replyData)
 {
-  if ( fun == "dockMe(QCString)" )
+  if ( fun == "dockRequest(QCString,QCString)" )
     {
       QDataStream dataStream( data, IO_ReadOnly );
-      QCString name;
-      dataStream >> name;
+      QCString name, id;
+      dataStream >> name >> id;
       dockMe( kapp->dcopClient()->senderId(), name );
       return true;
     }
@@ -871,6 +884,7 @@ void AppletArea::layoutChildren()
   if (_block_relayout) return;
   int pos = 0;
 
+  int occupiedspace = 0;
   int freespace = totalFreeSpace();
 
   AppletContainer *a;
@@ -880,8 +894,6 @@ void AppletArea::layoutChildren()
 		{
 		  a->hide();
 		  a->move(0,0);
-		  a->setOrientation(orientation());
-		  a->setPosition(PGlobal::panel->position());
 		  continue;
 		}
 
@@ -893,14 +905,11 @@ void AppletArea::layoutChildren()
 
 	  // reset current
 	  _applets.find(a);
-
-      a->setOrientation(orientation());
-      a->setPosition(PGlobal::panel->position());
       
-      double fspace = a->freeSpace()/100*freespace;
+      double fspace = a->freeSpace()*freespace;
       if ((fspace - floor(fspace)) > 0.5)
         fspace += 1;
-      pos += static_cast<int>(fspace);
+      pos = static_cast<int>(fspace) + occupiedspace;
 
       if (orientation() == Horizontal)
         {
@@ -909,13 +918,14 @@ void AppletArea::layoutChildren()
           if (isStretch(a))
             {
               if (next)
-                a->resize(w + next->freeSpace()/100*freespace, height());
+                a->resize(w + (next->freeSpace() - a->freeSpace())*freespace, 
+                  height());
               else
                 a->resize(realWidth() - a->x(), height());
             }
           else
             a->resize(w, height());
-          pos += w + 1;
+          occupiedspace += w;
         }
       else
         {
@@ -924,13 +934,14 @@ void AppletArea::layoutChildren()
 		  if (isStretch(a))
             {
               if (next)
-                a->resize(width(), h + next->freeSpace()/100*freespace);
+                a->resize(width(), 
+                  h + (next->freeSpace() - a->freeSpace())*freespace);
               else
                 a->resize(width(), realHeight() - a->y());
             }
           else
             a->resize(width(), h);
-          pos += h + 1;
+          occupiedspace += h;
         }
     }
 
@@ -1144,14 +1155,14 @@ void AppletArea::updateAppletContainerList()
   _applets = sorted;
   
   float freespace = totalFreeSpace();
+  float fspace = 0;
 
   QListIterator<AppletContainer> it(_applets);
   for(; it.current() ; ++it)
     {
-      float fspace = relativeAppletContainerPos(it.current());
+      fspace += relativeAppletContainerPos(it.current());
       if (fspace < 0) fspace = 0;
-      fspace = (fspace/freespace) * 100;
-      it.current()->setFreeSpace(fspace);
+      it.current()->setFreeSpace(fspace/freespace);
     }
 }
 
@@ -1171,6 +1182,9 @@ int AppletArea::totalFreeSpace()
 	{
 	  AppletContainer* a = static_cast<AppletContainer*>(it.current());
 
+      if (isTopLevel(a))
+        continue;
+
       int space;
       if(orientation() == Horizontal)
         space = a->widthForHeight(height());
@@ -1184,7 +1198,7 @@ int AppletArea::totalFreeSpace()
   int freespace = availablespace - usedspace;
   if (freespace < 0) freespace = 0;
 
-  return freespace - 20;
+  return freespace;
 }
 
 int AppletArea::relativeAppletContainerPos(AppletContainer* b)
@@ -1211,7 +1225,7 @@ int AppletArea::relativeAppletContainerPos(AppletContainer* b)
               return p;
             }
 		  else
-			pos = a->x() + a->widthForHeight(height())+1;
+			pos = a->x() + a->widthForHeight(height());
 		}
 	  else
 		{
@@ -1222,7 +1236,7 @@ int AppletArea::relativeAppletContainerPos(AppletContainer* b)
               return p;
             }
 		  else
-			pos = a->y() + a->heightForWidth(width())+1;
+			pos = a->y() + a->heightForWidth(width());
 		}
 	}
   return 0;
