@@ -25,22 +25,26 @@
 
 static KCmdLineOptions options[] =
 { 
+  { "appletId <id>", I18N_NOOP("For internal use only."), "" },
   {"c <cmd>", I18N_NOOP("The command to execute"), 0},
   {"t <title>", I18N_NOOP("The window title to trigger swallowing"), 0},
   {0, 0, 0}
 };
 
-
 int main( int argc, char ** argv )
 {
   KCmdLineArgs::init(argc, argv, "swallowapplet", I18N_NOOP("Swallow applet for kicker."), "v0.1.0" );
   KCmdLineArgs::addCmdLineOptions(options);
   KApplication::addCmdLineOptions();
 
+  KCmdLineArgs *args = KCmdLineArgs::parsedArgs();
+
   KApplication a;
   
   SwallowApplet applet( 0, "swallow applet");
   a.setMainWidget( &applet );
-  applet.init( argc, argv);
-  return a.exec();
+  if(applet.dock(args->getOption("appletId")))
+    return a.exec();
+  else
+    return 1;
 }
