@@ -24,6 +24,10 @@ class KPager : public InternalApplet
     int widthForHeight(int height);
     int heightForWidth(int width);
 
+	void about();
+	void help();
+	void preferences();
+
 public slots:
     void slotSetDesktop(int desktop);
     void slotSetDesktopCount(int count);
