@@ -53,15 +53,58 @@ extern "C"
 {
     InternalApplet* init(QWidget *parent, KWinModule *module)
     {
+        KConfig *config = KGlobal::config();
+        KConfigGroupSaver saver(config, "taskbar");
         kwin_module = module;
         KGlobal::locale()->insertCatalogue("ktaskbarapplet");
-        return new TaskbarApplet(parent, "ktaskbarapplet");
+        if (config->readBoolEntry("TopLevel", false))
+            return new TaskbarApplet("ktaskbarapplet");
+        else
+            return new TaskbarApplet(parent, "ktaskbarapplet");
     }
 }
 
+TaskbarApplet::TaskbarApplet( const char* name )
+    : InternalApplet(NULL, name),
+      DCOPObject("TaskbarApplet")
+{
+  KWM::keepOnTop(winId());
+
+  KConfig *config = KGlobal::config();
+  KConfigGroupSaver saver(config, "taskbar");
+
+  setPosition((Position)config->readNumEntry("Position", (int)Bottom));
+
+  show_all = config->readBoolEntry("ShowAllWindows", false);
+
+  setFrameStyle(QFrame::StyledPanel | QFrame::Plain );
+
+  connect( kwin_module, SIGNAL( windowAdd(WId) ), this, SLOT( windowAdd(WId) ) );
+  connect( kwin_module, SIGNAL( windowRemove(WId) ), this, SLOT( windowRemove(WId) ) );
+  connect( kwin_module, SIGNAL( windowChange(WId) ), this, SLOT( windowChange(WId) ) );
+  connect( kwin_module, SIGNAL( windowActivate(WId) ), this, SLOT( windowActivate(WId) ) );
+  connect( kwin_module, SIGNAL( desktopChange(int) ), this, SLOT( desktopChange(int) ) );
+
+  setFlags(TopLevel);
+
+  // register existing windows
+  const QValueList<WId> windows = kwin_module->windows();
+  QValueList<WId>::ConstIterator it;
+  for ( it=windows.begin(); it!=windows.end(); ++it )
+     windowAdd( *it );
+
+  resetLayout();
+
+  show();
+}
+
 TaskbarApplet::TaskbarApplet(QWidget* parent, const char* name )
     : InternalApplet(parent, name ), DCOPObject("TaskbarApplet")
 {
+  KConfig *config = KGlobal::config();
+  KConfigGroupSaver saver(config, "taskbar");
+  show_all = config->readBoolEntry("ShowAllWindows", false);
+
   setFrameStyle(QFrame::StyledPanel | QFrame::Sunken);
 
   connect( kwin_module, SIGNAL( windowAdd(WId) ), this, SLOT( windowAdd(WId) ) );
@@ -71,7 +114,6 @@ TaskbarApplet::TaskbarApplet(QWidget* parent, const char* name )
   connect( kwin_module, SIGNAL( desktopChange(int) ), this, SLOT( desktopChange(int) ) );
 
   setFlags(Stretch);
-  appsStarting.setAutoDelete(true);
 
   // register existing windows
   const QValueList<WId> windows = kwin_module->windows();
@@ -84,9 +126,22 @@ TaskbarApplet::TaskbarApplet(QWidget* parent, const char* name )
 
 TaskbarApplet::~TaskbarApplet() {}
 
-void TaskbarApplet::killAppStartButton(int pid)
+void TaskbarApplet::killAppStartButton(pid_t pid)
 {
-  appsStarting.remove(pid);
+  QMap<pid_t, AppStartButton *>::Iterator it = appsStarting.find(pid);
+
+  if (it == appsStarting.end())
+    return;
+
+  AppStartButton * b = *it;
+
+  if (0 != b) {
+    kdDebug() << "Found a button to kill for pid " << long(pid) << "d" << endl;
+    appsStarting.remove(pid);
+    delete b;
+    b = 0;
+    updateLayout();
+  }
 }
 
 void TaskbarApplet::resizeEvent(QResizeEvent*)
@@ -108,16 +163,14 @@ void TaskbarApplet::windowAdd(WId w )
     if ( w == topLevelWidget()->winId() )
         return;
     QString s = KWM::title(w);
-    if(s.right(6) == "[menu]" || s.right(7) == "[tools]")
+    if(s.right(6) == "[menu]" || s.right(7) == "[tools]" ||
+       s.right(6) == "Kicker" )
         return;
 
+    pid_t pid = KWin::pid(w);
 
-    XClassHint xch;
-    if (0 != XGetClassHint(qt_xdisplay(), w, &xch)) {
-	clientMapped( QString::fromUtf8(xch.res_name) );
-	XFree(xch.res_name);
-	XFree(xch.res_class);
-    }
+    if (-1 != pid)
+      clientMapped(pid);
 
     TaskButton* b = new TaskButton(w, this);
     buttons.append( b );
@@ -185,9 +238,12 @@ void TaskbarApplet::resetLayout()
     bool horiz = orientation() == Horizontal;
     int items, i, col, row, mod = 0;
 
+    if ( flags() == TopLevel && ( pos == Left || pos == Right ) )
+      horiz = false;
+
     TaskButton *b;
     for(items=0, b = buttons.first(); b; b = buttons.next())
-        items += b->onCurrentDesktop()?1:0;
+        items += (b->onCurrentDesktop() || show_all)?1:0;
 
     items += appsStarting.count();
 
@@ -199,7 +255,7 @@ void TaskbarApplet::resetLayout()
       layout = NULL;
 
     for(i=0, col=0, row=0, b = buttons.first(); b; b = buttons.next()){
-        if(b->onCurrentDesktop()){
+        if(b->onCurrentDesktop() || show_all){
             b->show();
             if(horiz){
                 b->setMinimumSize(64, 8);
@@ -225,11 +281,11 @@ void TaskbarApplet::resetLayout()
         }
     }
 
-    QIntDictIterator<AppStartButton> it(appsStarting);
+    QMap<pid_t, AppStartButton *>::Iterator it(appsStarting.begin());
 
-    for (; it.current(); ++it) {
-
-      AppStartButton * asb = it.current();
+    for (; it != appsStarting.end(); ++it) {
+    
+      AppStartButton * asb = *it;
 
       asb->show();
 
@@ -263,7 +319,6 @@ void TaskbarApplet::resetLayout()
     }
 }
 
-
 TaskButton* TaskButton::activeButton = 0;
 
 void TaskButton::setActiveButton()
@@ -483,61 +538,77 @@ QSize TaskButton::sizeHint() const
 void TaskbarApplet::clientStarted(
   QString name,
   QString icon,
-  QString resName,
-  int pid
+  pid_t pid
 )
 {
-//     qDebug("clientStarted(%s, %s, %s, %d)", name.latin1(), icon.latin1(), resName.latin1(), pid);
+  kdDebug() << "clientStarted(" << name << ", " << icon << ", " << (long)pid << "d)" << endl;
 
-  AppStartButton * b = new AppStartButton(name, icon, resName, pid, this);
-
-  appsStarting.insert(pid, b);
+  AppStartButton * b = new AppStartButton(name, icon, pid, this);
+  appsStarting[pid] = b;
 
   connect(
-    b,    SIGNAL(killMe(int)),
-    this, SLOT(killAppStartButton(int)));
+    b,    SIGNAL(killMe(pid_t)),
+    this, SLOT(killAppStartButton(pid_t)));
 
   resetLayout();
   b->show();
 }
 
-void TaskbarApplet::clientMapped(QString name)
+void TaskbarApplet::clientMapped(pid_t pid)
 {
-//     qDebug("clientMapped(`%s')", name.latin1());
-
-  QIntDictIterator<AppStartButton> it(appsStarting);
-
-  for (; it.current(); ++it) {
-
-      if (it.current()->resName() == name || (name == "Navigator" && it.current()->resName() == "netscape" ) ) {
-      appsStarting.remove(it.currentKey());
-      resetLayout();
-      break;
-    }
-  }
+  kdDebug() << "clientMapped(" << (long)pid << "d)" << endl;
+  killAppStartButton(pid);
 }
 
-void TaskbarApplet::clientDied(int pid)
+void TaskbarApplet::clientDied(pid_t pid)
 {
-  //qDebug("clientDied(%d)", pid);
-
-  AppStartButton * b = appsStarting[pid];
-
-  if (0 != b) {
-    appsStarting.remove(pid);
-    resetLayout();
-  }
+  kdDebug() << "clientDied(" << (long)pid << "d)" << endl;
+  killAppStartButton(pid);
 }
 
+void TaskbarApplet::setPosition(Position p)
+{
+  // temporary stop avoiding while we are repositioning
+  KWin::stopAvoiding(winId());
 
+  pos = p;
+  QRect r(KWin::edgeClientArea());
+  switch (p)
+  {
+  case Top:
+    resize(r.width(), 25);
+    move(r.left(), r.top());
+    KWin::avoid(winId(), KWin::Top);
+    break;
+  case Left:
+    resize(150, 25);
+    move(r.left(), r.top());
+    KWin::avoid(winId(), KWin::Left);
+    break;
+  case Right:
+    resize(150, 25);
+    move(r.right() - width(), r.top());
+    KWin::avoid(winId(), KWin::Right);
+    break;
+  case Bottom:
+  default:
+    resize(r.width(), 25);
+    move(r.left(), r.bottom() - height());
+//    KWin::avoid(winId(), KWin::Bottom);
+    break;
+  };
+
+  KWin::updateClientArea();
+}
+
+///////////////////////////////////////////////////////////////
 AppStartButton::AppStartButton(
   const QString & text,
   const QString & /*icon*/,
-  const QString & resName,
-  int pid,
+  pid_t pid,
   QWidget * parent
 )
-  : QPushButton(text, parent), appResName(resName), frame(0), pid_(pid)
+  : QPushButton(text, parent), frame(0), pid_(pid)
 {
 
   QString appName(text);
@@ -673,9 +744,3 @@ QSize AppStartButton::sizeHint() const
   return(minimumSize());
 }
 
-QString AppStartButton::resName() const
-{
-  return appResName;
-}
-
-
