@@ -1,14 +1,29 @@
-/*
- * Copyright (c) 1999 Daniel M. Duley <mosfet@kde.org>
- * Copyright (c) 2000 Matthias Elter <elter@kde.org>
- * Copyright (c) 2000 Preston Brown <pbrown@kde.org>
- *
- * Artistic License - See file LICENSE for details.
- */
+/*****************************************************************
+
+Copyright (c) 1996-2000 the kicker authors. See file AUTHORS.
+
+Permission is hereby granted, free of charge, to any person obtaining a copy
+of this software and associated documentation files (the "Software"), to deal
+in the Software without restriction, including without limitation the rights
+to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
+copies of the Software, and to permit persons to whom the Software is
+furnished to do so, subject to the following conditions:
+
+The above copyright notice and this permission notice shall be included in
+all copies or substantial portions of the Software.
+
+THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
+IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL THE
+AUTHORS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN
+AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
+CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+
+******************************************************************/
+
 #include <stdlib.h>
 #include <unistd.h>
 
-
 #include <qdir.h>
 #include <qdragobject.h>
 
@@ -23,7 +38,6 @@
 #include <kdebug.h>
 #include <kglobalsettings.h>
 #include <kstddirs.h>
-#include <kdesktopfile.h>
 #include <kmimetype.h>
 #include <kurl.h>
 #include <kfiledialog.h>
@@ -32,10 +46,14 @@
 #include <kwm.h>
 #include <kwin.h>
 #include <kprocess.h>
+#include <kpanelapplet.h>
 #include <dcopclient.h>
+#include <kwinmodule.h>
+#include <kstringhandler.h>
 
 #include "menus.h"
 #include "menus.moc"
+#include "servicemenu.h"
 #include "dialogs.h"
 #include "panel.h"
 #include "global.h"
@@ -44,8 +62,9 @@
 
 template class QList<PanelBrowserMenu>;
 
-PanelMenu::PanelMenu(const QString &startDir, QWidget *parent, const char *name)
-  : KPopupMenu(parent, name)
+PanelMenu::PanelMenu(const QString &startDir, QWidget *parent, 
+		     const char *name)
+  : QPopupMenu(parent, name)
 {
   init = false;
   startPath = startDir;
@@ -78,21 +97,18 @@ void PanelMenu::hideEvent(QHideEvent *ev)
   QPopupMenu::hideEvent(ev);
 }
 
-PanelBrowserMenu::PanelBrowserMenu(QString startDir, 
-				   bool useRelative,
+PanelBrowserMenu::PanelBrowserMenu(QString startDir,
 				   bool expandFSTypes,
                                    bool ignoreEmptyDirs, QWidget *parent,
                                    const char *name, int filter,
                                    int sorting)
   : PanelMenu(startDir, parent, name)
 {
-  useRel = useRelative;
   expandFS = expandFSTypes;
   ignoreEmpty = ignoreEmptyDirs;
   KConfig *config = KGlobal::config();
   config->setGroup("menus");
   max = config->readNumEntry("MaxEntries", 100);
-  merge = config->readBoolEntry("MergeKDEDirs", true);
   maxedOut=false;
   // gcc didn't like me using QDir:: for the type in the declaration
   filterSpec = (QDir::FilterSpec)filter;
@@ -100,217 +116,158 @@ PanelBrowserMenu::PanelBrowserMenu(QString startDir,
 }
 
 PanelBrowserMenu* PanelBrowserMenu::createSubMenu(QString startDir,
-						  bool useRelative,
 						  bool expandFSTypes,
                                                   bool ignoreEmptyDirs, QWidget *parent,
                                                   const char *name, int filter, int sorting)
 {
-  return new PanelBrowserMenu(startDir, useRelative,
-			      expandFSTypes, ignoreEmptyDirs,
+  return new PanelBrowserMenu(startDir, expandFSTypes, ignoreEmptyDirs,
                               parent, name, filter, sorting);
 }
 
 void PanelBrowserMenu::initialize()
 {
-    if (init)
-	return;
-
-    QStringList appDirs =
-	KGlobal::dirs()->resourceDirs("apps");
-
+    if (init) return;
+    
     QPixmap smallIcon, medIcon;
-    // just assume we will have a lot of these
+    
+    // precache often used default icons 
     QIconSet defaultIcons(SmallIcon("unknown"));
     defaultIcons.setPixmap(KGlobal::iconLoader()->
-			   loadIcon("unknown", KIcon::Desktop,
+			   loadIcon("unknown", KIcon::Desktop, 
 				    KIcon::SizeMedium),
 			   QIconSet::Large);
-    
+  
     QIconSet defaultFolders(SmallIcon("folder"));
     defaultFolders.setPixmap(KGlobal::iconLoader()->
-			     loadIcon("folder", KIcon::Desktop,
+			     loadIcon("folder", KIcon::Desktop, 
 				      KIcon::SizeMedium),
 			     QIconSet::Large);
     
+    // some often used strings
     QString cwd = QString::fromLatin1(".");
     QString up = QString::fromLatin1("..");
     QString slashDotDirectory = QString::fromLatin1("/.directory");
-
-    // locate the relevant portion of the startPath.
-    QStringList::Iterator it(appDirs.begin());
-
-    if (useRel) {
-	for (; it != appDirs.end(); ++it) {
-	    int loc = startPath.find(*it);
-	    if (loc > -1) {
-		relPath = startPath.right(startPath.length() -
-					  (loc + (*it).length()));
-		break;
-	    }
-	}
-	
-    if (relPath.right(1) != "/")
-	relPath.append('/');
-    }
-
-    // rewind
-    bool done = false;
-    it = appDirs.begin();
-    for (; it != appDirs.end() && !done; ++it) {
-
-	QDir dir(useRel ? *it+relPath : startPath);
-	if (!dir.exists())
-	    continue;
-
-	dir.setSorting(sortSpec);
-	dir.setFilter(filterSpec);
-	const QFileInfoList *list = dir.entryInfoList();
-	
-	if(!list) {
-	    insertItem(SmallIcon("stop"), i18n("Permission Denied!"));
-	    maxedOut = true;
-	    return;
-	}
-
-	if(list->count() > max){
-	    maxedOut = true;
-	    insertItem(SmallIcon("exclamation"), 
-		       i18n("Too many files to load."));
-	    return;
-	}
     
-	QFileInfoListIterator filit(*list);
-	QFileInfo *fi;
+    fileList.clear();
 	
-	for (; (fi = filit.current()) != NULL; ++filit) {
-	    // directories
-	    const QString& fileName = fi->fileName();
-	    const QString& absFilePath = fi->absFilePath();
-
-	    if(fi->isDir() && fileName != cwd && fileName != up){
-		if(ignoreEmpty){
-		    QDir tmpDir(absFilePath);
-		    if((int)tmpDir.count() == 2) {
-			continue;
-		    }
-		}
-		
-		PanelBrowserMenu *subMenu = 0;
-		if (merge) {
-		    for (subMenu = subMenus.first(); subMenu != 0;
-			 subMenu = subMenus.next()) {
-			if (QDir(subMenu->path()).dirName() == fileName)
-			    break;
-		    }
-		}
-		
-		// if we didn't find the menu already (or we are not
-		// merging menus) we need to create a new submenu.
-		if (!subMenu) {
-		    subMenu = createSubMenu(absFilePath, useRel, expandFS, 
-					    ignoreEmpty, this);
-		    subMenus.append(subMenu);
-		    
-		    QString dirFile(absFilePath + slashDotDirectory);
-		    QString entryName;
-		    if(QFile::exists(dirFile)){
-			KSimpleConfig config(dirFile);
-			config.setDesktopGroup();
-			smallIcon = SmallIcon(config.readEntry("Icon", 
-							       "folder"));
-			medIcon = KGlobal::iconLoader()->
-			    loadIcon(config.readEntry("Icon", "folder"), 
-				     KIcon::Desktop, KIcon::SizeMedium);
-			entryName = config.readEntry("Name", fileName);
-		    }
-		    if (entryName.isNull())
-			entryName = fileName;
-		    if(smallIcon.isNull())
-			append(defaultFolders, entryName, subMenu);
-		    else
-			append(smallIcon, medIcon, entryName, subMenu);
-		}
-	    } else if(fi->isFile() && fileName != ".directory" &&
-		      fileName != ".order"){
-		// kdelnks
-		if(KDesktopFile::isDesktopFile(absFilePath)){
-		    KDesktopFile dFile(absFilePath);
-		    if(dFile.tryExec()){
-			smallIcon = SmallIcon(dFile.readIcon());
-			medIcon = KGlobal::iconLoader()->
-			    loadIcon(dFile.readIcon(), KIcon::Desktop,
-				     KIcon::SizeMedium);
-			if(smallIcon.isNull())
-			    smallIcon = KMimeType::
-			    pixmapForURL(KURL(absFilePath), 0, 
-					 KIcon::SizeSmall);
-			if(medIcon.isNull())
-			    medIcon = KMimeType::
-			    pixmapForURL(KURL(absFilePath), 0, 
-					 KIcon::SizeMedium);
-
-			// only append if it isn't already listed.
-			
-			if((dFile.hasDeviceType() || dFile.hasLinkType()) &&
-			   expandFS){
-			    // expand FS device applnks
-			    KURL url(dFile.readURL());
-
-			    if (!fileList.contains(fi->baseName()) && 
-				((fi->dirPath() == startPath) || merge)) {
-				PanelBrowserMenu *mnu = 
-				    createSubMenu(url.path(), useRel, expandFS, 
-						  ignoreEmpty, this);
-				append(smallIcon, medIcon, 
-				       fi->baseName(), mnu);
-			    }
-			} else {
-			    QString name = (dFile.readName().isNull()) ?
-				fi->baseName() : dFile.readName();
-			    name[0] = name[0].upper();
-			    
-			    if (!fileList.contains(fileName) && 
-				((fi->dirPath() == startPath) || merge)) {
-				append(smallIcon, medIcon, name, fileName);
-			    }
-
-			}
-		    }
-		}
-		// normal files
-		else {
-		    QPixmap cachePix =
-			KMimeType::pixmapForURL(KURL(absFilePath), 0,
-						KIcon::SizeSmall);
-		    if(!cachePix.isNull())
-			append(cachePix, fileName, fileName);
-		    else
-			append(defaultIcons, fileName, fileName);
+    QDir dir(startPath);
+    if (!dir.exists())
+	return;
+    
+    dir.setSorting(sortSpec);
+    dir.setFilter(filterSpec);
+    const QFileInfoList *list = dir.entryInfoList();
+    
+    if(!list) {
+	insertItem(SmallIcon("stop"), i18n("Permission Denied!"));
+	maxedOut = true;
+	return;
+    }
+    
+    if(list->count() > max){
+	maxedOut = true;
+	insertItem(SmallIcon("exclamation"),
+		   i18n("Too many files to load."));
+	return;
+    }
+    
+    QFileInfoListIterator filit(*list);
+    QFileInfo *fi;
+    
+    for (; (fi = filit.current()) != NULL; ++filit) {
+	// directories
+	const QString& fileName = fi->fileName();
+	const QString& absFilePath = fi->absFilePath();
+	
+	if(fi->isDir() && fileName != cwd && fileName != up){
+	    if(ignoreEmpty){
+		QDir tmpDir(absFilePath);
+		if((int)tmpDir.count() == 2) {
+		    continue;
 		}
 	    }
 	    
-	    smallIcon.resize(0, 0);
-	    medIcon.resize(0, 0);
-	    if (!useRel)
-		done = true;
+            QString dirFile(absFilePath + slashDotDirectory);
+            QString entryName;
+            if(QFile::exists(dirFile)){
+		KSimpleConfig config(dirFile);
+		config.setDesktopGroup();
+//		if (config.readBoolEntry("X-KDE-HideFromPanel", false))
+//		    continue;
+		
+		smallIcon = SmallIcon(config.readEntry("Icon",
+						       "folder"));
+		medIcon = KGlobal::iconLoader()->
+		    loadIcon(config.readEntry("Icon", "folder"),
+			     KIcon::Desktop, KIcon::SizeMedium);
+		entryName = config.readEntry("Name", fileName);
+            }
+            PanelBrowserMenu *subMenu = createSubMenu(absFilePath, expandFS,
+						      ignoreEmpty, this);
+            if (entryName.isNull())
+		entryName = fileName;
+            if(smallIcon.isNull())
+		append(defaultFolders, entryName, subMenu);
+            else
+		append(smallIcon, medIcon, entryName, subMenu);
+	} else if(fi->isFile() && fileName != ".directory" &&
+		  fileName != ".order") {
+	    // kdelnks
+	    if(KDesktopFile::isDesktopFile(absFilePath))
+	    {
+		KDesktopFile dFile(absFilePath);
+		if(dFile.tryExec() /*&& !dFile.readBoolEntry("X-KDE-HideFromPanel", false)*/)
+		{
+		    smallIcon = SmallIcon(dFile.readIcon());
+		    medIcon = KGlobal::iconLoader()->
+			loadIcon(dFile.readIcon(), KIcon::Desktop,
+				 KIcon::SizeMedium);
+		    if(smallIcon.isNull())
+			smallIcon = KMimeType::
+			pixmapForURL(KURL(absFilePath), 0,
+				     KIcon::SizeSmall);
+		    if(medIcon.isNull())
+			medIcon = KMimeType::
+			pixmapForURL(KURL(absFilePath), 0,
+				     KIcon::SizeMedium);
+		    
+		    if ((dFile.hasDeviceType() || dFile.hasLinkType()) &&
+			expandFS) {
+			PanelBrowserMenu *mnu =
+			    createSubMenu(KURL(dFile.readURL()).path(), 
+					  expandFS, ignoreEmpty, this);
+			append(smallIcon, medIcon,
+			       fi->baseName(), mnu);
+		    } else {
+			append(smallIcon, medIcon, fileName, fileName);
+		    }
+		}
+	    }
+	    // normal files
+	    else {
+	    QPixmap cachePix =
+		KMimeType::pixmapForURL(KURL(absFilePath), 0,
+					KIcon::SizeSmall);
+	    if(!cachePix.isNull())
+		append(cachePix, fileName, fileName);
+	    else
+		append(defaultIcons, fileName, fileName);
+	    }
 	}
-
-	if (!merge && it != appDirs.fromLast() && 
-	    appDirs.contains(startPath))
-	    insertSeparator();
     }
+	
+    smallIcon.resize(0, 0);
+    medIcon.resize(0, 0);
     
     adjustSize();
-    subMenus.clear(); // empty this list out for next time.
-    init = true;
 }
 
 
 void PanelBrowserMenu::append(const QPixmap &pixmap, const QString &title,
                               const QString &fileName)
 {
-  fileList.append(fileName);
-  insertItem(QIconSet(pixmap), title, fileList.count()-1);
+    fileList.append(fileName);
+    insertItem(QIconSet(pixmap), title, fileList.count()-1);
 }
 
 void PanelBrowserMenu::append(const QPixmap &smallPixmap,
@@ -318,24 +275,24 @@ void PanelBrowserMenu::append(const QPixmap &smallPixmap,
                               const QString &title,
                               const QString &fileName)
 {
-  fileList.append(fileName);
-  QIconSet is(smallPixmap);
-  is.setPixmap(mediumPixmap, QIconSet::Large);
-  insertItem(is, title, fileList.count()-1);
+    fileList.append(fileName);
+    QIconSet is(smallPixmap);
+    is.setPixmap(mediumPixmap, QIconSet::Large);
+    insertItem(is, title, fileList.count()-1);
 }
 
 void PanelBrowserMenu::append(const QIconSet &iconSet, const QString &title,
                               const QString &fileName)
 {
-  fileList.append(fileName);
-  insertItem(iconSet, title, fileList.count()-1);
+    fileList.append(fileName);
+    insertItem(iconSet, title, fileList.count()-1);
 }
 
 void PanelBrowserMenu::append(const QPixmap &pixmap, const QString &title,
                               PanelBrowserMenu *subMenu)
 {
-  fileList.append(""); // keep in sync
-  insertItem(QIconSet(pixmap), title, subMenu, fileList.count()-1);
+    fileList.append(""); // keep in sync
+    insertItem(QIconSet(pixmap), title, subMenu, fileList.count()-1);
 }
 
 void PanelBrowserMenu::append(const QPixmap &smallPixmap,
@@ -343,66 +300,66 @@ void PanelBrowserMenu::append(const QPixmap &smallPixmap,
                               const QString &title,
                               PanelBrowserMenu *subMenu)
 {
-  QIconSet is(smallPixmap);
-  is.setPixmap(mediumPixmap, QIconSet::Large);
-  insertItem(is, title, subMenu, fileList.count()-1);
+    QIconSet is(smallPixmap);
+    is.setPixmap(mediumPixmap, QIconSet::Large);
+    insertItem(is, title, subMenu, fileList.count()-1);
 }
 
 void PanelBrowserMenu::append(const QIconSet &iconSet, const QString &title,
                               PanelBrowserMenu *subMenu)
 {
-  insertItem(iconSet, title, subMenu, fileList.count()-1);
+    insertItem(iconSet, title, subMenu, fileList.count()-1);
 }
 
 void PanelBrowserMenu::mousePressEvent(QMouseEvent *me)
 {
-  QPopupMenu::mousePressEvent(me);
+    QPopupMenu::mousePressEvent(me);
 
-  m_pressedPos = me->pos();
+    m_pressedPos = me->pos();
 }
 
 void PanelBrowserMenu::mouseMoveEvent(QMouseEvent *me)
 {
-  QPopupMenu::mouseMoveEvent(me);
+    QPopupMenu::mouseMoveEvent(me);
 
-  if (!(me->state() & LeftButton))
-    return; // only handle left button drags
-
-  int x = me->pos().x();
-  int y = me->pos().y();
-
-  if (abs(x - m_pressedPos.x()) > KGlobalSettings::dndEventDelay() ||
-      abs(y - m_pressedPos.y()) > KGlobalSettings::dndEventDelay()) {
-    int id = idAt(m_pressedPos);
-    // the >=0 thing is a neat hack to avoid checking manual items
-    if(id >= 0 && !maxedOut && !fileList[id].isEmpty()) {
-      //      QUriDrag *d = new QUriDrag(findItem(id));
-      QUriDrag *d = new QUriDrag(this);
-      QPoint hotspot;
-      hotspot.setX(iconSet(id)->pixmap(QIconSet::Large,
-                                       QIconSet::Active).width() / 2);
-      hotspot.setY(iconSet(id)->pixmap(QIconSet::Large,
-                                       QIconSet::Active).height() / 2);
-      d->setPixmap(iconSet(id)->pixmap(QIconSet::Large,
-                                       QIconSet::Active), hotspot);
-
-      QStringList l;
-      l.append(locate("apps", relPath + fileList[id]));
-      d->setFilenames(l);
-
-      d->drag();
+    if (!(me->state() & LeftButton))
+	return; // only handle left button drags
+    
+    int x = me->pos().x();
+    int y = me->pos().y();
+    
+    if (abs(x - m_pressedPos.x()) > KGlobalSettings::dndEventDelay() ||
+	abs(y - m_pressedPos.y()) > KGlobalSettings::dndEventDelay()) {
+	int id = idAt(m_pressedPos);
+	// the >=0 thing is a neat hack to avoid checking manual items
+	if(id >= 0 && !maxedOut && !fileList[id].isEmpty()) {
+	    //      QUriDrag *d = new QUriDrag(findItem(id));
+	    QUriDrag *d = new QUriDrag(this);
+	    QPoint hotspot;
+	    hotspot.setX(iconSet(id)->pixmap(QIconSet::Large,
+					     QIconSet::Active).width() / 2);
+	    hotspot.setY(iconSet(id)->pixmap(QIconSet::Large,
+					     QIconSet::Active).height() / 2);
+	    d->setPixmap(iconSet(id)->pixmap(QIconSet::Large,
+					     QIconSet::Active), hotspot);
+	    
+	    QStringList l;
+	    l.append(startPath + fileList[id]);
+	    d->setFilenames(l);
+	    
+	    d->drag();
+	}
     }
-  }
 }
 
 void PanelBrowserMenu::slotExec(int id)
 {
-  kapp->propagateSessionManager();
-
-  // the >=0 thing is a neat hack to avoid checking manual items
-  if(id >= 0 && !maxedOut && !fileList[id].isEmpty()) {
-      new KRun(locate("apps", relPath + fileList[id]), 0, true);
-  }
+    kapp->propagateSessionManager();
+    
+    // the >=0 thing is a neat hack to avoid checking manual items
+    if(id >= 0 && !maxedOut && !fileList[id].isEmpty()) {
+	new KRun(startPath + "/" + fileList[id], 0, true);
+    }
 }
 
 PanelQuickBrowser::PanelQuickBrowser(QWidget *parent, const char *name)
@@ -415,7 +372,7 @@ PanelQuickBrowser::PanelQuickBrowser(QWidget *parent, const char *name)
 
 void PanelQuickBrowser::initialize()
 {
-  if(!init){
+  if(!init) {
     init = true;
     // special handling for the device menu
     QDir dir( KGlobalSettings::desktopPath() );
@@ -426,25 +383,22 @@ void PanelQuickBrowser::initialize()
     if(list){
       QFileInfoListIterator it(*list);
       QFileInfo *fi;
-      for(; (fi = it.current()) != NULL; ++it){
+      for(; (fi = it.current()) != NULL; ++it) {
         KDesktopFile dFile(fi->absFilePath());
         if(dFile.hasDeviceType()){
           if(!flag){
-            insertTitle(SmallIcon("blockdevice"), i18n("Devices:"));
             fileList.append("");
             flag = true;
           }
-          KURL url(dFile.readURL());
           PanelBrowserMenu *mnu =
-            new PanelBrowserMenu(url.path(), false, true, false, this,
-				 0L, QDir::Dirs|QDir::Files);
+	      new PanelBrowserMenu(KURL(dFile.readURL()).path(), true, 
+				   false, this, 0L, QDir::Dirs|QDir::Files);
           insertItem(SmallIcon(dFile.readIcon()), fi->baseName(), mnu);
           fileList.append("");
         }
       }
     }
 
-    // use kdisknav's kdelnks for now
     int count = KGlobal::dirs()->findDirs("data", "quickbrowser").count();
     if(count){
       dir.setPath(KGlobal::dirs()->findDirs("data", "quickbrowser")
@@ -480,22 +434,22 @@ void PanelQuickBrowser::parseBrowserApplnks(QFileInfoListIterator &it,
   for(; (fi = it.current()) != NULL; ++it){
     if(KDesktopFile::isDesktopFile(fi->absFilePath())){
       KDesktopFile dFile(fi->absFilePath());
+      dFile.setDollarExpansion(true); // need to expand $HOME and the like.
       if(!flag){
         //insertTitle(QPixmap(pixmap), title);
         fileList.append("");
         flag = true;
       }
-      if(dFile.hasDeviceType() || dFile.hasLinkType()){
-        KURL url(dFile.readURL());
-        PanelBrowserMenu *mnu =
-          new PanelBrowserMenu(url.path(), false, true, false, this,
-			       0L, QDir::Dirs|QDir::Files);
-        insertItem(SmallIcon(dFile.readIcon()), fi->baseName(), mnu);
-        fileList.append("");
-      }
-      else{
-        insertItem(SmallIcon(dFile.readIcon()), fi->baseName());
-        fileList.append(fi->absFilePath());
+      if (dFile.hasDeviceType() || dFile.hasLinkType()) {
+	  PanelBrowserMenu *mnu =
+	      new PanelBrowserMenu(KURL(dFile.readURL()).path(), 
+				   true, false, this,
+				   0L, QDir::Dirs|QDir::Files);
+	  insertItem(SmallIcon(dFile.readIcon()), fi->baseName(), mnu);
+	  fileList.append("");
+      } else{
+	  insertItem(SmallIcon(dFile.readIcon()), fi->baseName());
+	  fileList.append(fi->absFilePath());
       }
     }
   }
@@ -509,8 +463,7 @@ void PanelQuickBrowser::slotExec(int id)
 }
 
 PanelKMenu::PanelKMenu(QWidget *parent, const char *name)
-  : PanelBrowserMenu(KGlobal::dirs()->resourceDirs("apps").last(), 
-		     true, false, true, parent, name)
+  : PanelServiceMenu(QString::null, QString::null, parent, name)
 {
   // set the first client id to some arbitrarily large value. I guess more
   // than 10000 menu entries in the toplevel K menu are quite useless, anyway :-)
@@ -527,21 +480,21 @@ void PanelKMenu::initialize()
 {
   if (!init)
     {
-      // parse applnk
-      PanelBrowserMenu::initialize();
+      // Add services
+      PanelServiceMenu::initialize();
       insertSeparator();
-    
+
       // insert recent documents menu
       KConfig *config = KGlobal::config();
       config->setGroup("menus");
-      
+
       if(config->readBoolEntry("UseRecent", true))
         {
           PanelRecentMenu *recentMnu = new PanelRecentMenu(this);
           insertItem(SmallIcon("document"), i18n("Recent Documents"), recentMnu);
           insertSeparator();
         }
-      
+
       // insert quickbrowser
       if(config->readBoolEntry("UseBrowser", true))
         {
@@ -563,16 +516,16 @@ void PanelKMenu::initialize()
         }
 
       // insert some default menu items like logout/lock screen
-      insertItem(SmallIcon("help"), i18n("Context Help"), this, SLOT( slotContextHelp() ) );
+      insertItem(SmallIcon("run"), i18n("Run..."), this, SLOT( slotRunCommand() ) );
+      insertSeparator();
+      insertItem(SmallIcon("panel"), i18n("Panel Menu..."), new PanelOpMenu(this));
       insertItem(SmallIcon("go"), i18n("About KDE"), this, SLOT( slotAboutKDE() ) );
-      insertSeparator();
-      insertItem(SmallIcon("exec"), i18n("Run Command..."), this, SLOT( slotRunCommand() ) );
-      insertItem(SmallIcon("panel"), i18n("Panel..."), new PanelOpMenu(this));
-      insertSeparator();
       insertItem(SmallIcon("key"), i18n("Lock Screen"), this, SLOT(slotLock()));
       insertItem(SmallIcon("exit"), i18n("Logout"), this, SLOT(slotLogout()));
       adjustSize();
   }
+  
+  init = true;
 }
 
 int PanelKMenu::insertClientMenu(KickerClientMenu *p)
@@ -630,10 +583,11 @@ PanelAddAppsMenu::PanelAddAppsMenu(QWidget *parent, const char *name)
 PanelAddAppsBaseMenu::PanelAddAppsBaseMenu(QString startDir, bool expandFSTypes,
                                            bool ignoreEmptyDirs, QWidget *parent,
                                            const char *name, int filter, int sorting)
-  : PanelBrowserMenu(startDir, true, expandFSTypes, ignoreEmptyDirs, parent, name, filter, sorting) {}
+  : PanelBrowserMenu(startDir, expandFSTypes, ignoreEmptyDirs, parent, name, filter, sorting) {}
 
 
-PanelBrowserMenu* PanelAddAppsBaseMenu::createSubMenu(QString startDir, bool expandFSTypes,
+PanelBrowserMenu* PanelAddAppsBaseMenu::createSubMenu(QString startDir,
+						      bool expandFSTypes,
                                                       bool ignoreEmptyDirs, QWidget *parent,
                                                       const char *name, int filter, int sorting)
 {
@@ -646,8 +600,8 @@ void PanelAddAppsBaseMenu::slotExec(int id)
   // the >=0 thing is a neat hack to avoid checking manual items
   if(id >= 0 && !maxedOut && !fileList[id].isEmpty())
     {
-      kdDebug() << "adding url button: " << locate("apps", relPath + fileList[id]) << endl;
-      PGlobal::panel->appletArea()->addURLButton(locate("apps", relPath + fileList[id]));
+      kdDebug() << "adding url button: " << startPath + "/" +fileList[id] << endl;
+      PGlobal::panel->appletArea()->addURLButton(startPath + "/" + fileList[id]);
     }
 }
 
@@ -657,8 +611,8 @@ void PanelAddAppsMenu::initialize()
 }
 
 PanelRecentMenu::PanelRecentMenu(QWidget *parent, const char *name)
-  :PanelBrowserMenu(locateLocal("data", "RecentDocuments/"), 
-		    false, false, false, parent, name,
+  :PanelBrowserMenu(locateLocal("data", "RecentDocuments/"),
+		    false, false, parent, name,
                     QDir::Files, QDir::Time || QDir::Reversed)
 {
   QString path(locateLocal("data", "RecentDocuments/"));
@@ -693,11 +647,11 @@ void PanelRecentMenu::slotClearHistory()
 
 
 
-PanelAppletOpMenu::PanelAppletOpMenu(QWidget *parent, const char *name)
-  : KPopupMenu(parent, name)
+PanelAppletOpMenu::PanelAppletOpMenu(int actions, QWidget *parent, const char *name)
+  : QPopupMenu(parent, name)
 {
-  //insertItem(SmallIcon("panel"),i18n("Panel..."), new PanelOpMenu(this));
-  //insertSeparator();
+  insertItem(SmallIcon("panel"), i18n("Panel Menu"), new PanelOpMenu(this));
+  insertSeparator();
 
   insertItem(SmallIcon("move"), i18n("&Move"), Move);
   setAccel(CTRL+Key_M, Move);
@@ -705,15 +659,34 @@ PanelAppletOpMenu::PanelAppletOpMenu(QWidget *parent, const char *name)
   insertItem(SmallIcon("stop"), i18n("&Remove"), Remove);
   setAccel(CTRL+Key_R, Remove);
 
-  insertSeparator();
-  insertItem(SmallIcon("configure"), i18n("&Properties"), Properties);
-  setAccel(CTRL+Key_P, Properties);
+  if (actions & KPanelApplet::Help
+	  || actions & KPanelApplet::About)
+	insertSeparator();
+
+  if (actions & KPanelApplet::About)
+	{
+	  insertItem(i18n("&About"), About);
+	  setAccel(CTRL+Key_A, About);
+	}
+  
+  if (actions & KPanelApplet::Help)
+	{
+	  insertItem(SmallIcon("help"), i18n("&Help"), Help);
+	  setAccel(CTRL+Key_H, Help);
+	}
+
+  if (actions & KPanelApplet::Preferences)
+	{
+	  insertSeparator();
+	  insertItem(SmallIcon("configure"), i18n("&Preferences"), Preferences);
+	  setAccel(CTRL+Key_P, Preferences);
+	}
 
   adjustSize();
 }
 
 PanelDirDropMenu::PanelDirDropMenu(QWidget *parent, const char *name)
-  :KPopupMenu(parent, name)
+  :QPopupMenu(parent, name)
 {
   insertItem(SmallIcon("folder"), i18n("Add as &file manager URL"), Url);
   setAccel(CTRL+Key_F, Url);
@@ -723,35 +696,36 @@ PanelDirDropMenu::PanelDirDropMenu(QWidget *parent, const char *name)
 }
 
 PanelOpMenu::PanelOpMenu(QWidget *parent, const char *name)
-  : KPopupMenu(parent, name)
+  : QPopupMenu(parent, name)
 {
-  KPopupMenu *sizeMnu = new KPopupMenu(this);
+  QPopupMenu *sizeMnu = new QPopupMenu(this);
   sizeMnu->insertItem(i18n("Tiny"), this, SLOT(slotSizeSmall()));
   sizeMnu->insertItem(i18n("Normal"), this, SLOT(slotSizeNormal()));
   sizeMnu->insertItem(i18n("Large"), this, SLOT(slotSizeLarge()));
 
-  KPopupMenu *configMnu = new KPopupMenu(this);
+  QPopupMenu *configMnu = new QPopupMenu(this);
   configMnu->insertItem(i18n("Panel Size"), sizeMnu);
   configMnu->insertItem(SmallIcon("panel_settings"), i18n("Panel Settings"), this, SLOT(slotConfigure()));
 
-  KPopupMenu *addMnu = new KPopupMenu(this);
+  QPopupMenu *addMnu = new QPopupMenu(this);
   addMnu->insertItem(i18n("Application"), new PanelAddAppsMenu(this));
   addMnu->insertItem(i18n("Applet"), new PanelAppletMenu(this));
   addMnu->insertSeparator();
   addMnu->insertItem(SmallIcon("go"), i18n("K Menu"), this, SLOT(slotAddKMenu()));
+  addMnu->insertItem(SmallIcon("window_list"), i18n("Windowlist"), this, SLOT(slotAddWindowList()));
   addMnu->insertItem(SmallIcon("kdisknav"), i18n("Quick Browser"),
                      this, SLOT(slotAddQuickBrowser()));
   addMnu->insertItem(SmallIcon("exec"), i18n("Legacy Application"),
                      this, SLOT(slotAddNonKDEApp()));
 
-  KHelpMenu *help = new KHelpMenu(this, KGlobal::instance()->aboutData(), false);
+  KHelpMenu *help = new KHelpMenu(0, KGlobal::instance()->aboutData(), false);
   QPopupMenu *helpMnu = help->menu();
 
   insertItem(i18n("Add..."), addMnu);
   insertItem(SmallIcon("configure"), i18n("Configure..."), configMnu);
   insertItem(SmallIcon("help"), i18n("Help..."), helpMnu);
   insertSeparator();
-  insertItem(i18n("Restart"), this, SLOT(slotRestart()));
+  insertItem(i18n("Restart"), this, SLOT(slotRestartDontAsk()));
   adjustSize();
 }
 
@@ -760,6 +734,11 @@ void PanelOpMenu::slotAddKMenu()
   PGlobal::panel->appletArea()->addKMenuButton();
 }
 
+void PanelOpMenu::slotAddWindowList()
+{
+  PGlobal::panel->appletArea()->addWindowListButton();
+}
+
 void PanelOpMenu::slotAddQuickBrowser()
 {
   QString dir = KFileDialog::getExistingDirectory(QString::null, 0, i18n("Select a directory"));
@@ -806,7 +785,7 @@ void PanelOpMenu::slotSizeLarge()
 void PanelOpMenu::slotConfigure()
 {
   PGlobal::panel->writeConfig();
-  
+
   KProcess proc;
   proc << locate("exe", "kcmshell");
   proc << "LookNFeel/panel";
@@ -827,19 +806,17 @@ void PanelOpMenu::slotRestart()
 void PanelOpMenu::slotRestartDontAsk()
 {
     char ** o_argv = new char*[2];
-    // TODO : support for cmd line arguments
-    //for (int v=0; v<o_argc; v++) o_argv[v] = argv[v];
     o_argv[0] = strdup("kicker");
     o_argv[1] = 0L;
-    
+
     PGlobal::panel->writeConfig();
     QApplication::exit();
     execv(locate("exe", "kicker"), o_argv);
     exit(1);
 }
-    
+
 PanelAppletMenu::PanelAppletMenu(QWidget *parent, const char *name)
-  : KPopupMenu(parent, name)
+  : QPopupMenu(parent, name)
 {
   connect(this, SIGNAL(activated(int)), SLOT(slotExec(int)));
 
@@ -863,3 +840,81 @@ void PanelAppletMenu::slotExec(int id)
       PGlobal::panel->appletArea()->addInternalFrame(name, internalApplets[id]);
     }
 }
+
+PanelWindowListMenu::PanelWindowListMenu(QWidget *parent, const char *name)
+  : QPopupMenu(parent, name)
+{  
+  connect(
+      this, SIGNAL(activated(int)), 
+      SLOT(slotExec(int)));
+}
+
+void PanelWindowListMenu::slotExec(int id)
+{  
+  if (id > 1000) {
+    KWin::setCurrentDesktop(id - 1000);
+  }
+  else {
+    Window w = PGlobal::kwin_module->windows()[id];
+    KWin::setActiveWindow(w);
+  }
+}
+
+/**
+ * Generate the list of windows
+ **/
+void PanelWindowListMenu::init()
+{
+  int i, d;
+  int nd = KWin::numberOfDesktops();
+  int cd = KWin::currentDesktop();
+  WId active_window = KWin::activeWindow();
+  
+  clear();
+  
+  for (d = 1; d <= nd; d++)
+	{
+	  if (nd > 1)
+		{
+		  insertItem(QString("Desktop &") + QString::number(d), 1000 + d);
+		  insertSeparator();
+		}
+	  
+	  int items = 0;
+	  
+	  if (!active_window && d == cd)
+        setItemChecked(1000 + d, TRUE);
+      
+      QValueList<WId>::ConstIterator it;
+      for (it = PGlobal::kwin_module->windows().begin(), i = 0;
+		   it != PGlobal::kwin_module->windows().end(); ++it, ++i) {
+        if (
+			(KWM::desktop(*it) == d
+			 && !KWM::isSticky(*it)
+			 )
+			||
+			(d == cd && KWM::isSticky(*it))
+			) {
+          QString title = KWM::titleWithState(*it);
+          if (title != "Kicker") { // Don't show Kicker
+            QPixmap pm = KWM::miniIcon(*it, 16, 16);
+			items++;
+            insertItem(/*pm.isNull()?defaultPixmap:*/pm,
+					   QString("   ")+ 
+					   KStringHandler::csqueeze(
+												KWM::titleWithState(*it),25),i);
+            if (*it == active_window)
+              setItemChecked(i, TRUE);
+          }
+        }
+      }
+	  if (items > 0)
+		{
+		  items = 0;
+		  if (d < nd)
+			insertSeparator();
+		}
+    }
+  adjustSize();
+}
+
