@@ -23,21 +23,23 @@
 
 #include <qframe.h>
 #include <qlayout.h>
-#include <qpushbt.h>
-#include <qbttngrp.h>
+#include <qpushbutton.h>
+#include <qbuttongroup.h>
 #include <qlabel.h>
 #include <qdir.h>
-#include <qcombo.h>
+#include <qcombobox.h>
 #include <qtooltip.h>
 #include <qbitmap.h>
 #include <qaccel.h>
 #include <qdialog.h>
 
 #include <kiconloader.h>
-#include <kmsgbox.h>
 #include <kcolordlg.h>
+#include <kmessagebox.h>
 
 #include "widgets.h"
+#include <klocale.h>
+#include <kglobal.h>
 #include "widgets.moc"
 
 //====================================================
@@ -46,14 +48,14 @@
 //
 // Add translated tooltip to widget
 //
-void addToolTip(QWidget* w, const char* tip) {
-  QToolTip::add(w, klocale->translate(tip));
+void addToolTip(QWidget* w, const QString& tip) {
+  QToolTip::add(w, tip);
 }
 QWidget* mkButton(QWidget* parent, QBoxLayout* box, const char* slot,
-		      QObject* obj, const char* label, const char* tip)
+		      QObject* obj, const QString& label, const QString& tip)
 {
   QPushButton* but = new QPushButton(i18n(label), parent);
-  but->setMinimumSize(but->sizeHint());
+  //CT but->setMinimumSize(but->sizeHint());//CT - obsolete with Qt-2.0
   box->addWidget(but);
   addToolTip(but, tip);
   QObject::connect(but, SIGNAL(clicked()), obj, slot);
@@ -74,7 +76,6 @@ QPixmap mapLine(KiKbdMapConfig* map) {
   //CT
 
   int      width = pp.fontMetrics().width(text) + 25;
-  /*CT*/  pp.end(); //CT of course, we have to reinitialize it later
   QPixmap  pm(width, 16);
   QBitmap  bm(width, 16);
 
@@ -82,17 +83,17 @@ QPixmap mapLine(KiKbdMapConfig* map) {
   pm.fill((kapp->mainWidget())->colorGroup().base());
   pp.begin(&pm);
   pp.setPen(map->getColor());
-  pp.drawText(25, 1, width-25, 14, AlignLeft | AlignVCenter, text);
-  pp.fillRect(0, 0, 23, 16, gray);
+  pp.drawText(25, 1, width-25, 14, Qt::AlignLeft | Qt::AlignVCenter, text);
+  pp.fillRect(0, 0, 23, 16, Qt::gray);
   pp.drawPixmap(1, 1, map->getIcon());
   pp.end();
 
   // mask
-  bm.fill(color0);
+  bm.fill(Qt::color0);
   pb.begin(&bm);
-  pb.setPen(color1);
-  pb.fillRect(0, 0, 24, 16, color1);
-  pb.fillRect(1, 1, width-1, 14, color1);
+  pb.setPen(Qt::color1);
+  pb.fillRect(0, 0, 24, 16, Qt::color1);
+  pb.fillRect(1, 1, width-1, 14, Qt::color1);
   pb.end();
   
   return pm.setMask(bm), pm;
@@ -113,36 +114,36 @@ KiKbdMapsWidget::KiKbdMapsWidget(QWidget* parent)
   mbox->addLayout(hbox, 20);
 
   addToolTip(mapsList=new QListBox(this), 
-	     gettext("List of active keyboard maps"));
-  hbox->addWidget(mapsList, 20);
+	     i18n("List of active keyboard maps"));
+  hbox->addWidget(mapsList, 10);
   connect(mapsList, SIGNAL(highlighted(int)), SLOT(highlighted(int)));
   connect(mapsList, SIGNAL(selected(int)), SLOT(selected(int)));
 
   vbox = new QVBoxLayout(5);
-  hbox->addSpacing(14);
+  hbox->addSpacing(5);
   hbox->addLayout(vbox);
 
   // add
-  wid = mkButton(this, vbox, SLOT(addMap()), this, gettext("&Add"),
-		 gettext("Add new keyboard map"));
+  wid = mkButton(this, vbox, SLOT(addMap()), this, i18n("&Add"),
+		 i18n("Add new keyboard map"));
   accel->connectItem(accel->insertItem(Key_Insert), wid, SLOT(animateClick()));
   // delete
   wid = mkButton(this, vbox, SLOT(deleteMap()), this,
-		 gettext("&Delete"), gettext("Remove selected keyboard map"));
+		 i18n("&Delete"), i18n("Remove selected keyboard map"));
   connect(this, SIGNAL(activateDelete(bool)), wid, SLOT(setEnabled(bool)));
   accel->connectItem(accel->insertItem(Key_Delete), wid, SLOT(animateClick()));
   // up
   wid = mkButton(this, vbox, SLOT(upMap()), this,
-		 gettext("U&p"), gettext("Move up selected keyboard map"));
+		 i18n("U&p"), i18n("Move up selected keyboard map"));
   connect(this, SIGNAL(activateUp(bool)), wid, SLOT(setEnabled(bool)));
   // down
   wid = mkButton(this, vbox, SLOT(downMap()), this,
-		 gettext("D&own"), gettext("Move down selected keyboard map"));
+		 i18n("D&own"), i18n("Move down selected keyboard map"));
   connect(this, SIGNAL(activateDown(bool)), wid, SLOT(setEnabled(bool)));
   // info
   wid = mkButton(this, vbox, SLOT(infoMap()), this,
-		 gettext("&Info"), 
-		 gettext("Display information for selected keyboard map"));
+		 i18n("&Info"), 
+		 i18n("Display information for selected keyboard map"));
   connect(this, SIGNAL(infoClick()), wid, SLOT(animateClick())); 
   connect(this, SIGNAL(activateInfo(bool)), wid, SLOT(setEnabled(bool)));
 
@@ -151,8 +152,8 @@ KiKbdMapsWidget::KiKbdMapsWidget(QWidget* parent)
   mbox->
     addWidget(wid=kikbdConfig->
 	      createWidget(&kikbdConfig->getHotList(), this,
-			   gettext("Use &hot list"),
-			   gettext("Use only default and last active "
+			   i18n("Use &hot list"),
+			   i18n("Use only default and last active "
 				   "keyboard maps when switch key sequence is used")));
   connect(this, SIGNAL(activateHot(bool)), wid, SLOT(setEnabled(bool)));
 
@@ -200,7 +201,7 @@ void KiKbdMapsWidget::chkActive()
   emit activateInfo  (current >= 0);
   emit activateHot   (count > 2);
 }
-void KiKbdMapsWidget::addMap(const char* name)
+void KiKbdMapsWidget::addMap(const QString& name)
 {
   int current = mapsList->currentItem();
   mapsList->insertItem(mapLine(kikbdConfig->getMap(name)),
@@ -221,8 +222,8 @@ void KiKbdMapsWidget::addMap()
       mapsToAdd.insert(sortList.at(), list.at(i));
     }
   if(mapsToAdd.count() == 0) {
-    KMsgBox::message(0, i18n("Adding Keyboard"),
-		     i18n("There are no keyboard maps left to add"));
+    KMessageBox::sorry(0, i18n("There are no keyboard maps left to add"),
+                          i18n("Adding Keyboard"));
     return;
   }
   KiKbdAddDialog addDialog(this);
@@ -260,14 +261,14 @@ void KiKbdMapsWidget::infoMap()
   QBoxLayout *box;
   QBoxLayout *topLayout = new QVBoxLayout(&dialog, 5);
   QGroupBox  *group = new QGroupBox("", &dialog);
-  topLayout->addWidget(group, 20);
+  topLayout->addWidget(group, 10);
   // label
   KiKbdMapInfoWidget *label = new KiKbdMapInfoWidget(group);
   label->changeMap(mapsStr.at(mapsList->currentItem()));
   box = new QVBoxLayout(group, 10);
   box->addWidget(label, 10);
   box->addStretch(1);
-  box->activate();
+  //CT  box->activate(); //CT - obsolete with Qt-2.0
   // ok button
   QPushButton *ok = new QPushButton(i18n("OK"), &dialog);
   ok->setFixedSize(ok->sizeHint());
@@ -279,8 +280,8 @@ void KiKbdMapsWidget::infoMap()
   box->addWidget(ok);
   box->addStretch(10);
 
-  topLayout->activate();
-  dialog.resize(0, 0);
+  //CT  topLayout->activate(); //CT - obsolete with Qt-2.0
+  //CT  dialog.resize(0, 0); //CT - obsolete with Qt-2.0
   dialog.exec();
 }
 
@@ -296,12 +297,12 @@ KiKbdAddDialog::KiKbdAddDialog(QWidget* parent):QDialog(parent, "", TRUE)
   QGroupBox  *group = new QGroupBox(i18n("Available keyboard maps"), 
 				    this);
   topLayout->addWidget(group, 10);
-  groupLayout = new QVBoxLayout(group, 20);
+  groupLayout = new QVBoxLayout(group, 10);
   maps        = new QComboBox(group);
   label       = new KiKbdMapInfoWidget(this);
   groupLayout->addWidget(maps);
   groupLayout->addWidget(label, 10);
-  maps->setMinimumSize(maps->sizeHint());
+  //CT  maps->setMinimumSize(maps->sizeHint()); //CT - obsolete with Qt-2.0
   //--- buttons
   QBoxLayout  *buttons = new QHBoxLayout(10);
   QPushButton *ok      = new QPushButton(i18n("OK"), this);
@@ -326,27 +327,33 @@ KiKbdAddDialog::KiKbdAddDialog(QWidget* parent):QDialog(parent, "", TRUE)
 void KiKbdAddDialog::setInfo(int i)
 {
   label->changeMap(mapsToAdd.at(i));
-  groupLayout->activate();
-  topLayout->activate();
-  resize(0, 0);
 }
+
 int KiKbdAddDialog::exec(const QStrList& toAdd, QStrList& mapStr) 
 { 
   mapsToAdd = toAdd;
   //--- load list of maps
   // also look up prefered language
-  QStrList preferedLang;
+
+  QStringList preferedLang(KGlobal::locale()->languageList());
   int *prefIndex = new int[4];
-  unsigned j;for(j = 0; j < 4; prefIndex[j++]=-1);
-  preferedLang = kapp->getLocale()->languageList();
-  if(preferedLang.find("en") == -1) preferedLang.insert(0, "en");
+
+  for(unsigned j = 0; j < 4; prefIndex[j++]=-1)
+    ;
+
+  //preferedLang = kapp->getLocale()->languageList();
+
+  if(preferedLang.find("en") == preferedLang.end()) 
+    preferedLang.insert(0, "en");
+
   // add
-  unsigned i;for(i = 0; i < mapsToAdd.count(); i++) {
+  for(unsigned i = 0; i < mapsToAdd.count(); i++) {
     KiKbdMapConfig *map = kikbdConfig->getMap(mapsToAdd.at(i));
     maps->insertItem(mapLine(map));
-    for(j = 0; j < 4; j++)
-      if((prefIndex[j] == -1) && preferedLang.at(j) == map->getLocale()) {
-	int k;for(k = mapStr.count(); k-- > 0;) {
+    for(unsigned j = 0; j < 4; j++)
+      if((prefIndex[j] == -1) && *(preferedLang.at(j)) == map->getLocale()) {
+	int k;
+        for(k = mapStr.count(); k-- > 0;) {
 	  KiKbdMapConfig *map1 = kikbdConfig->getMap(mapStr.at(k));
 	  if(map->getLocale() == map1->getLocale()
 	     && map->getCharset() == map1->getCharset()) break;
@@ -354,8 +361,9 @@ int KiKbdAddDialog::exec(const QStrList& toAdd, QStrList& mapStr)
 	if(k < 0) prefIndex[j] = i;
       }
   }
+
   int prefIndex0;
-  for(j=0; j<4 && (prefIndex0=prefIndex[j],prefIndex0 == -1);
+  for(unsigned j=0; j<4 && (prefIndex0=prefIndex[j],prefIndex0 == -1);
       prefIndex0=0, j++);
   delete prefIndex;
   maps->setCurrentItem(prefIndex0);
@@ -373,7 +381,7 @@ KiKbdMapInfoWidget::KiKbdMapInfoWidget(QWidget* parent):QLabel(parent)
 {
   setAlignment(WordBreak);
 }
-void KiKbdMapInfoWidget::changeMap(const char* map)
+void KiKbdMapInfoWidget::changeMap(const QString& map)
 {
   QString      text  = kikbdConfig->getMap(map)->getInfo();
   QStrList     tlist = KObjectConfig::separate(text, '\n');
@@ -399,7 +407,7 @@ void KiKbdMapInfoWidget::changeMap(const char* map)
 KiKbdGeneralWidget::KiKbdGeneralWidget(QWidget* parent)
   :QWidget(parent)
 {
-  QBoxLayout  *topLayout = new QVBoxLayout(this, 20);
+  QBoxLayout  *topLayout = new QVBoxLayout(this, 10);
   QGroupBox   *group = new QGroupBox(i18n("Keyboard maps"), this);
   QVBoxLayout *mbox  = new QVBoxLayout(group, 20);
   QBoxLayout  *hbox;
@@ -412,34 +420,34 @@ KiKbdGeneralWidget::KiKbdGeneralWidget(QWidget* parent)
 
   //--- switches group
   group = new QGroupBox(i18n("Switch and Alt Switch"), this);
-  hbox  = new QHBoxLayout(group, 20);
+  hbox  = new QHBoxLayout(group, 10);
 
   hbox->addWidget(wid=kikbdConfig->
 		  createWidget(&kikbdConfig->getSwitchRef(), group, 0L,
-			       gettext("Key(s) for switching between "
+			       i18n("Key(s) for switching between "
 				       "keyboard maps")));
   connect(wid, SIGNAL(activated(const char*)),  SLOT(newSwitch(const char*)));
 
   hbox->addWidget(wid=kikbdConfig->
 		  createWidget(&kikbdConfig->getAltSwitchRef(), group, 0L,
-			       gettext("Key for activating Alternate "
+			       i18n("Key for activating Alternate "
 				       "symbols in current keyboard map")));
   connect(this, SIGNAL(activateAltSwitch(bool)), wid, SLOT(setEnabled(bool)));
-  group->setMinimumHeight(2*wid->height());
+  //  group->setMinimumHeight(2*wid->height());
 
   topLayout->addWidget(group);
 
   //--- options group
   group = new QGroupBox(i18n("Options"), this);
-  hbox  = new QHBoxLayout(group, 20);
+  hbox  = new QHBoxLayout(group, 10);
 
   hbox->addWidget(kikbdConfig->
 		  createWidget(&kikbdConfig->getKeyboardBeep(), group,
-			       gettext("&Beep"),
-			       gettext("Beep when keyboard "
+			       i18n("&Beep"),
+			       i18n("Beep when keyboard "
 				       "map is changed")));
   wid = mkButton(group, hbox, SLOT(advanced()), this,
-		 gettext("Ad&vanced"), gettext("Advanced options"));
+		 i18n("Ad&vanced"), i18n("Advanced options"));
   group->setMinimumHeight(2*wid->height());
   topLayout->addWidget(group);
 
@@ -447,7 +455,7 @@ KiKbdGeneralWidget::KiKbdGeneralWidget(QWidget* parent)
   connect(kikbdConfig->find(&kikbdConfig->getMaps()), SIGNAL(dataChanged()),
 	  SLOT(listChanged()));
 }
-void KiKbdGeneralWidget::newSwitch(const char*)
+void KiKbdGeneralWidget::newSwitch(const QString&)
 {
   emit activateAltSwitch((!kikbdConfig->oneKeySwitch())
 			 && kikbdConfig->hasAltKeys());
@@ -461,7 +469,7 @@ void KiKbdGeneralWidget::advanced()
   QWidget    *wid, *wid2;
   QBoxLayout *topLayout = new QVBoxLayout(&dialog, 5);
   QGroupBox  *group     = new QGroupBox(&dialog);
-  QBoxLayout *groupLayout = new QVBoxLayout(group, 20);
+  QBoxLayout *groupLayout = new QVBoxLayout(group, 10);
   QBoxLayout *hbox;
 
   topLayout->addWidget(group, 10);
@@ -472,45 +480,45 @@ void KiKbdGeneralWidget::advanced()
   // emulate capslock
   hbox->addWidget(wid=kikbdConfig->
 		  createWidget(&kikbdConfig->getEmuCapsLock(), group,
-			       gettext("&Emulate Caps Lock"), 
-			       gettext("Emulate XServer "
+			       i18n("&Emulate Caps Lock"), 
+			       i18n("Emulate XServer "
 				       "Caps Lock. Needed for correct "
 				       "keyboard operation in some languages")));
   // auto menu
   hbox->addWidget(kikbdConfig->
 		  createWidget(&kikbdConfig->getAutoMenu(), group,
-			       gettext("&World Menu"), 
-			       gettext("Show menu in any window by "
-				       "holding sown the selected "
-				       "Switch key(s)")));
+			       i18n("&World Menu"), 
+			       i18n("Show menu in any window by "
+				    "holding down the selected "
+				    "Switch keys")));
   // save classes
   hbox = new QHBoxLayout();
   groupLayout->addLayout(hbox);
   hbox->addWidget(wid2=kikbdConfig->
 		  createWidget(&kikbdConfig->getSaveClasses(), group,
-			       gettext("&Save Classes"), 
-			       gettext("Save relations between window "
+			       i18n("&Save Classes"), 
+			       i18n("Save relations between window "
 				       "classes and keyboard maps on exit")));
   // custom codes
   hbox->addWidget(kikbdConfig->
 		  createWidget(&kikbdConfig->getCodes(), group,
 			       0L, 
-			       gettext("Define X codes")));
+			       i18n("Define X codes")));
   // input
   QButtonGroup* butg = (QButtonGroup*)kikbdConfig->
-    createWidget(&kikbdConfig->getInput(), group, gettext("Input"));
-  hbox = new QHBoxLayout(butg, 15);
+    createWidget(&kikbdConfig->getInput(), group, i18n("Input"));
+  hbox = new QHBoxLayout(butg, 10);
   // global
   hbox->addWidget(wid=butg->find(0));
-  addToolTip(wid, gettext("Standard behavior. Keyboard map effective for "
+  addToolTip(wid, i18n("Standard behavior. Keyboard map effective for "
 			  "all windows"));
   // window
   hbox->addWidget(wid=butg->find(1));
-  addToolTip(wid, gettext("Extended behavior. Keyboard map state is saved for "
+  addToolTip(wid, i18n("Extended behavior. Keyboard map state is saved for "
 			  "each window independently"));
   // class
   hbox->addWidget(wid=butg->find(2));
-  addToolTip(wid, gettext("Special behavior. Keyboard state is saved for each "
+  addToolTip(wid, i18n("Special behavior. Keyboard state is saved for each "
 			  "window class independently"));
 
   groupLayout->addWidget(butg);
@@ -530,10 +538,10 @@ void KiKbdGeneralWidget::advanced()
   hbox->addWidget(ok);
   hbox->addStretch(10);
 
-  groupLayout->activate();
-  topLayout->activate();
+  //CT  groupLayout->activate(); //CT - obsolete with Qt-2.0
+  //CT   topLayout->activate();//CT - obsolete with Qt-2.0
 
-  dialog.resize(0, 0);  
+  //CT  dialog.resize(0, 0);  //CT - obsolete with Qt-2.0
   dialog.exec();
 }
 
@@ -543,13 +551,13 @@ void KiKbdGeneralWidget::advanced()
    button font
 */
 void makeColorButton (QVBoxLayout* layout, QWidget* but, QLabel*& label,
-			  const char* text, const char* tip) {
+			  const QString& text, const QString& tip) {
   QHBoxLayout* hbox = new QHBoxLayout();
   label = new QLabel(i18n(text), but->parentWidget());
 
   layout->addLayout(hbox);
   but->setMinimumSize(100, 30);
-  label->setMinimumSize(label->sizeHint());
+  //CT  label->setMinimumSize(label->sizeHint()); //CT - obsolete with Qt-2.0
   hbox->addWidget(but  , 0);
   hbox->addWidget(label, 0);
   hbox->addStretch(10);
@@ -557,10 +565,10 @@ void makeColorButton (QVBoxLayout* layout, QWidget* but, QLabel*& label,
 }
 KiKbdStyleWidget::KiKbdStyleWidget(QWidget* parent):QWidget(parent)
 {
-  QBoxLayout *topLayout = new QVBoxLayout(this, 20);
+  QBoxLayout *topLayout = new QVBoxLayout(this, 10);
   QGroupBox *group = new QGroupBox(i18n("Button Colors"),
 				   this);
-  QVBoxLayout *vbox = new QVBoxLayout(group, 25);
+  QVBoxLayout *vbox = new QVBoxLayout(group, 20);
   QHBoxLayout *hbox;
   QLabel      *label;
   QWidget     *but;
@@ -568,29 +576,29 @@ KiKbdStyleWidget::KiKbdStyleWidget(QWidget* parent):QWidget(parent)
   topLayout->addWidget(group, 10);
   // foreground button color
   but = kikbdConfig->createWidget(&kikbdConfig->getForColor(), group);
-  makeColorButton(vbox, but, label, gettext("Foreground"), 
-		  gettext("Text label foreground color"));
+  makeColorButton(vbox, but, label, i18n("Foreground"), 
+		  i18n("Text label foreground color"));
 
   // background button color
   but = kikbdConfig->createWidget(&kikbdConfig->getBakColor(), group);
-  makeColorButton(vbox, but, label, gettext("Background"), 
-		  gettext("Text label background color"));
+  makeColorButton(vbox, but, label, i18n("Background"), 
+		  i18n("Text label background color"));
 
   // caps  color
   but = kikbdConfig->createWidget(&kikbdConfig->getCapsColor(), group);
-  makeColorButton(vbox, but, label, gettext("With Caps Lock"), 
-		  gettext("Background when Emulated Caps Lock active"));
+  makeColorButton(vbox, but, label, i18n("With Caps Lock"), 
+		  i18n("Background when Emulated Caps Lock active"));
   connect(this, SIGNAL(enableCaps(bool)), but, SLOT(setEnabled(bool)));
   connect(this, SIGNAL(enableCaps(bool)), label, SLOT(setEnabled(bool)));
 
   //  alternate color
   but = kikbdConfig->createWidget(&kikbdConfig->getAltColor(), group);
-  makeColorButton(vbox, but, label, gettext("With Alternate"), 
-		  gettext("Background when Alternate switch key is pressed"));
+  makeColorButton(vbox, but, label, i18n("With Alternate"), 
+		  i18n("Background when Alternate switch key is pressed"));
   connect(this, SIGNAL(enableAlternate(bool)), but, SLOT(setEnabled(bool)));
   connect(this, SIGNAL(enableAlternate(bool)), label, SLOT(setEnabled(bool)));
 
-  vbox->addStretch(10);
+  //CT  vbox->addStretch(10);
 
   /**
      font
@@ -603,17 +611,17 @@ KiKbdStyleWidget::KiKbdStyleWidget(QWidget* parent):QWidget(parent)
 
   QWidget *but2 = kikbdConfig->
     createWidget(&kikbdConfig->getCustFont(), group, 
-		 gettext("&Customize Font"),
-		 gettext("Customize Font for text label or use global "
+		 i18n("&Customize Font"),
+		 i18n("Customize Font for text label or use global "
 			 "settings"));
   hbox->addWidget(but2, 2);
   but = kikbdConfig->createWidget(&kikbdConfig->getFont(), group,
-				  gettext("C&hange Font"));
-  but->setMinimumSize(but->sizeHint());
+				  i18n("C&hange Font"));
+  //CT  but->setMinimumSize(but->sizeHint()); //CT - obsolete with Qt-2.0
   hbox->addWidget(but);
   hbox->addStretch(5);
   vbox->addStretch(5);
-  group->setMinimumHeight(3*but->height());
+  //CT  group->setMinimumHeight(3*but->height()); //CT - obsolete with Qt-2.0
   connect(but2, SIGNAL(toggled(bool)), but, SLOT(setEnabled(bool)));
   but->setEnabled(kikbdConfig->getCustFont());
 
@@ -640,28 +648,28 @@ void KiKbdStyleWidget::checkShow()
 //=========================================================
 KiKbdStartupWidget::KiKbdStartupWidget(QWidget* parent):QWidget(parent)
 {
-  QBoxLayout *topLayout = new QVBoxLayout(this, 20);
+  QBoxLayout *topLayout = new QVBoxLayout(this, 10);
   QGroupBox  *group     = new QGroupBox("", this);
   QBoxLayout *vbox;
   QWidget    *widget;
 
   topLayout->addWidget(group, 5);
-  vbox  = new QVBoxLayout(group, 20);
+  vbox  = new QVBoxLayout(group, 10);
   /**
      Autostart?
   */
   vbox->
     addWidget(kikbdConfig->
 	      createWidget(&kikbdConfig->getAutoStart(), group,
-			   gettext("&Autostart"),
-			   gettext("Start up automatically")), 0);
+			   i18n("&Autostart"),
+			   i18n("Start up automatically")), 0);
   /**
      Do docking?
   */
   vbox->addWidget(widget=kikbdConfig->
 		  createWidget(&kikbdConfig->getDocking(), group, 
-			       gettext("&Docked"),
-			       gettext("Dock into special area in the panel")),
+			       i18n("&Docked"),
+			       i18n("Dock into special area in the panel")),
 		  0);
   connect(widget, SIGNAL(toggled(bool)), SLOT(slotInvert(bool)));
 
@@ -671,17 +679,17 @@ KiKbdStartupWidget::KiKbdStartupWidget(QWidget* parent):QWidget(parent)
   QBoxLayout *hbox = new QHBoxLayout();
   vbox->addLayout(hbox);
   hbox->addWidget(widget=new QLabel(i18n("Place"), group), 0);
-  widget->setMinimumSize(widget->sizeHint());
+  //CT  widget->setMinimumSize(widget->sizeHint()); //CT - obsolete with Qt-2.0
   widget->setEnabled(!kikbdConfig->getDocking());
   connect(this, SIGNAL(signalInvert(bool)), widget, SLOT(setEnabled(bool)));
 
   hbox->addWidget(widget=kikbdConfig->
 		  createWidget(&kikbdConfig->getAutoStartPlace(), group,
-			       gettext("Place in selected corner")), 0);
+			       i18n("Place in selected corner")), 0);
   connect(this, SIGNAL(signalInvert(bool)), widget, SLOT(setEnabled(bool)));
   widget->setEnabled(!kikbdConfig->getDocking());
   hbox->addStretch(5);
 
-  vbox->addSpacing(20);
-  topLayout->addStretch(20);
+  vbox->addSpacing(10);
+  topLayout->addStretch(10);
 }
