@@ -26,11 +26,16 @@ public:
   HelpProtocol( const QCString &pool, const QCString &app);
   virtual ~HelpProtocol() { }
 
-  virtual void get( const QString& path, const QString& query, bool reload );
+  virtual void get( const KURL& url, bool reload );
 
-  virtual void stat( const QString& path, const QString& query );
+  virtual void mimetype( const KURL& url );
 
-  void createUDSEntry( const QString & filename, const QString & path, KIO::UDSEntry & entry );
+
+private:
+
+  QString langLookup(QString fname);
+  
+  QString lookupFile(QString fname, QString query, bool &redirect);
 
 };
 
