@@ -1,5 +1,5 @@
 #ifndef __LDAP_H__
-#define __LDAP_H__ "$Id: kio_ldap.h,v 1.4 2000/04/17 20:17:12 matz Exp $"
+#define __LDAP_H__ "$Id: kio_ldap.h,v 1.6 2000/05/31 07:06:26 matz Exp $"
 
 //#include <sys/types.h>
 //#include <sys/stat.h>
@@ -21,9 +21,10 @@ public:
   virtual void setHost(const QString& host, int port,
 		       const QString& user, const QString& pass);
 
-  virtual void get( const QString& __url, const QString& query, bool reload );
-  virtual void stat( const QString& path, const QString& query );
-  virtual void listDir( const QString& path, const QString& query );
+  virtual void get( const KURL& url, bool reload );
+  virtual void stat( const KURL& url );
+  virtual void mimetype( const KURL& url );
+  virtual void listDir( const KURL& url );
 
 private:
   QString urlPrefix;
