@@ -1,4 +1,4 @@
-// $Id: pop3.cc,v 1.46 2000/04/17 20:17:13 matz Exp $
+// $Id: pop3.cc,v 1.53 2000/06/04 22:06:05 porten Exp $
 #ifdef HAVE_CONFIG_H
 #include <config.h>
 #endif
@@ -32,6 +32,7 @@
 #include <kio/connection.h>
 #include <kio/slaveinterface.h>
 #include <kio/passdlg.h>
+#include <klocale.h>
 
 #include "pop3.h"
 
@@ -47,13 +48,50 @@ using namespace KIO;
 
 extern "C" { int kdemain(int argc, char **argv); }
 
+#ifdef SPOP3
+
+int SSL_readline(SSL *ssl, char *buf, int num) {
+int c = 0;
+  if (num <= 0) return -2;
+
+  buf[num-1] = 0;
+
+  for (c = 0; c < num-1; c++) {
+    char x;
+    int rc = SSL_read(ssl, &x, 1);
+    if (rc <= 0)
+      return rc;
+
+    buf[c] = x;
+
+    if (x == '\n') {  
+      buf[c+1] = 0;
+      break;
+    }
+  }
+
+  if (c == num-1)
+    return c;
+return c+1;
+}
+
+#endif
+
 int kdemain( int argc, char **argv )
 {
+#ifdef SPOP3
+  KInstance instance( "kio_spop3" );
+#else
   KInstance instance( "kio_pop3" );
+#endif
 
   if (argc != 4)
   {
+#ifdef SPOP3
+     fprintf(stderr, "Usage: kio_spop3 protocol domain-socket1 domain-socket2\n");
+#else
      fprintf(stderr, "Usage: kio_pop3 protocol domain-socket1 domain-socket2\n");
+#endif
      exit(-1);
   }
 
@@ -62,8 +100,13 @@ int kdemain( int argc, char **argv )
   return 0;
 }
 
+
 POP3Protocol::POP3Protocol(const QCString &pool, const QCString &app)
+#ifdef SPOP3
+  : SlaveBase( "spop3", pool, app)
+#else
   : SlaveBase( "pop3", pool, app)
+#endif
 {
   debug( "POP3Protocol()" );
   m_cmd = CMD_NONE;
@@ -71,27 +114,31 @@ POP3Protocol::POP3Protocol(const QCString &pool, const QCString &app)
   m_tTimeout.tv_sec=10;
   m_tTimeout.tv_usec=0;
   fp = 0;
+
+#ifdef SPOP3
+  ssl = NULL;
+  SSLeay_add_ssl_algorithms();
+  meth = SSLv2_client_method();  // should we allow v2/v3??
+  SSL_load_error_strings();
+  ctx = SSL_CTX_new(meth);
+#endif
 }
 
 POP3Protocol::~POP3Protocol()
 {
   debug( "~POP3Protocol()" );
   pop3_close();
+#ifdef SPOP3
+  SSL_CTX_free(ctx);
+#endif
 }
 
 void POP3Protocol::setHost( const QString& _host, int _port, const QString& _user, const QString& _pass )
 {
-  urlPrefix = "pop3://";
-  if (!_user.isEmpty()) {
-    urlPrefix += _user;
-    if (!_pass.isEmpty())
-      urlPrefix += ":" + _pass;
-    urlPrefix += "@";
-  }
-  urlPrefix += _host;
-  if (_port)
-    urlPrefix += QString( ":%1" ).arg( _port );
-  debug( "urlPrefix " + urlPrefix );
+  m_sServer = _host;
+  m_iPort = _port;
+  m_sUser = _user;
+  m_sPass = _pass;
 }
 
 bool POP3Protocol::getResponse (char *r_buf, unsigned int r_len)
@@ -131,10 +178,19 @@ bool POP3Protocol::getResponse (char *r_buf, unsigned int r_len)
   // Clear out the buffer
   memset(buf, 0, r_len);
   // And grab the data
+#ifdef SPOP3
+  int rc = SSL_readline(ssl, buf, r_len-1);
+  if (rc <= 0) {
+    if (buf) free(buf);
+    return false;
+  }
+  buf[rc] = 0;
+#else
   if (fgets(buf, r_len-1, fp) == 0) {
     if (buf) free(buf);
     return false;
   }
+#endif
   // This is really a funky crash waiting to happen if something isn't
   // null terminated.
   recv_len=strlen(buf);
@@ -186,11 +242,20 @@ bool POP3Protocol::command (const char *cmd, char *recv_buf, unsigned int len)
  *   argument may be up to 40 characters long.
  */
 
+#ifdef SPOP3
+  // Write the command
+  int rc = SSL_write(ssl, cmd, strlen(cmd));
+  if (rc <= 0) return false;
+
+  rc = SSL_write(ssl, "\r\n", 2);
+  if (rc <= 0) return false;
+#else
   // Write the command
   if (::write(m_iSock, cmd, strlen(cmd)) != (ssize_t)strlen(cmd))
     return false;
   if (::write(m_iSock, "\r\n", 2) != 2)
     return false;
+#endif
   return getResponse(recv_buf, len);
 }
 
@@ -202,15 +267,27 @@ void POP3Protocol::pop3_close ()
   // response.  We don't care if it's positive or negative.  Also
   // flush out any semblance of a persistant connection, i.e.: the
   // old username and password are now invalid.
+#ifdef SPOP3
+  if (ssl) {
+    (void)command("QUIT");
+    close(m_iSock);
+    SSL_shutdown(ssl);
+    SSL_free(ssl);
+    ssl = NULL;
+    m_iSock=0;
+    m_sOldUser = ""; m_sOldPass = ""; m_sOldServer = "";
+  }
+#else
   if (fp) {
     (void)command("QUIT");
     fclose(fp);
     m_iSock=0; fp=0;
     m_sOldUser = ""; m_sOldPass = ""; m_sOldServer = "";
   }
+#endif
 }
 
-bool POP3Protocol::pop3_open( KURL &_url )
+bool POP3Protocol::pop3_open()
 {
   // This function is simply a wrapper to establish the connection
   // to the server.  It's a bit more complicated than ::connect
@@ -225,20 +302,75 @@ bool POP3Protocol::pop3_open( KURL &_url )
 
   // We want 110 as the default, but -1 means no port was specified.
   // Why 0 wasn't chosen is beyond me.
-  port = _url.port() ? _url.port() : 110;
-  if ( (m_iOldPort == port) && (m_sOldServer == _url.host()) && (m_sOldUser == _url.user()) && (m_sOldPass == _url.pass())) {
+ 
+#ifdef SPOP3
+  if (m_iPort) {
+    port = m_iPort;
+  } else {
+    struct servent *sent = getservbyname("spop3", "tcp");
+    if (sent) {
+       port = ntohs(sent->s_port);
+    } else {
+       port = 995;
+    }
+  }
+#else
+  if (m_iPort) {
+    port = m_iPort;
+  } else {
+    struct servent *sent = getservbyname("pop-3", "tcp");
+    if (sent) {
+       port = ntohs(sent->s_port);
+    } else {
+       port = 110;
+    }
+  }
+#endif
+  if ( (m_iOldPort == port) && (m_sOldServer == m_sServer) && 
+       (m_sOldUser == m_sUser) && (m_sOldPass == m_sPass)) {
     fprintf(stderr,"Reusing old connection\n");
     return true;
   } else {
     pop3_close();
     m_iSock = ::socket(PF_INET, SOCK_STREAM, 0);
-    if (!KSocket::initSockaddr(&server_name, _url.host(), port))
+    if (!KSocket::initSockaddr(&server_name, m_sServer, port))
       return false;
     if (::connect(m_iSock, (struct sockaddr*)(&server_name), sizeof(server_name))) {
-      error( ERR_COULD_NOT_CONNECT, strdup(_url.host()));
+      error( ERR_COULD_NOT_CONNECT, m_sServer);
       return false;
     }
 
+#ifdef SPOP3
+    // do the SSL negotiation
+    ssl = SSL_new(ctx);
+    if (!ssl) {
+      error( ERR_COULD_NOT_CONNECT, m_sServer );
+      close(m_iSock);
+      return false;
+    }
+
+    SSL_set_fd(ssl, m_iSock);
+    if (-1 == SSL_connect(ssl)) {
+      error( ERR_COULD_NOT_CONNECT, m_sServer );
+      close(m_iSock);
+      SSL_shutdown(ssl);
+      SSL_free(ssl);
+      return false;
+    }
+
+    server_cert = SSL_get_peer_certificate(ssl);
+    if (!server_cert) {
+      error( ERR_COULD_NOT_CONNECT, m_sServer );
+      close(m_iSock);
+      SSL_shutdown(ssl);
+      SSL_free(ssl);
+      return false;
+    }
+
+    // we should verify the certificate here
+
+    X509_free(server_cert);
+#else
     // Since we want to use stdio on the socket,
     // we must fdopen it to get a file pointer,
     // if it fails, close everything up
@@ -246,6 +378,7 @@ bool POP3Protocol::pop3_open( KURL &_url )
       close(m_iSock);
       return false;
     }
+#endif
 
     QCString greeting( 1024 );
     // If the server doesn't respond with a greeting
@@ -266,18 +399,18 @@ bool POP3Protocol::pop3_open( KURL &_url )
 #endif
 
     m_iOldPort = port;
-    m_sOldServer = _url.host();
+    m_sOldServer = m_sServer;
 
     QString usr, pass, one_string="USER ";
 #ifdef APOP
     QString apop_string = "APOP ";
 #endif
-    if (_url.user().isEmpty() || _url.pass().isEmpty()) {
+    if (m_sUser.isEmpty() || m_sPass.isEmpty()) {
       // Prompt for usernames
-      QString head="Username and password for your POP3 account:";
+      QString head=i18n("Username and password for your POP3 account:");
       if (!openPassDlg(head, usr, pass)) {
-	return false;
 	pop3_close();
+	return false;
       } else {
 #ifdef APOP
 	apop_string.append(usr);
@@ -287,25 +420,24 @@ bool POP3Protocol::pop3_open( KURL &_url )
       }
     } else {
 #ifdef APOP
-      apop_string.append(_url.user());
+      apop_string.append(m_sUser);
 #endif
-      one_string.append(_url.user());
-      m_sOldUser = _url.user();
+      one_string.append(m_sUser);
+      m_sOldUser = m_sUser;
     }
 
     memset(buf, 0, sizeof(buf));
 #ifdef APOP
     if(apop) {
       char *c = greeting.data() + apop_pos;
-      char *pass;
       unsigned char digest[16];
       char ascii_digest[33];
       Bin_MD5Context ctx;
 
-      if (_url.pass().isEmpty())
+      if ( m_sPass.isEmpty())
 	m_sOldPass = pass;
       else
-	m_sOldPass = _url.pass();
+	m_sOldPass = m_sPass;
 
       // Generate digest
       Bin_MD5Init(&ctx);
@@ -338,12 +470,12 @@ bool POP3Protocol::pop3_open( KURL &_url )
     }
     
     one_string="PASS ";
-    if (_url.pass().isEmpty()) {
+    if (m_sPass.isEmpty()) {
       m_sOldPass = pass;
       one_string.append(pass);
     } else {
-      m_sOldPass = _url.pass();
-      one_string.append(_url.pass());
+      m_sOldPass = m_sPass;
+      one_string.append(m_sPass);
     }
     if (!command(one_string, buf, sizeof(buf))) {
       fprintf(stderr, "Couldn't login. Bad password Sorry\n");
@@ -374,7 +506,7 @@ size_t POP3Protocol::realGetSize(unsigned int msg_num)
   return ret;
 }
 
-void POP3Protocol::get( const QString& __url, const QString&, bool )
+void POP3Protocol::get( const KURL& url, bool )
 {
 // List of supported commands
 //
@@ -396,33 +528,20 @@ void POP3Protocol::get( const QString& __url, const QString&, bool )
   bool ok=true;
   static char buf[512];
   QByteArray array;
-  QString path, cmd;
-  QString _url = urlPrefix + __url;
-  KURL usrc(_url);
-  if ( usrc.isMalformed() ) {
-    error( ERR_MALFORMED_URL, _url );
-    m_cmd = CMD_NONE;
-    return;
-  }
-
-  if (usrc.protocol() != "pop3") {
-    error( ERR_INTERNAL, "kio_pop3 got non pop3 url" );
-    m_cmd = CMD_NONE;
-    return;
-  }
-
-  path = usrc.path().copy();
 
+  QString cmd;
+  QString path = url.path();
+  
   if (path.at(0)=='/') path.remove(0,1);
   if (path.isEmpty()) {
     debug("We should be a dir!!");
-    error(ERR_IS_DIRECTORY, _url);
+    error(ERR_IS_DIRECTORY, url.url());
     m_cmd=CMD_NONE; return;
   }
 
   if (((path.find("/") == -1) && (path != "index") &&
        (path != "uidl") && (path != "commit")) ) {
-    error( ERR_MALFORMED_URL, _url );
+    error( ERR_MALFORMED_URL, url.url() );
     m_cmd = CMD_NONE;
     return;
   }
@@ -430,9 +549,13 @@ void POP3Protocol::get( const QString& __url, const QString&, bool )
   cmd = path.left(path.find("/"));
   path.remove(0,path.find("/")+1);
 
-  if (!pop3_open(usrc)) {
+  if (!pop3_open()) {
+#ifdef SPOP3
+    fprintf(stderr,"spop3_open failed\n");
+#else
     fprintf(stderr,"pop3_open failed\n");
-    error( ERR_COULD_NOT_CONNECT, strdup(usrc.host()));
+#endif
+    error( ERR_COULD_NOT_CONNECT, m_sServer);
     pop3_close();
     return;
   }
@@ -446,11 +569,17 @@ void POP3Protocol::get( const QString& __url, const QString&, bool )
       result = command("UIDL");
     if (result) {
       //ready();
-      gettingFile(_url);
+      gettingFile(url.url());
+#ifdef SPOP3
+      while (SSL_pending(ssl)) {
+        memset(buf, 0, sizeof(buf));
+        SSL_readline(ssl, buf, sizeof(buf)-1);
+#else
       while (!feof(fp)) {
 	memset(buf, 0, sizeof(buf));
 	if (!fgets(buf, sizeof(buf)-1, fp))
 	  break;  // Error??
+#endif
 	// HACK: This assumes fread stops at the first \n and not \r
 	if (strcmp(buf, ".\r\n")==0) break; // End of data
 	// sanders, changed -2 to -1 below
@@ -494,15 +623,19 @@ LIST
                          // and stopping at the first blank line used if the
                          // TOP cmd isn't supported
       //ready();
-      gettingFile(_url);
+      gettingFile(url.url());
       mimeType("text/plain");
       memset(buf, 0, sizeof(buf));
+#ifdef SPOP3
+      while (SSL_pending(ssl)) {
+        memset(buf, 0, sizeof(buf));
+        SSL_readline(ssl, buf, sizeof(buf)-1);
+#else
       while (!feof(fp)) {
-	fprintf(stderr,"xxxxxxxxxxxFinishing up\n");
 	memset(buf, 0, sizeof(buf));
 	if (!fgets(buf, sizeof(buf)-1, fp))
 	  break;  // Error??
-
+#endif
 	// HACK: This assumes fread stops at the first \n and not \r
 	if (strcmp(buf, ".\r\n")==0) break; // End of data
 	// sanders, changed -2 to -1 below
@@ -548,14 +681,14 @@ LIST
       list_cmd=buf;
       // We need a space, otherwise we got an invalid reply
       if (!list_cmd.find(" ")) {
-	kDebugInfo(7105, "List command needs a space? %s", debugString(list_cmd));
+	kdDebug(7105) << "List command needs a space? " << list_cmd << endl;
         pop3_close();
         return;
       }
       list_cmd.remove(0, list_cmd.find(" ")+1);
       msg_len = list_cmd.toUInt(&ok);
       if (!ok) {
-	  kDebugInfo(7105, "LIST command needs to return a number? :%s:", debugString(list_cmd));
+	kdDebug(7105) << "LIST command needs to return a number? :" << list_cmd << ":" << endl;
 	pop3_close();return;
       }
     } else {
@@ -563,14 +696,20 @@ LIST
     }
     if (command(path)) {
       //ready();
-      gettingFile(_url);
+      gettingFile(url.url());
       mimeType("message/rfc822");
       totalSize(msg_len);
       memset(buf, 0, sizeof(buf));
+#ifdef SPOP3
+      while (SSL_pending(ssl)) {
+        memset(buf, 0, sizeof(buf));
+        SSL_readline(ssl, buf, sizeof(buf)-1);
+#else
       while (!feof(fp)) {
 	memset(buf, 0, sizeof(buf));
 	if (!fgets(buf, sizeof(buf)-1, fp))
 	  break;  // Error??
+#endif
 	// HACK: This assumes fread stops at the first \n and not \r
 	if (strcmp(buf, ".\r\n")==0) break; // End of data
 	// sanders, changed -2 to -1 below
@@ -603,7 +742,7 @@ LIST
     if (command(path, buf, sizeof(buf)-1)) {
       const int len = strlen(buf);
       //ready();
-      gettingFile(_url);
+      gettingFile(url.url());
       mimeType("text/plain");
       totalSize(len);
       array.setRawData(buf, len);
@@ -629,21 +768,20 @@ LIST
 
 }
 
-void POP3Protocol::listDir( const QString & _path, const QString& /*query*/ )
+void POP3Protocol::listDir( const KURL & /* url*/ )
 {
   bool isINT; int num_messages=0;
   char buf[512];
   QCString q_buf;
-  QString _url = urlPrefix + _path;
-  KURL usrc( _url );
-  if ( usrc.isMalformed() ) {
-    error( ERR_MALFORMED_URL, _url );
-    return;
-  }
+
   // Try and open a connection
-  if (!pop3_open(usrc)) {
+  if (!pop3_open()) {
+#ifdef SPOP3
+    fprintf(stderr,"spop3_open failed\n");
+#else
     fprintf(stderr,"pop3_open failed\n");
-    error( ERR_COULD_NOT_CONNECT, strdup(usrc.host()));
+#endif
+    error( ERR_COULD_NOT_CONNECT, m_sServer);
     pop3_close();
     return;
   }
@@ -687,17 +825,20 @@ void POP3Protocol::listDir( const QString & _path, const QString& /*query*/ )
     fprintf(stderr,"Mimetype is %s\n", atom.m_str.ascii());
 
     atom.m_uds = UDS_URL;
-    QString uds_url;
-    if (usrc.user().isEmpty() || usrc.pass().isEmpty()) {
-      uds_url="pop3://%1/download/%2";
-      atom.m_str = uds_url.arg(usrc.host()).arg(i+1);
-    } else {
-      uds_url="pop3://%1:%2@%3/download/%3";
-      atom.m_str = uds_url.arg(usrc.user()).arg(usrc.pass()).arg(usrc.host()).arg(i+1);
-    }
+    KURL uds_url;
+#ifdef SPOP3
+    uds_url.setProtocol("spop3");
+#else
+    uds_url.setProtocol("pop3");
+#endif
+    uds_url.setUser(m_sUser);
+    uds_url.setPass(m_sPass);
+    uds_url.setHost(m_sServer);
+    uds_url.setPath(QString::fromLatin1("/download/%1").arg(i+1));
+    atom.m_str = uds_url.url();
     atom.m_long = 0;
     entry.append(atom);
-    fprintf(stderr,"URL is %s\n", atom.m_str.ascii());
+fprintf(stderr,"URL is %s\n", atom.m_str.ascii());
 
     atom.m_uds = UDS_FILE_TYPE;
     atom.m_str = "";
@@ -717,9 +858,9 @@ void POP3Protocol::listDir( const QString & _path, const QString& /*query*/ )
   finished();
 }
 
-void POP3Protocol::stat( const QString & path, const QString& /*query*/ )
+void POP3Protocol::stat( const KURL & url )
 {
-  QString _path = path;
+  QString _path = url.path();
   if (_path.at(0) == '/')
     _path.remove(0,1);
 
@@ -735,27 +876,23 @@ void POP3Protocol::stat( const QString & path, const QString& /*query*/ )
   finished();
 }
 
-void POP3Protocol::del( const QString& path, bool /*isfile*/ )
+void POP3Protocol::del( const KURL& url, bool /*isfile*/ )
 {
-  QString _url = urlPrefix + path;
-  KURL usrc(_url);
   QString invalidURI=QString::null;
   bool isInt;
 
-  if ( usrc.isMalformed() ) {
-    error( ERR_MALFORMED_URL, _url );
-    m_cmd = CMD_NONE;
-    return;
-  }
-
-  if ( !pop3_open(usrc) ) {
+  if ( !pop3_open() ) {
+#ifdef SPOP3
+    fprintf(stderr,"spop3_open failed\n");
+#else
     fprintf(stderr,"pop3_open failed\n");
-    error( ERR_COULD_NOT_CONNECT, strdup(usrc.host()));
+#endif
+    error( ERR_COULD_NOT_CONNECT, m_sServer );
     pop3_close();
     return;
   }
   
-  QString _path = path;
+  QString _path = url.path();
   if (_path.at(0) == '/')
     _path.remove(0,1);
   (void)_path.toUInt(&isInt);
