@@ -22,8 +22,10 @@
 
 #include <kshred.h>
 #include <kdebug.h>
+#include <klocale.h>
 #include <kurl.h>
 #include <kprotocolmanager.h>
+#include <kmimemagic.h>
 #include <kinstance.h>
 
 #include <kconfig.h>
@@ -44,7 +46,7 @@ protected:
 	bool havePass;
 	bool haveServicePass;
 public:
-	MyCallback(SmbProtocol *p) : proto(p), 
+	MyCallback(SmbProtocol *p) : proto(p),
 		user(0), pass(0), service(0),
         	havePass(false), haveServicePass(false) {}
 	~MyCallback() {
@@ -70,17 +72,16 @@ public:
 						if (pass) delete pass;
 						pass = new char[it->password.local8Bit().length()+1];
 						strcpy(pass,it->password.local8Bit().data());
-						kDebugInfo( 7106, "CallBack: use binding: user=%s, pass=%s", debugString(user), debugString(pass));
+						kdDebug(7106) << "CallBack: use binding: user=" << user << ", pass=" << pass << endl;
 						havePass=true;
 						return user;
 					}
 				}
-				message = "Login for host ";
-				message += optmessage;
+				message = i18n("Login for host %1").arg(optmessage);
 				myUser = user?user:"";
 				myPass = "";
-				res = proto->openPassDlg(message, myUser, myPass);
-				kDebugInfo( 7106, "CallBack: res=%s", res?debugString("true"):debugString("false"));
+				res = proto->openPassDlg(message, myUser, myPass, optmessage);
+				kdDebug(7106) << "CallBack: res=" << (res?"true":"false") << endl;
 				if (!res) {
 					if (user) {delete user; user = 0;}
 					if (pass) {delete pass; pass = 0;}
@@ -92,7 +93,7 @@ public:
 					if (pass) delete pass;
 					pass=new char[myPass.local8Bit().length()+1];
 					strcpy(pass,myPass.local8Bit().data());
-					kDebugInfo( 7106, "CallBack: user=%s, pass=%s", debugString(user), debugString(pass));
+					kdDebug(7106) << "CallBack: user=" << user << ", pass=" << pass << endl;
 					havePass=true;
 					// Store the new binding info in case of success
 					proto->bserver = optmessage;
@@ -104,12 +105,11 @@ public:
 			
 			case ANSWER_USER_PASSWORD:
 				if (havePass) return pass;
-				message = "Password for user ";
-				message += optmessage;
+				message = i18n("Password for user %1").arg(optmessage);
 				myUser = optmessage;
 				myPass = "";
-				res = proto->openPassDlg(message, myUser, myPass);
-				kDebugInfo( 7106, "CallBack: res=%s", res?debugString("true"):debugString("false"));
+				res = proto->openPassDlg(message, myUser, myPass, proto->currentHost);
+				kdDebug(7106) << "CallBack: res=" << (res?"true":"false") << endl;
 				if (!res) {
 					if (user) {delete user; user = 0;}
 					if (pass) {delete pass; pass = 0;}
@@ -121,7 +121,7 @@ public:
 					if (pass) delete pass;
 					pass=new char[myPass.local8Bit().length()+1];
 					strcpy(pass,myPass.local8Bit().data());
-					kDebugInfo( 7106, "CallBack: user=%s, pass=%s", debugString(user), debugString(pass));
+					kdDebug(7106) << "CallBack: user=" << user << ", pass=" << pass << endl;
 					havePass=true;
 					// Store the new binding info in case of success
 					proto->bserver = proto->currentHost;
@@ -145,19 +145,17 @@ public:
 						if (pass) delete pass;
 						pass = new char[it->password.local8Bit().length()+1];
 						strcpy(pass,it->password.local8Bit().data());
-						kDebugInfo( 7106, "CallBack: use binding: service=%s, pass=%s", debugString(service), debugString(pass));
+						kdDebug(7106) << "CallBack: use binding: service=" << service << ", pass=" << pass << endl;
 						haveServicePass=true;
 						return pass;
 					}
 				}
-				message = "Password for service ";
-				message += optmessage;
-				message += " (user ignored)";
+				message = i18n("Password for service %1 (user ignored)").arg(optmessage);
 				myUser = user?user:"";
 				myPass = "";
-				res = proto->openPassDlg(message, myUser, myPass);
-				kDebugInfo( 7106, "CallBack: res=%s", res?debugString("true"):debugString("false"));
-				kDebugInfo( 7106, "CallBack: user=%s, pass=%s", debugString(user), debugString(pass));
+				res = proto->openPassDlg(message, myUser, myPass, proto->currentHost);
+				kdDebug(7106) << "CallBack: res=" << (res?"true":"false") << endl;
+				kdDebug(7106) << "CallBack: user=" << user << ", pass=" << pass << endl;
 				if (!res) {
 					if (service) {delete service; service = 0;}
 					if (pass) {delete pass; pass = 0;}
@@ -169,7 +167,7 @@ public:
 					if (pass) delete pass;
 					pass=new char[myPass.local8Bit().length()+1];
 					strcpy(pass,myPass.local8Bit().data());
-					kDebugInfo( 7106, "CallBack: service=%s, pass=%s", debugString(service), debugString(pass));
+					kdDebug(7106) << "CallBack: service=" << service << ", pass=" << pass << endl;
 					haveServicePass=true;
 					// Store the new binding info in case of success
 					proto->bserver = proto->currentHost;
@@ -189,7 +187,7 @@ int kdemain( int argc, char **argv )
 {
   KInstance instance( "kio_smb" );
 
-  kDebugInfo(7106, "Starting %d", getpid());
+  kdDebug(7106) << "Starting " << getpid() << endl;
 
   if (argc != 4)
   {
@@ -200,14 +198,14 @@ int kdemain( int argc, char **argv )
   SmbProtocol slave(argv[2], argv[3]);
   slave.dispatchLoop();
 
-  kDebugInfo(7106, "Done" );
+  kdDebug(7106) << "Done" << endl;
   return 0;
 }
 
 
 SmbProtocol::SmbProtocol( const QCString &pool, const QCString &app) : SlaveBase( "smb", pool, app )
 {
-	kDebugInfo( 7106, "Constructor");
+  kdDebug( 7106 ) << "Constructor" << endl;
 	currentHost=QString::null;
 	currentIP=QString::null;
 	currentUser=QString::null;
@@ -256,7 +254,7 @@ void SmbProtocol::loadBindings(bool force)
 		// unscramble
 		QString scrambled = g_pConfig->readEntry( key );
 		password = "";
-		for (int i=0; i<scrambled.length()/3; i++) {
+		for (unsigned int i=0; i<scrambled.length()/3; i++) {
 			QChar qc1 = scrambled[i*3];
 			QChar qc2 = scrambled[i*3+1];
 			QChar qc3 = scrambled[i*3+2];
@@ -288,7 +286,7 @@ void SmbProtocol::saveBindings() // Will store on the disk if required
 		key.sprintf("password%d",index);
 		// Weak code, but least it makes the string unreadable
 		QString scrambled;
-		for (int i=0; i<it->password.length(); i++) {
+		for (unsigned int i=0; i<it->password.length(); i++) {
 			QChar c = it->password[i];
 			unsigned int num = (c.unicode() ^ 173) + 17;
 			unsigned int a1 = (num & 0xFC00) >> 10;
@@ -314,7 +312,7 @@ SmbProtocol::~SmbProtocol()
 // Uses this function to get information in the url
 void SmbProtocol::setHost(const QString& host, int ip, const QString& user, const QString& pass)
 {
-	kDebugInfo( 7106, "in set host method");
+  kdDebug( 7106 ) << "in set host method" << endl;
 	currentHost=host;
 	currentIP=ip;
 	currentUser=user;
@@ -324,10 +322,10 @@ void SmbProtocol::setHost(const QString& host, int ip, const QString& user, cons
 QString SmbProtocol::buildFullLibURL(const QString &pathArg)
 {
 	Util util;
-	kDebugInfo( 7106, "currentUser: %s", debugString(currentUser));
-	kDebugInfo( 7106, "currentPass: %s", debugString(currentPass));
-	kDebugInfo( 7106, "currentHost: %s", debugString(currentHost));
-	kDebugInfo( 7106, "currentIP: %s", debugString(currentIP));
+	kdDebug( 7106 ) << "currentUser: " << currentUser << endl;
+	kdDebug( 7106 ) << "currentPass: " << currentPass << endl;
+	kdDebug( 7106 ) << "currentHost: " << currentHost << endl;
+	kdDebug( 7106 ) << "currentIP: " << currentIP << endl;
 	QString path = pathArg;
 	if (path[0]=='/') path.remove(0,1);
 	// NB20000423: Hmmm, with smb:// => smb:/ conversion, now there is no host
@@ -352,14 +350,14 @@ QString SmbProtocol::buildFullLibURL(const QString &pathArg)
 		);
 	util.parse(ret);
 	currentHost = util.host(); // Make sure we have the host, not the workgroup
-	kDebugInfo( 7106, "converting argument %s to %s", debugString(pathArg), debugString(ret));
+	kdDebug(7106) << "converting argument " << pathArg << " to " << ret << endl;
 	return ret;
 }
 
-void SmbProtocol::mkdir( const QString& pathArg, int /*permissions*/ )
+void SmbProtocol::mkdir( const KURL& url, int /*permissions*/ )
 {
-	QString path = buildFullLibURL(pathArg);
-	kDebugInfo( 7106, "entering mkdir %s", debugString(path));
+	QString path = buildFullLibURL(url.path());
+	kdDebug(7106) << "entering mkdir " << path << endl;
 	struct stat buff;
 	if ( smb.stat( path, &buff ) == -1 ) {
 		if ( smb.mkdir( path ) != 0 ) {
@@ -384,10 +382,10 @@ void SmbProtocol::mkdir( const QString& pathArg, int /*permissions*/ )
 	return;
 }
 
-void SmbProtocol::get( const QString& pathArg, const QString& /*query*/, bool /* reload */)
+void SmbProtocol::get( const KURL& url, bool /* reload */)
 {
-	QString path = buildFullLibURL(pathArg);
-	kDebugInfo( 7106, "entering get %s", debugString(path));
+	QString path = buildFullLibURL(url.path());
+	kdDebug( 7106 ) << "entering get " << path << endl;
 
 	struct stat buff;
 	if ( smb.stat( path, &buff ) == -1 ) {
@@ -416,21 +414,28 @@ void SmbProtocol::get( const QString& pathArg, const QString& /*query*/, bool /*
 
 	char buffer[ 4090 ];
 	QByteArray array;
+        bool mimetypeEmitted = false;
 
 	int n;
 	while( (n = smb.read(fd, buffer, 2048)) > 0 )
 	{
 		array.setRawData(buffer, n);
+                if ( !mimetypeEmitted )
+                {
+                  KMimeMagicResult * result = KMimeMagic::self()->findBufferFileType( array, url.fileName() );
+                  mimeType( result->mimeType() );
+                  mimetypeEmitted = true;
+                }
 		data( array );
-			array.resetRawData(buffer, n);
+                array.resetRawData(buffer, n);
 
 		processed_size += n;
 		time_t t = time( 0L );
 		if ( t - t_last >= 1 )
 		{
-			processedSize( processed_size );
-			speed( processed_size / ( t - t_start ) );
-			t_last = t;
+                  processedSize( processed_size );
+                  speed( processed_size / ( t - t_start ) );
+                  t_last = t;
 		}
 	}
 	if (n == -1)
@@ -453,11 +458,10 @@ void SmbProtocol::get( const QString& pathArg, const QString& /*query*/, bool /*
 }
 
 
-void SmbProtocol::put( const QString& dest_orig_arg, int _mode, bool _overwrite, bool _resume )
+void SmbProtocol::put( const KURL& url, int /*_mode*/, bool _overwrite, bool _resume )
 {
-	QString dest_orig = buildFullLibURL(dest_orig_arg);
-	kDebugInfo( 7106, "entering put %s", debugString(dest_orig));
-    bool bMarkPartial = false;
+    QString dest_orig = buildFullLibURL(url.path());
+    kdDebug(7106) << "entering put " << dest_orig << endl;
 
     struct stat buff_orig;
     bool orig_exists = ( smb.stat( dest_orig, &buff_orig ) != -1 );
@@ -473,7 +477,7 @@ void SmbProtocol::put( const QString& dest_orig_arg, int _mode, bool _overwrite,
     QString dest = dest_orig;
 	if ( orig_exists && !_resume )
 	{
-		kDebugInfo( 7106, "Deleting destination file %s", debugString(dest_orig) );
+	  kdDebug(7106) << "Deleting destination file " << dest_orig << endl;
 		remove( dest_orig );
 		// Catch errors when we try to open the file.
 	}
@@ -485,7 +489,7 @@ void SmbProtocol::put( const QString& dest_orig_arg, int _mode, bool _overwrite,
 	}
 
 	if ( m_fPut == -1 ) {
-	kDebugInfo( 7106, "####################### COULD NOT WRITE %s", debugString(dest));
+	  kdDebug(7106) << "####################### COULD NOT WRITE " << dest << endl;
 		if ( smb.error() == EACCES ) {
 			error( KIO::ERR_WRITE_ACCESS_DENIED, dest );
 		} else {
@@ -494,7 +498,7 @@ void SmbProtocol::put( const QString& dest_orig_arg, int _mode, bool _overwrite,
 		return;
 	}
 
-	kDebugInfo( 7106, "Put: Ready" );
+	kdDebug( 7106 ) << "Put: Ready" << endl;
 
 	int result;
 	// Loop until we got 0 (end of data)
@@ -514,7 +518,7 @@ void SmbProtocol::put( const QString& dest_orig_arg, int _mode, bool _overwrite,
 	if (result != 0)
 	{
 		smb.close(m_fPut);
-		kDebugInfo( 7106, "Error during 'put'. Aborting.");
+		kdDebug( 7106 ) << "Error during 'put'. Aborting." << endl;
 		::exit(255);
 	}
 
@@ -528,12 +532,12 @@ void SmbProtocol::put( const QString& dest_orig_arg, int _mode, bool _overwrite,
 	finished();
 }
 
-void SmbProtocol::rename( const QString &srcArg, const QString &destArg,
+void SmbProtocol::rename( const KURL &srcArg, const KURL &destArg,
                            bool _overwrite )
 {
-	QString src = buildFullLibURL(srcArg);
-	QString dest = buildFullLibURL(destArg);
-	kDebugInfo( 7106, "entering rename %s -> %s", debugString(src), debugString(dest));
+    QString src = buildFullLibURL(srcArg.path());
+    QString dest = buildFullLibURL(destArg.path());
+    kdDebug(7106) << "entering rename " << src << " -> " << dest << endl;
 
     struct stat buff_src;
     if ( smb.stat( src, &buff_src ) == -1 ) {
@@ -576,9 +580,10 @@ void SmbProtocol::rename( const QString &srcArg, const QString &destArg,
 }
 
 
-void SmbProtocol::del( const QString& path, bool isfile)
+void SmbProtocol::del( const KURL& url, bool isfile)
 {
-	kDebugInfo( 7106, "entering del %s", debugString(path));
+    QString path = url.path(); // Not URL??
+    kdDebug(7106) << "entering del " << path << endl;
 	/*****
 	* Delete files
 	*****/
@@ -603,7 +608,7 @@ void SmbProtocol::del( const QString& path, bool isfile)
 		* Delete empty directory
 		*****/
 
-		kDebugInfo( 7106, "Deleting directory %s", debugString(path) );
+       	  kdDebug(7106) << "Deleting directory " << path << endl;
 
 		// TODO deletingFile( source );
 
@@ -612,7 +617,7 @@ void SmbProtocol::del( const QString& path, bool isfile)
 		* Delete empty directory
 		*****/
 
-		kdDebug( 7106 ) << "Deleting directory " << debugString(path) << endl;
+		kdDebug(7106) << "Deleting directory " << path << endl;
 
 		if ( smb.rmdir( path ) == -1 ) {
 			if ((smb.error() == EACCES) || (smb.error() == EPERM))
@@ -714,50 +719,47 @@ void SmbProtocol::createUDSEntry( const SMBdirent *dent, const QString & /*path*
 	entry.append( atom );
 }
 
-void SmbProtocol::stat( const QString & pathArg, const QString& /*query*/ )
+void SmbProtocol::stat( const KURL &url)
 {
-	QString path = buildFullLibURL(pathArg);
-	kDebugInfo( 7106, "entering stat %s", debugString(path));
+	QString path = buildFullLibURL(url.path());
+	kdDebug( 7106 ) << "entering stat " << path << endl;
 	struct stat buff;
 	if ( smb.stat( path, &buff ) == -1 ) {
 		error( KIO::ERR_DOES_NOT_EXIST, path );
 		return;
 	}
 
-	// Extract filename out of path
-	QString filename = KURL( path ).filename();
-
 	UDSEntry entry;
-	createUDSEntry( filename, path, entry );
+	createUDSEntry( url.filename(), path, entry );
 ///////// debug code
 
 	KIO::UDSEntry::ConstIterator it = entry.begin();
 	for( ; it != entry.end(); it++ ) {
 		switch ((*it).m_uds) {
 			case KIO::UDS_FILE_TYPE:
-				kDebugInfo("File Type : %d", (mode_t)((*it).m_long) );
+			  kdDebug(7106) << "File Type : " << (mode_t)((*it).m_long) << endl;
 				break;
 			case KIO::UDS_ACCESS:
-				kDebugInfo("Access permissions : %d", (mode_t)((*it).m_long) );
+			  kdDebug(7106) << "Access permissions : " << (int)(mode_t)(*it).m_long << endl;
 				break;
 			case KIO::UDS_USER:
-				kDebugInfo("User : %s", ((*it).m_str.ascii() ) );
+			  kdDebug(7106) << "User : " << (*it).m_str << endl;
 				break;
 			case KIO::UDS_GROUP:
-				kDebugInfo("Group : %s", ((*it).m_str.ascii() ) );
+			  kdDebug(7106) << "Group : " << (*it).m_str << endl;
 				break;
 			case KIO::UDS_NAME:
-				kDebugInfo("Name : %s", ((*it).m_str.ascii() ) );
+			kdDebug(7106) << "Name : " << (*it).m_str << endl;
 				//m_strText = decodeFileName( (*it).m_str );
 				break;
 			case KIO::UDS_URL:
-				kDebugInfo("URL : %s", ((*it).m_str.ascii() ) );
+			kdDebug(7106) << "URL : " << (*it).m_str << endl;
 				break;
 			case KIO::UDS_MIME_TYPE:
-				kDebugInfo("MimeType : %s", ((*it).m_str.ascii() ) );
+			kdDebug(7106) << "MimeType : " << (*it).m_str << endl;
 				break;
 			case KIO::UDS_LINK_DEST:
-				kDebugInfo("LinkDest : %s", ((*it).m_str.ascii() ) );
+			kdDebug(7106) << "LinkDest : " << (*it).m_str << endl;
 				break;
 		}
 	}
@@ -768,10 +770,10 @@ void SmbProtocol::stat( const QString & pathArg, const QString& /*query*/ )
 	finished();
 }
 
-void SmbProtocol::listDir( const QString& pathArg, const QString& /*query*/ )
+void SmbProtocol::listDir( const KURL& url )
 {
-	QString path = buildFullLibURL(pathArg);
-	kDebugInfo( 7106, "=============== LIST %s ===============", debugString(path) );
+	QString path = buildFullLibURL(url.path());
+	kdDebug( 7106 ) << "=============== LIST " << path << " ===============" << endl;
 
 	struct stat buff;
 	if ( smb.stat( path, &buff ) == -1 ) {
@@ -808,9 +810,9 @@ void SmbProtocol::listDir( const QString& pathArg, const QString& /*query*/ )
 
 	listEntry( entry, true ); // ready
 
-	kDebugInfo(7106, "============= COMPLETED LIST ============" );
+	kdDebug(7106) << "============= COMPLETED LIST ============" << endl;
 
 	finished();
 
-	kDebugInfo(7106, "=============== BYE ===========" );
+	kdDebug(7106) << "=============== BYE ===========" << endl;
 }
