@@ -23,26 +23,33 @@
 #include <kapp.h>
 #include <krun.h>
 
-class clientApp : public KApplication,
-                  public KFileManager
+class clientApp : public KApplication
 {
   Q_OBJECT
 public:
 
   clientApp( int &argc, char **argv, const QCString& rAppName )
     : KApplication ( argc, argv, rAppName, false /* non-GUI */ )
-    { };
+    { }
 
-  ~clientApp() {} ;
+  ~clientApp() {}
 
   /** Parse command-line arguments and "do it" */
   int doIt( int argc, char **argv );
 
-  /** Implements KFileManager interface */
-  virtual bool openFileManagerWindow(const KURL & url);
+  /** Make konqueror open a window for @p url */
+  bool openFileManagerWindow(const KURL & url);
+
+  /** Make konqueror open a window for @p profile */
+  bool openProfile(const QString & profile);
 
 protected slots:
   void slotResult( KIO::Job * );
+  void slotAppRegistered( const QCString & );
+
+private:
+  QString m_profile;
+
 };
 
 #endif
