@@ -1,3 +1,21 @@
+/* This file is part of the KDE project
+   Copyright (C) 1998, 1999 Simon Hausmann <hausmann@kde.org>
+
+   This program is free software; you can redistribute it and/or
+   modify it under the terms of the GNU General Public
+   License as published by the Free Software Foundation; either
+   version 2 of the License, or (at your option) any later version.
+
+   This program is distributed in the hope that it will be useful,
+   but WITHOUT ANY WARRANTY; without even the implied warranty of
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+    General Public License for more details.
+
+   You should have received a copy of the GNU General Public License
+   along with this program; see the file COPYING.  If not, write to
+   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+   Boston, MA 02111-1307, USA.
+*/
 
 #include "konq_dirtree.h"
 
@@ -154,12 +172,6 @@ KURL::List KonqDirTreeBrowserExtension::selectedUrls()
   return lst;
 }
 
-void KonqDirTreeBrowserExtension::slotResult( KIO::Job * job )
-{
-    if (job->error())
-        job->showErrorDialog(m_tree);
-}
-
 KonqDirTreePart::KonqDirTreePart( QWidget *parentWidget, QObject *parent, const char *name )
  : KParts::ReadOnlyPart( parent, name )
 {
@@ -187,8 +199,7 @@ bool KonqDirTreePart::openURL( const KURL & url )
 
 bool KonqDirTreePart::closeURL()
 {
-  // (David) shouldn't we stop the dirLister here?
-
+  // Nothing to do
   return true;
 }
 
@@ -302,7 +313,7 @@ void KonqDirTree::clear()
 
 void KonqDirTree::openSubFolder( KonqDirTreeItem *item, KonqDirTreeItem *topLevel )
 {
-//  qDebug( "openSubFolder( %s )", item->fileItem()->url().url().ascii() );
+//  kdDebug() << "openSubFolder( " << item->fileItem()->url().url() << " )" << endl;
   TopLevelItem topLevelItem = findTopLevelByItem( topLevel ? topLevel : item );
 
   assert( topLevelItem.m_item );
@@ -343,7 +354,9 @@ void KonqDirTree::removeSubDir( KonqDirTreeItem *item, KonqDirTreeItem *topLevel
 
 void KonqDirTree::followURL( const KURL &_url )
 {
-  KURL u( _url );
+  kdDebug(1202) << "KonqDirTree::followURL: " << _url.url() << endl;
+  KURL uParent( _url.upURL() );
+
   QValueList<TopLevelItem>::ConstIterator it = m_topLevelItems.begin();
   QValueList<TopLevelItem>::ConstIterator end = m_topLevelItems.end();
   for (; it != end; ++it )
@@ -351,18 +364,28 @@ void KonqDirTree::followURL( const KURL &_url )
     QMap<KURL, KonqDirTreeItem *>::ConstIterator dirIt = (*it).m_mapSubDirs->begin();
     QMap<KURL, KonqDirTreeItem *>::ConstIterator dirEnd = (*it).m_mapSubDirs->end();
     for (; dirIt != dirEnd; ++dirIt )
-      if ( u.cmp( dirIt.key(), true ) )
+    {
+      // That's the URL we want to follow -> ensure visible, select, return.
+      if ( _url.cmp( dirIt.key(), true ) )
       {
-        if ( !dirIt.data()->isOpen() )
-	  dirIt.data()->setOpen( true );
-	
 	ensureItemVisible( dirIt.data() );
         setSelected( dirIt.data(), true );
-	
         return;
       }
+      // That's the parent directory. Open if not open...
+      if ( uParent.cmp( dirIt.key(), true ) )
+      {
+        if ( !dirIt.data()->isOpen() )
+        {
+            m_selectAfterOpening = _url;
+	    //kdDebug(1202) << "KonqDirTree::followURL: m_selectAfterOpening=" << m_selectAfterOpening.url() << endl;
+            dirIt.data()->setOpen( true );
+            return; // We know we won't find it
+        }
+      }
+    }
   }
-  kdDebug() << "Not found" << endl;
+  kdDebug(1202) << "KonqDirTree::followURL: Not found" << endl;
 }
 
 void KonqDirTree::contentsDragEnterEvent( QDragEnterEvent * )
@@ -413,9 +436,19 @@ void KonqDirTree::contentsDropEvent( QDropEvent *ev )
 void KonqDirTree::contentsMousePressEvent( QMouseEvent *e )
 {
   KListView::contentsMousePressEvent( e );
-  if ( e->button() == LeftButton ) {
-      m_dragPos = e->pos();
-      m_bDrag = true;
+
+  QPoint p( contentsToViewport( e->pos() ) );
+  QListViewItem *i = itemAt( p );
+
+  if ( e->button() == LeftButton && i ) {
+      // if the user clicked into the root decoration of the item, don't try to start a drag!
+      if ( p.x() > header()->cellPos( header()->mapToActual( 0 ) ) +
+	   treeStepSize() * ( i->depth() + ( rootIsDecorated() ? 1 : 0) ) + itemMargin() ||
+	   p.x() < header()->cellPos( header()->mapToActual( 0 ) ) )
+      {
+        m_dragPos = e->pos();
+        m_bDrag = true;
+      }
   }
 }
 
@@ -447,6 +480,14 @@ void KonqDirTree::contentsMouseReleaseEvent( QMouseEvent *e )
 
 void KonqDirTree::slotNewItems( const KFileItemList& entries )
 {
+  kdDebug() << "slotNewItems " << entries.count() << endl;
+
+  const KonqDirLister *lister = static_cast<const KonqDirLister *>( sender() );
+
+  TopLevelItem topLevelItem = findTopLevelByDirLister( lister );
+
+  assert( topLevelItem.m_item );
+
   QListIterator<KFileItem> kit ( entries );
   for( ; kit.current(); ++kit )
   {
@@ -454,12 +495,6 @@ void KonqDirTree::slotNewItems( const KFileItemList& entries )
 
     assert( S_ISDIR( item->mode() ) );
 
-    KonqDirLister *lister = (KonqDirLister *)sender();
-
-    TopLevelItem topLevelItem = findTopLevelByDirLister( lister );
-
-    assert( topLevelItem.m_item );
-
     KURL dir( item->url() );
     dir.setFileName( "" );
 
@@ -470,7 +505,7 @@ void KonqDirTree::slotNewItems( const KFileItemList& entries )
     QMap<KURL, KonqDirTreeItem *>::ConstIterator dirEnd = topLevelItem.m_mapSubDirs->end();
     for (; dirIt != dirEnd; ++dirIt )
     {
-      //    qDebug( "comparing %s with %s", dirIt.key().url().ascii(), dir.url().ascii() );
+      //    kdDebug() << "comparing " << dirIt.key().url() << " with " << dir.url() << endl;
       if ( dir.cmp( dirIt.key(), true ) )
         break;
     }
@@ -483,7 +518,7 @@ void KonqDirTree::slotNewItems( const KFileItemList& entries )
 
     KonqDirTreeItem *dirTreeItem = new KonqDirTreeItem( this, parentDir, topLevelItem.m_item, item );
     dirTreeItem->setPixmap( 0, m_folderPixmap );
-    dirTreeItem->setText( 0, KIO::decodeFileName( item->url().filename() ) );
+    dirTreeItem->setText( 0, KIO::decodeFileName( item->url().fileName() ) );
   }
 }
 
@@ -491,7 +526,7 @@ void KonqDirTree::slotDeleteItem( KFileItem *item )
 {
   assert( S_ISDIR( item->mode() ) );
 
-  //  qDebug( "slotDeleteItem( %s )", item->url().url().ascii() );
+  //  kdDebug() << "slotDeleteItem( " << item->url().url() << " )" << endl;
 
   KonqDirLister *lister = (KonqDirLister *)sender();
 
@@ -509,7 +544,7 @@ void KonqDirTree::slotDeleteItem( KFileItem *item )
   {
     if ( ((KonqDirTreeItem *)it.current())->fileItem() == item )
     {
-    //      qDebug( "removing %s", item->url().url().ascii() );
+    //      kdDebug() << "removing " << item->url().url() << endl;
       delete it.current();
       return;
     }
@@ -589,7 +624,7 @@ void KonqDirTree::slotClicked( QListViewItem *item )
 
 void KonqDirTree::slotListingStopped()
 {
-  KonqDirLister *lister = (KonqDirLister *)sender();
+  const KonqDirLister *lister = static_cast<const KonqDirLister *>( sender() );
 
   TopLevelItem topLevelItem = findTopLevelByDirLister( lister );
 
@@ -613,7 +648,9 @@ void KonqDirTree::slotListingStopped()
 
   KURL::List::Iterator it = topLevelItem.m_lstPendingURLs->find( url );
   if ( it != topLevelItem.m_lstPendingURLs->end() )
+  {
     topLevelItem.m_lstPendingURLs->remove( it );
+  }
 
   if ( topLevelItem.m_lstPendingURLs->count() > 0 )
     topLevelItem.m_dirLister->openURL( topLevelItem.m_lstPendingURLs->first(), false, true );
@@ -622,6 +659,11 @@ void KonqDirTree::slotListingStopped()
   if ( oIt != m_mapCurrentOpeningFolders.end() )
   {
     oIt.data()->setPixmap( 0, m_folderPixmap );
+    if ( !m_selectAfterOpening.isEmpty() && m_selectAfterOpening.upURL() == url )
+    {
+      followURL( m_selectAfterOpening );
+      m_selectAfterOpening = KURL();
+    }
 
     m_mapCurrentOpeningFolders.remove( oIt );
 
@@ -731,7 +773,7 @@ void KonqDirTree::scanDir2( QListViewItem *parent, const QString &path )
   QString icon = "folder";
   bool    open = false;
 
-  qDebug( "Scanning %s",  path.ascii() );
+  kdDebug() << "Scanning " << path << endl;
 
   QString dotDirectoryFile = QString(  path ).append( "/.directory" );
 
@@ -868,7 +910,7 @@ KonqDirTree::TopLevelItem KonqDirTree::findTopLevelByItem( KonqDirTreeItem *item
   return TopLevelItem();
 }
 
-KonqDirTree::TopLevelItem KonqDirTree::findTopLevelByDirLister( KonqDirLister *lister )
+KonqDirTree::TopLevelItem KonqDirTree::findTopLevelByDirLister( const KonqDirLister *lister )
 {
   QValueList<TopLevelItem>::ConstIterator it = m_topLevelItems.begin();
   QValueList<TopLevelItem>::ConstIterator end = m_topLevelItems.end();
