@@ -60,54 +60,61 @@
 #include <qpainter.h>
 #include <qpen.h>
 
+#include <config.h>
+
 template class QList<KFileIVI>;
 //template class QValueList<int>;
 
 class KonqIconViewFactory : public KParts::Factory
 {
 public:
-    KonqIconViewFactory()
-    {
+   KonqIconViewFactory()
+   {
       s_defaultViewProps = 0;
       s_instance = 0;
-    }
-    virtual ~KonqIconViewFactory()
-    {
+   }
+
+   virtual ~KonqIconViewFactory()
+   {
       if ( s_instance )
-        delete s_instance;
+         delete s_instance;
 
       if ( s_defaultViewProps )
-        delete s_defaultViewProps;
+         delete s_defaultViewProps;
 
       s_instance = 0;
       s_defaultViewProps = 0;
-    }
+   }
 
-    virtual KParts::Part* createPart( QWidget *parentWidget, const char *, QObject *parent, const char *name, const char*, const QStringList &/*&args*/ )
-    {
-	KonqKfmIconView *obj = new KonqKfmIconView( parentWidget, parent, name );
-	emit objectCreated( obj );
-	return obj;
-    }
+    virtual KParts::Part* createPart( QWidget *parentWidget, const char *,
+                                      QObject *parent, const char *name, const char*, const QStringList &args )
+   {
+      if( args.count() < 1 )
+         kdWarning() << "KonqKfmIconView: Missing Parameter" << endl;
 
-    static KInstance *instance()
-    {
+      KonqKfmIconView *obj = new KonqKfmIconView( parentWidget, parent, name,args.first() );
+      emit objectCreated( obj );
+      return obj;
+   }
+
+   static KInstance *instance()
+   {
       if ( !s_instance )
-        s_instance = new KInstance( "konqiconview" );
+         s_instance = new KInstance( "konqiconview" );
       return s_instance;
-    }
+   }
 
    static KonqPropsView *defaultViewProps()
    {
-     if ( !s_defaultViewProps )
-       s_defaultViewProps = new KonqPropsView( instance(), 0L );
+      if ( !s_defaultViewProps )
+         s_defaultViewProps = new KonqPropsView( instance(), 0L );
 
-     return s_defaultViewProps;
+      return s_defaultViewProps;
    }
 
-private:
-  static KInstance *s_instance;
-  static KonqPropsView *s_defaultViewProps;
+   private:
+      static KInstance *s_instance;
+      static KonqPropsView *s_defaultViewProps;
 };
 
 KInstance *KonqIconViewFactory::s_instance = 0;
@@ -164,7 +171,7 @@ void IconViewBrowserExtension::setSaveViewPropertiesLocally( bool value )
 }
 
 
-KonqKfmIconView::KonqKfmIconView( QWidget *parentWidget, QObject *parent, const char *name )
+KonqKfmIconView::KonqKfmIconView( QWidget *parentWidget, QObject *parent, const char *name, const QString& mode  )
     : KParts::ReadOnlyPart( parent, name )
 {
     kdDebug(1202) << "+KonqKfmIconView" << endl;
@@ -240,10 +247,10 @@ KonqKfmIconView::KonqKfmIconView( QWidget *parentWidget, QObject *parent, const
     m_paUnselectAll = new KAction( i18n( "U&nselect All" ), CTRL+Key_U, this, SLOT( slotUnselectAll() ), actionCollection(), "unselectall" );
     m_paInvertSelection = new KAction( i18n( "&Invert Selection" ), CTRL+Key_Asterisk, this, SLOT( slotInvertSelection() ), actionCollection(), "invertselection" );
 
-    m_paDefaultIcons = new KToggleAction( i18n( "&Default Size" ), 0, actionCollection(), "modedefault" );
-    m_paLargeIcons = new KToggleAction( i18n( "&Large" ), 0, actionCollection(), "modelarge" );
-    m_paMediumIcons = new KToggleAction( i18n( "&Medium" ), 0, actionCollection(), "modemedium" );
-    m_paSmallIcons = new KToggleAction( i18n( "&Small" ), 0, actionCollection(), "modesmall" );
+    m_paDefaultIcons = new KRadioAction( i18n( "&Default Size" ), 0, actionCollection(), "modedefault" );
+    m_paLargeIcons = new KRadioAction( i18n( "&Large" ), 0, actionCollection(), "modelarge" );
+    m_paMediumIcons = new KRadioAction( i18n( "&Medium" ), 0, actionCollection(), "modemedium" );
+    m_paSmallIcons = new KRadioAction( i18n( "&Small" ), 0, actionCollection(), "modesmall" );
     // I don't see how QIconView could cope with a no-icon mode. (David)
     //m_paNoIcons = new KToggleAction( i18n( "&Disabled" ), 0, actionCollection(), "modenone" );
     //m_paKOfficeMode = new KToggleAction( i18n( "&KOffice mode" ), 0, this );
@@ -258,11 +265,11 @@ KonqKfmIconView::KonqKfmIconView( QWidget *parentWidget, QObject *parent, const
     //m_paKOfficeMode->setChecked( false );
     //m_paKOfficeMode->setEnabled( false );
 
-    m_paBottomText = new KToggleAction( i18n( "Text at the &bottom" ), 0, actionCollection(), "textbottom" );
-    m_paRightText = new KToggleAction( i18n( "Text at the &right" ), 0, actionCollection(), "textright" );
+    //m_paBottomText = new KToggleAction( i18n( "Text at the &bottom" ), 0, actionCollection(), "textbottom" );
+    //m_paRightText = new KToggleAction( i18n( "Text at the &right" ), 0, actionCollection(), "textright" );
 
-    m_paBottomText->setExclusiveGroup( "TextPos" );
-    m_paRightText->setExclusiveGroup( "TextPos" );
+    //m_paBottomText->setExclusiveGroup( "TextPos" );
+    //m_paRightText->setExclusiveGroup( "TextPos" );
 
     new KAction( i18n( "Background Color..." ), 0, this, SLOT( slotBackgroundColor() ), actionCollection(), "bgcolor" );
     new KAction( i18n( "Background Image..." ), 0, this, SLOT( slotBackgroundImage() ), actionCollection(), "bgimage" );
@@ -276,8 +283,8 @@ KonqKfmIconView::KonqKfmIconView( QWidget *parentWidget, QObject *parent, const
     //connect( m_paKOfficeMode, SIGNAL( toggled( bool ) ), this, SLOT( slotKofficeMode( bool ) ) );
     //connect( m_paNoIcons, SIGNAL( toggled( bool ) ), this, SLOT( slotViewNone( bool ) ) );
 
-    connect( m_paBottomText, SIGNAL( toggled( bool ) ), this, SLOT( slotTextBottom( bool ) ) );
-    connect( m_paRightText, SIGNAL( toggled( bool ) ), this, SLOT( slotTextRight( bool ) ) );
+    //connect( m_paBottomText, SIGNAL( toggled( bool ) ), this, SLOT( slotTextBottom( bool ) ) );
+    //connect( m_paRightText, SIGNAL( toggled( bool ) ), this, SLOT( slotTextRight( bool ) ) );
 
     //
 
@@ -329,6 +336,23 @@ KonqKfmIconView::KonqKfmIconView( QWidget *parentWidget, QObject *parent, const
 
     connect( m_pIconView, SIGNAL( selectionChanged() ),
 	     this, SLOT( slotDisplayFileSelectionInfo() ) );
+
+    if (mode=="MultiColumnView")
+    {
+       m_pIconView->setArrangement(QIconView::TopToBottom);
+       //m_pIconView->setWordWrapIconText(false);
+       m_pIconView->setItemTextPos(QIconView::Right);
+    }
+    else
+    {
+       m_pIconView->setItemTextPos(QIconView::Bottom);
+       //m_pIconView->setWordWrapIconText(true);
+       m_pIconView->setArrangement(QIconView::LeftToRight);
+    }
+    // Respect kcmkonq's configuration for word-wrap icon text.
+    // If we want something else, we have to adapt the configuration or remove it...
+    m_pIconView->setWordWrapIconText(KonqFMSettings::settings()->wordWrapText());
+
 }
 
 KonqKfmIconView::~KonqKfmIconView()
@@ -496,6 +520,8 @@ void KonqKfmIconView::slotSortDescending()
     else
 	m_pIconView->setSorting( true, true );
 
+    setupSortKeys(); // keys have to change, for directories
+
     m_pIconView->sort( m_pIconView->sortDirection() );
 }
 
@@ -510,7 +536,7 @@ void KonqKfmIconView::slotSortDirsFirst()
 
 void KonqKfmIconView::guiActivateEvent( KParts::GUIActivateEvent *event )
 {
-  ReadOnlyPart::guiActivateEvent( event );
+  KParts::ReadOnlyPart::guiActivateEvent( event );
   if ( event->activated() )
     m_pIconView->slotSelectionChanged();
 }
@@ -588,7 +614,7 @@ void KonqKfmIconView::slotViewDefault( bool b)
   //TODO: Disable Icons
 }*/
 
-void KonqKfmIconView::slotTextBottom( bool b )
+/*void KonqKfmIconView::slotTextBottom( bool b )
 {
     if ( b ) {
         m_pProps->setItemTextPos( QIconView::Bottom );
@@ -606,7 +632,7 @@ void KonqKfmIconView::slotTextRight( bool b )
         calculateGridX();
 	m_pIconView->arrangeItemsInGrid( true );
     }
-}
+}*/
 
 void KonqKfmIconView::slotBackgroundColor()
 {
@@ -704,7 +730,7 @@ void KonqKfmIconView::slotReturnPressed( QIconViewItem *item )
     if ( !item )
 	return;
 
-    visualActivate(item);
+    m_pIconView->visualActivate(item);
 
     KonqFileItem *fileItem = (static_cast<KFileIVI*>(item))->item();
     if ( !fileItem )
@@ -740,7 +766,7 @@ void KonqKfmIconView::slotMouseButtonPressed(int _button, QIconViewItem* _item,
     if(_item) {
 	switch(_button) {
 	case RightButton:
-	    (static_cast<KFileIVI*>(_item))->setSelected( true );
+            (static_cast<KFileIVI*>(_item))->setSelected( true, true /* don't touch other items */ );
 	    emit m_extension->popupMenu( _global, m_pIconView->selectedFileItems() );
 	    break;
 	case MidButton:
@@ -788,14 +814,20 @@ void KonqKfmIconView::slotCompleted()
     if ( m_dirLister->rootItem() )
       m_pIconView->setRootItem( static_cast<KonqFileItem *>(m_dirLister->rootItem()) );
 
-    m_pIconView->setContentsPos( m_extension->urlArgs().xOffset, m_extension->urlArgs().yOffset );
+    if ( m_bUpdateContentsPosAfterListing )
+      m_pIconView->setContentsPos( m_extension->urlArgs().xOffset, m_extension->urlArgs().yOffset );
     //m_paKOfficeMode->setEnabled( m_dirLister->kofficeDocsFound() );
 
+    m_bUpdateContentsPosAfterListing = false;
+
     slotOnViewport();
     // slotProcessMimeIcons will do it
     m_bNeedEmitCompleted = true;
 
     QTimer::singleShot( 0, this, SLOT( slotProcessMimeIcons() ) );
+
+    // Disable cut icons if any
+    m_pIconView->slotClipboardDataChanged();
 }
 
 void KonqKfmIconView::slotNewItems( const KFileItemList& entries )
@@ -862,12 +894,34 @@ void KonqKfmIconView::slotDeleteItem( KFileItem * _fileitem )
     }
 }
 
+void KonqKfmIconView::slotRefreshItems( const KFileItemList& entries )
+{
+  KFileItemListIterator rit(entries);
+  for (; rit.current(); ++rit) {
+    QIconViewItem *it = m_pIconView->firstItem();
+    for ( ; it ; it = it->nextItem() )
+    {
+        KFileIVI * fileIVI = static_cast<KFileIVI *>(it);
+        if ( fileIVI->item() == rit.current() )
+        {
+            fileIVI->refreshIcon( true );
+            break;
+        }
+    }
+  }
+}
+
 void KonqKfmIconView::slotClear()
 {
     m_pIconView->clear();
     m_lstPendingMimeIconItems.clear();
 }
 
+void KonqKfmIconView::slotRedirection( const KURL & url )
+{
+    emit m_extension->setLocationBarURL( url.prettyURL() );
+}
+
 static QString displayString(int items, int files, long size, int dirs)
 {
     QString text;
@@ -921,7 +975,7 @@ void KonqKfmIconView::slotDisplayFileSelectionInfo()
 
 void KonqKfmIconView::slotProcessMimeIcons()
 {
-    // kdDebug() << "KonqKfmIconView::slotProcessMimeIcons() "
+    // kdDebug(1202) << "KonqKfmIconView::slotProcessMimeIcons() "
     //             << m_lstPendingMimeIconItems.count() << endl;
     KFileIVI * item = 0L;
     int nextDelay = 0;
@@ -964,7 +1018,7 @@ void KonqKfmIconView::slotProcessMimeIcons()
         {
             if ( m_bNeedEmitCompleted )
             {
-                kdDebug() << "KonqKfmIconView completed()" << endl;
+                kdDebug(1202) << "KonqKfmIconView completed()" << endl;
                 emit completed();
                 m_bNeedEmitCompleted = false;
             }
@@ -982,6 +1036,7 @@ void KonqKfmIconView::slotProcessMimeIcons()
     KMimeType::Ptr dummy = item->item()->determineMimeType();
 
     QPixmap newIcon = item->item()->pixmap( m_pIconView->iconSize(),
+                                            item->state(),
                                             m_pProps->isShowingImagePreview() );
 
     if ( currentIcon->serialNumber() != newIcon.serialNumber() )
@@ -1013,6 +1068,10 @@ bool KonqKfmIconView::openURL( const KURL &_url )
 			  this, SLOT( slotNewItems( const KFileItemList& ) ) );
 	QObject::connect( m_dirLister, SIGNAL( deleteItem( KFileItem * ) ),
 			  this, SLOT( slotDeleteItem( KFileItem * ) ) );
+	QObject::connect( m_dirLister, SIGNAL( refreshItems( const KFileItemList& ) ),
+			  this, SLOT( slotRefreshItems( const KFileItemList& ) ) );
+	QObject::connect( m_dirLister, SIGNAL( redirection( const KURL & ) ),
+                          this, SLOT( slotRedirection( const KURL & ) ) );
     }
 
     m_bLoading = true;
@@ -1026,13 +1085,17 @@ bool KonqKfmIconView::openURL( const KURL &_url )
     // and in the part :-)
     m_url = _url;
 
-    m_pProps->enterDir( _url );
+    if ( m_pProps->enterDir( _url ) )
+    {
+      m_pIconView->setImagePreviewAllowed ( m_pProps->isShowingImagePreview() );
+    }
 
     // Start the directory lister !
     m_dirLister->openURL( url(), m_pProps->isShowingDotFiles() );
     // Note : we don't store the url. KonqDirLister does it for us.
 
     m_bNeedAlign = false;
+    m_bUpdateContentsPosAfterListing = true;
 
     // Apply properties and reflect them on the actions
     // do it after starting the dir lister to avoid changing the properties
@@ -1046,10 +1109,10 @@ bool KonqKfmIconView::openURL( const KURL &_url )
     m_paSmallIcons->setChecked( size == m_iIconSize[0] );
     //m_paNoIcons->setChecked( false );
 
-    QIconView::ItemTextPos textPos = (QIconView::ItemTextPos) m_pProps->itemTextPos();
+    /*QIconView::ItemTextPos textPos = (QIconView::ItemTextPos) m_pProps->itemTextPos();
     m_pIconView->setItemTextPos( textPos );
     m_paBottomText->setChecked( textPos == QIconView::Bottom );
-    m_paRightText->setChecked( textPos == QIconView::Right );
+    m_paRightText->setChecked( textPos == QIconView::Right );*/
 
     m_paDotFiles->setChecked( m_pProps->isShowingDotFiles() );
     m_paImagePreview->setChecked( m_pProps->isShowingImagePreview() );
@@ -1057,7 +1120,7 @@ bool KonqKfmIconView::openURL( const KURL &_url )
     m_pIconView->viewport()->setBackgroundColor( m_pProps->bgColor() );
     m_pIconView->viewport()->setBackgroundPixmap( m_pProps->bgPixmap() );
 
-    emit setWindowCaption( _url.decodedURL() );
+    emit setWindowCaption( _url.prettyURL() );
 
     calculateGridX();
     return true;
@@ -1130,84 +1193,4 @@ QString KonqKfmIconView::makeSizeKey( KFileIVI *item )
     return QString::number( item->item()->size() ).rightJustify( 20, '0' );
 }
 
-void KonqKfmIconView::visualActivate(QIconViewItem * item)
-{
-    // Draw concentric rectangles, beginning from the centre of the item's
-    // pixmap area and expanding to the size of the pixmap area.
-    // The rects are removed as the next rect is drawn, giving the impression
-    // that there is one rect, expanding outwards.
-
-    if (!KonqFMSettings::settings()->visualActivate())
-      return;
-
-    unsigned int actCount = KonqFMSettings::settings()->visualActivateCount();
-
-    // actCount ranges from 1..10.
-
-    if (actCount < 1)
-      actCount = 1;
-
-    else if (actCount > 10)
-      actCount = 10;
-
-    unsigned int actSpeed = KonqFMSettings::settings()->visualActivateSpeed();
-
-    // actSpeed ranges from 1..100.
-
-    if (actSpeed < 1)
-      actSpeed = 1;
-
-    else if (actSpeed > 100)
-      actSpeed = 100;
-
-    // actSpeed needs to be converted to actDelay.
-    // actDelay is inversely proportional to actSpeed and needs to be
-    // divided up into actCount portions.
-    // We also convert the us value to ms.
-
-    unsigned int actDelay = (1000 * (100 - actSpeed)) / actCount;
-    qDebug("actDelay == %d", actDelay);
-
-    // Rect of the QIconViewItem.
-    QRect irect = item->rect();
-
-    // Rect of the QIconViewItem's pixmap area.
-    QRect rect = item->pixmapRect();
-
-    // Adjust to correct position. If this isn't done, the fact that the
-    // text may be wider than the pixmap puts us off-centre.
-    rect.moveBy(irect.x(), irect.y());
-
-    // We work from the centre of the pixmap - it's nicer that way.
-    QPoint c = rect.center();
-
-    QPainter p(m_pIconView->viewport());
-
-    // Use NotROP to avoid having to repaint the pixmap each time.
-    p.setPen(QPen(Qt::black, 1, Qt::DotLine));
-    p.setRasterOp(Qt::NotROP);
-
-    // The spacing between the rects we draw.
-    // Use the minimum of width and height to avoid painting outside the
-    // pixmap area.
-    unsigned int delta(QMIN(rect.width() / actCount, rect.height() / actCount));
-
-    for (unsigned int i = 1; i < actCount; i++) {
-
-        int sz = i * delta;
-
-        QSize rectSize(sz, sz);
-        QPoint rectPos(c.x() - sz / 2, c.y() - sz / 2);
-
-        QRect r(m_pIconView->contentsToViewport(rectPos), rectSize);
-
-        p.drawRect(r);
-        p.flush();
-
-        usleep(actDelay);
-
-        p.drawRect(r);
-    }
-}
-
 #include "konq_iconview.moc"
