@@ -20,7 +20,7 @@
 */
 
 #ifndef __konq_factory_h__
-#define __konq_factory_h__ $Id: konq_factory.h,v 1.23 2000/05/07 23:08:45 faure Exp $
+#define __konq_factory_h__ $Id: konq_factory.h,v 1.24 2000/05/20 17:27:38 faure Exp $
 
 #include <qstring.h>
 #include <qstringlist.h>
@@ -32,7 +32,7 @@
 #include <kparts/part.h>
 
 class BrowserView;
-class KonqMainView;
+class KonqMainWindow;
 class KAboutData;
 
 class KonqViewFactory
