@@ -38,9 +38,9 @@
 #include <kparts/browserextension.h>
 #include <kparts/event.h>
 #include "konq_frame.h"
-#include "konq_childview.h"
+#include "konq_view.h"
 #include "konq_viewmgr.h"
-#include "konq_mainview.h"
+#include "konq_mainwindow.h"
 
 #include <assert.h>
 
@@ -66,6 +66,10 @@ KonqFrameStatusBar::KonqFrameStatusBar( KonqFrame *_parent, const char *_name )
 ,m_yOffset(0)
 ,m_showLed(true)
 {
+   m_pStatusLabel = new QLabel( this );
+   m_pStatusLabel->show();
+   m_pStatusLabel->installEventFilter(this);
+
    m_pLinkedViewCheckBox = new KonqCheckBox( this, "m_pLinkedViewCheckBox" );
    m_pLinkedViewCheckBox->show();
    QWhatsThis::add( m_pLinkedViewCheckBox,
@@ -76,16 +80,12 @@ KonqFrameStatusBar::KonqFrameStatusBar( KonqFrame *_parent, const char *_name )
                          "directory tree with an icon view or detailed view, and possibly a "
                          "terminal emulator window." ) );
 
-   m_pStatusLabel = new QLabel( this );
-   m_pStatusLabel->show();
-   m_pStatusLabel->installEventFilter(this);
-
    int h=fontMetrics().height()+2;
    if (h<DEFAULT_HEADER_HEIGHT ) h=DEFAULT_HEADER_HEIGHT;
    setFixedHeight(h);
    m_yOffset=(h-13)/2;
 
-   m_pLinkedViewCheckBox->setGeometry(20,m_yOffset,13,13);
+   //m_pLinkedViewCheckBox->setGeometry(20,m_yOffset,13,13);
    m_pLinkedViewCheckBox->setFocusPolicy(NoFocus);
    m_pStatusLabel->setGeometry(40,0,50,h);
 
@@ -104,6 +104,7 @@ KonqFrameStatusBar::~KonqFrameStatusBar()
 void KonqFrameStatusBar::resizeEvent( QResizeEvent* )
 {
    m_progressBar->setGeometry( width()-160, 0, 140, height() );
+   m_pLinkedViewCheckBox->move( width()-15, m_yOffset ); // right justify
 }
 
 void KonqFrameStatusBar::mousePressEvent( QMouseEvent* event )
@@ -120,7 +121,7 @@ void KonqFrameStatusBar::mousePressEvent( QMouseEvent* event )
 
 void KonqFrameStatusBar::splitFrameMenu()
 {
-   KActionCollection *actionColl = m_pParentKonqFrame->childView()->mainView()->actionCollection();
+   KActionCollection *actionColl = m_pParentKonqFrame->childView()->mainWindow()->actionCollection();
 
    QPopupMenu menu;
 
@@ -169,7 +170,7 @@ void KonqFrameStatusBar::message( const QString &msg )
 void KonqFrameStatusBar::slotDisplayStatusText(const QString& text)
 {
    //kdDebug(1202)<<"KongFrameHeader::slotDisplayStatusText("<<text<<")"<<endl;
-   m_pStatusLabel->resize(fontMetrics().width(text),13);
+   m_pStatusLabel->resize(fontMetrics().width(text),fontMetrics().height());
    m_pStatusLabel->setText(text);
    m_savedMessage = text;
 
@@ -184,8 +185,7 @@ void KonqFrameStatusBar::slotClear()
 
 void KonqFrameStatusBar::slotLoadingProgress( int percent )
 {
-  //m_iProgress = percent;
-  if ( percent != -1 )
+  if ( percent != -1 && percent != 100 ) // hide on 100 too
   {
     if ( !m_progressBar->isVisible() )
       m_progressBar->show();
@@ -211,30 +211,31 @@ void KonqFrameStatusBar::slotSpeedProgress( int bytesPerSecond )
   slotDisplayStatusText( sizeStr ); // let's share the same label...
 }
 
-void KonqFrameStatusBar::slotConnectToNewView(KonqChildView *, KParts::ReadOnlyPart *,KParts::ReadOnlyPart *newOne)
+void KonqFrameStatusBar::slotConnectToNewView(KonqView *, KParts::ReadOnlyPart *,KParts::ReadOnlyPart *newOne)
 {
    if (newOne!=0)
       connect(newOne,SIGNAL(setStatusBarText(const QString &)),this,SLOT(slotDisplayStatusText(const QString&)));
    slotDisplayStatusText( QString::null );
 }
 
-void KonqFrameStatusBar::showStuff()
+void KonqFrameStatusBar::showActiveViewIndicator( bool b )
 {
-    m_pLinkedViewCheckBox->show();
-    m_showLed = true;
+    m_showLed = b;
     repaint();
 }
 
-void KonqFrameStatusBar::hideStuff()
+void KonqFrameStatusBar::showLinkedViewIndicator( bool b )
 {
-    m_pLinkedViewCheckBox->hide();
-    m_showLed = false;
-    repaint();
+    if (b)
+      m_pLinkedViewCheckBox->show();
+    else
+      m_pLinkedViewCheckBox->hide();
+    //repaint();
 }
 
 void KonqFrameStatusBar::setLinkedView( bool b )
 {
-  m_pLinkedViewCheckBox->setChecked( b );
+    m_pLinkedViewCheckBox->setChecked( b );
 }
 
 void KonqFrameStatusBar::paintEvent(QPaintEvent* e)
@@ -262,7 +263,7 @@ KonqFrame::KonqFrame( KonqFrameContainer *_parentContainer, const char *_name )
 :QWidget(_parentContainer,_name)
 {
    m_pLayout = 0L;
-   m_pChildView = 0L;
+   m_pView = 0L;
 
    // add the frame statusbar to the layout
    m_pStatusBar = new KonqFrameStatusBar( this, "KonquerorFrameStatusBar");
@@ -283,15 +284,10 @@ KonqFrame::~KonqFrame()
   //delete m_pLayout;
 }
 
-KParts::ReadOnlyPart * KonqFrame::view()
-{
-  return m_pView;
-}
-
 bool KonqFrame::isActivePart()
 {
-  return ( m_pChildView &&
-           static_cast<KonqChildView*>(m_pChildView) == m_pChildView->mainView()->currentChildView() );
+  return ( m_pView &&
+           static_cast<KonqView*>(m_pView) == m_pView->mainWindow()->currentView() );
 }
 
 void KonqFrame::listViews( ChildViewList *viewList )
@@ -299,9 +295,11 @@ void KonqFrame::listViews( ChildViewList *viewList )
   viewList->append( childView() );
 }
 
-void KonqFrame::saveConfig( KConfig* config, const QString &prefix, int /*id*/, int /*depth*/ )
+void KonqFrame::saveConfig( KConfig* config, const QString &prefix, bool saveURLs, int /*id*/, int /*depth*/ )
 {
-  config->writeEntry( QString::fromLatin1( "URL" ).prepend( prefix ), childView()->url().url() );
+  if (saveURLs)
+    config->writeEntry( QString::fromLatin1( "URL" ).prepend( prefix ),
+                        childView()->url().url() );
   config->writeEntry( QString::fromLatin1( "ServiceType" ).prepend( prefix ), childView()->serviceType() );
   config->writeEntry( QString::fromLatin1( "ServiceName" ).prepend( prefix ), childView()->service()->name() );
   config->writeEntry( QString::fromLatin1( "PassiveMode" ).prepend( prefix ), childView()->passiveMode() );
@@ -317,17 +315,17 @@ KParts::ReadOnlyPart *KonqFrame::attach( const KonqViewFactory &viewFactory )
    // because we already have that taken care of in KParts...
 
 #ifdef METAVIEWS
-   m_pView = factory.create( m_metaViewFrame, "childview widget", 0, "child view" );
+   m_pPart = factory.create( m_metaViewFrame, "view widget", 0, "child view" );
 #else
-   m_pView = factory.create( this, "childview widget", 0, "child view" );
+   m_pPart = factory.create( this, "view widget", 0, "child view" );
 #endif
 
-   assert( m_pView->widget() );
+   assert( m_pPart->widget() );
 
    attachInternal();
 
-   m_pStatusBar->slotConnectToNewView(0, 0,m_pView);
-   return m_pView;
+   m_pStatusBar->slotConnectToNewView(0, 0,m_pPart);
+   return m_pPart;
 }
 
 void KonqFrame::attachInternal()
@@ -346,30 +344,30 @@ void KonqFrame::attachInternal()
 
    m_metaViewLayout = new QVBoxLayout( m_metaViewFrame );
    m_metaViewLayout->setMargin( m_metaViewFrame->frameWidth() );
-   m_metaViewLayout->addWidget( m_pView->widget() );
+   m_metaViewLayout->addWidget( m_pPart->widget() );
 
    m_pLayout->addWidget( m_metaViewFrame );
 #else
-   m_pLayout->addWidget( m_pView->widget() );
+   m_pLayout->addWidget( m_pPart->widget() );
 #endif
 
    m_pLayout->addWidget( m_pStatusBar );
-   m_pView->widget()->show();
-   if ( m_pChildView->mainView()->fullScreenMode() )
-     m_pChildView->mainView()->attachToolbars( this );
+   m_pPart->widget()->show();
+   if ( m_pView->mainWindow()->fullScreenMode() )
+     m_pView->mainWindow()->attachToolbars( this );
    else
      m_pStatusBar->show();
    m_pLayout->activate();
 }
 
-void KonqFrame::setChildView( KonqChildView* child )
+void KonqFrame::setView( KonqView* child )
 {
-   m_pChildView = child;
-   if (m_pChildView)
+   m_pView = child;
+   if (m_pView)
    {
-     connect(m_pChildView,SIGNAL(sigViewChanged(KonqChildView *, KParts::ReadOnlyPart *,KParts::ReadOnlyPart *)),
-             m_pStatusBar,SLOT(slotConnectToNewView(KonqChildView *, KParts::ReadOnlyPart *,KParts::ReadOnlyPart *)));
-     //connect(m_pChildView->view(),SIGNAL(setStatusBarText(const QString &)),
+     connect(m_pView,SIGNAL(sigPartChanged(KonqView *, KParts::ReadOnlyPart *,KParts::ReadOnlyPart *)),
+             m_pStatusBar,SLOT(slotConnectToNewView(KonqView *, KParts::ReadOnlyPart *,KParts::ReadOnlyPart *)));
+     //connect(m_pView->view(),SIGNAL(setStatusBarText(const QString &)),
      //m_pHeader,SLOT(slotDisplayStatusText(const QString&)));
    }
 };
@@ -390,22 +388,22 @@ void KonqFrame::reparentFrame( QWidget* parent, const QPoint & p, bool showIt )
 void KonqFrame::slotStatusBarClicked()
 {
   if ( !isActivePart() )
-     m_pChildView->mainView()->viewManager()->setActivePart( m_pView );
+    part()->widget()->setFocus(); // Will change the active part
 }
 
 void KonqFrame::slotLinkedViewClicked( bool mode )
 {
-  if (m_pChildView->mainView()->viewCount() == 2)
+  if (m_pView->mainWindow()->viewCount() == 2)
   {
     // Two views : link both
-    KonqMainView::MapViews mapViews = m_pChildView->mainView()->viewMap();
-    KonqMainView::MapViews::Iterator it = mapViews.begin();
+    KonqMainWindow::MapViews mapViews = m_pView->mainWindow()->viewMap();
+    KonqMainWindow::MapViews::Iterator it = mapViews.begin();
     (*it)->setLinkedView( mode );
     ++it;
     (*it)->setLinkedView( mode );
   }
   else // Normal case : just this view
-    m_pChildView->setLinkedView( mode );
+    m_pView->setLinkedView( mode );
 }
 
 void
@@ -470,7 +468,7 @@ void KonqFrameContainer::listViews( ChildViewList *viewList )
       m_pSecondChild->listViews( viewList );
 }
 
-void KonqFrameContainer::saveConfig( KConfig* config, const QString &prefix, int id, int depth )
+void KonqFrameContainer::saveConfig( KConfig* config, const QString &prefix, bool saveURLs, int id, int depth )
 {
   int idSecond = id + (int)pow( 2, depth );
 
@@ -499,13 +497,13 @@ void KonqFrameContainer::saveConfig( KConfig* config, const QString &prefix, int
   if( firstChild() ) {
     QString newPrefix = firstChild()->frameType() + QString("%1").arg(idSecond - 1);
     newPrefix.append( '_' );
-    firstChild()->saveConfig( config, newPrefix, id, depth + 1 );
+    firstChild()->saveConfig( config, newPrefix, saveURLs, id, depth + 1 );
   }
 
   if( secondChild() ) {
     QString newPrefix = secondChild()->frameType() + QString("%1").arg( idSecond );
     newPrefix.append( '_' );
-    secondChild()->saveConfig( config, newPrefix, idSecond, depth + 1 );
+    secondChild()->saveConfig( config, newPrefix, saveURLs, idSecond, depth + 1 );
   }
 }
 
