@@ -18,7 +18,7 @@
 */
 
 #ifndef __konq_profiledlg_h__
-#define __konq_profiledlg_h__ $Id: konq_profiledlg.h,v 1.4 2000/04/22 19:01:00 faure Exp $
+#define __konq_profiledlg_h__ $Id: konq_profiledlg.h,v 1.8 2000/06/08 00:03:00 faure Exp $
 
 #include <kdialog.h>
 #include <qmap.h>
@@ -26,6 +26,7 @@
 class KonqViewManager;
 class QListBox;
 class QGridLayout;
+class QCheckBox;
 class QLineEdit;
 class QPushButton;
 
@@ -36,10 +37,16 @@ public:
   KonqProfileDlg( KonqViewManager *manager, QWidget *parent = 0L );
   ~KonqProfileDlg();
 
+  /**
+   * Find, read and return all available profiles
+   * @return a map with < name, full path >
+   */
+  static QMap<QString,QString> readAllProfiles();
+
 protected slots:
-  void slotEnableSave( const QString &text );
   void slotSave();
   void slotDelete();
+  void slotTextChanged( const QString & );
 
 private:
   KonqViewManager *m_pViewManager;
@@ -53,6 +60,8 @@ private:
   QPushButton *m_pDeleteProfileButton;
   QPushButton *m_pSaveButton;
   QPushButton *m_pCloseButton;
+  QCheckBox *m_cbSaveURLs;
+  QCheckBox *m_cbSaveSize;
 
   QListBox *m_pListBox;
 };
