@@ -20,8 +20,8 @@
 
 #include <kparts/browserextension.h>
 #include "konq_viewmgr.h"
-#include "konq_mainview.h"
-#include "konq_childview.h"
+#include "konq_mainwindow.h"
+#include "konq_view.h"
 #include "konq_factory.h"
 #include "konq_frame.h"
 #include "konq_profiledlg.h"
@@ -36,23 +36,21 @@
 #include <kconfig.h>
 #include <kstddirs.h>
 #include <kdebug.h>
+#include <kpopupmenu.h>
 
 #include <assert.h>
 
-template class QList<KonqChildView>;
+template class QList<KonqView>;
 
-KonqViewManager::KonqViewManager( KonqMainView *mainView )
- : KParts::PartManager( mainView )
+KonqViewManager::KonqViewManager( KonqMainWindow *mainWindow )
+ : KParts::PartManager( mainWindow )
 {
-  m_pMainView = mainView;
+  m_pMainWindow = mainWindow;
 
   m_pMainContainer = 0L;
 
+  m_pamProfiles = 0L;
   m_bProfileListDirty = true;
-
-  // we need this for a proper layout of the toolbars upon startup, when no real view has been loaded, yet
-  m_dummyWidget = 0L; // new QWidget( mainView );
-  // mainView->setView( m_dummyWidget );
 }
 
 KonqViewManager::~KonqViewManager()
@@ -60,7 +58,7 @@ KonqViewManager::~KonqViewManager()
   clear();
 }
 
-KonqChildView* KonqViewManager::splitView ( Qt::Orientation orientation,
+KonqView* KonqViewManager::splitView ( Qt::Orientation orientation,
                                             const KURL &url,
                                             QString serviceType,
                                             const QString &serviceName )
@@ -71,11 +69,11 @@ KonqChildView* KonqViewManager::splitView ( Qt::Orientation orientation,
   KonqFrame* viewFrame = 0L;
   if( m_pMainContainer )
   {
-    viewFrame = m_pMainView->currentChildView()->frame();
-    locationBarURL = m_pMainView->currentChildView()->locationBarURL();
+    viewFrame = m_pMainWindow->currentView()->frame();
+    locationBarURL = m_pMainWindow->currentView()->locationBarURL();
   }
 
-  KonqChildView* childView = split( viewFrame, orientation, serviceType, serviceName );
+  KonqView* childView = split( viewFrame, orientation, serviceType, serviceName );
 
   if( childView )
   {
@@ -87,21 +85,21 @@ KonqChildView* KonqViewManager::splitView ( Qt::Orientation orientation,
   return childView;
 }
 
-KonqChildView* KonqViewManager::splitWindow( Qt::Orientation orientation )
+KonqView* KonqViewManager::splitWindow( Qt::Orientation orientation )
 {
   kdDebug(1202) << "KonqViewManager::splitWindow(default)" << endl;
 
-  KURL url = m_pMainView->currentChildView()->url();
+  KURL url = m_pMainWindow->currentView()->url();
 
   QString locationBarURL;
   KonqFrameBase* splitFrame = 0L;
   if( m_pMainContainer )
   {
     splitFrame = m_pMainContainer->firstChild();
-    locationBarURL = m_pMainView->currentChildView()->locationBarURL();
+    locationBarURL = m_pMainWindow->currentView()->locationBarURL();
   }
 
-  KonqChildView* childView = split( splitFrame, orientation );
+  KonqView* childView = split( splitFrame, orientation );
 
   if( childView )
   {
@@ -113,7 +111,7 @@ KonqChildView* KonqViewManager::splitWindow( Qt::Orientation orientation )
   return childView;
 }
 
-KonqChildView* KonqViewManager::split (KonqFrameBase* splitFrame,
+KonqView* KonqViewManager::split (KonqFrameBase* splitFrame,
                                        Qt::Orientation orientation,
                                        const QString &serviceType, const QString &serviceName,
                                        KonqFrameContainer **newFrameContainer )
@@ -128,7 +126,7 @@ KonqChildView* KonqViewManager::split (KonqFrameBase* splitFrame,
   if( newViewFactory.isNull() )
     return 0L; //do not split at all if we can't create the new view
 
-  KonqChildView *childView;
+  KonqView *childView;
   if( m_pMainContainer )
   {
     assert( splitFrame );
@@ -138,9 +136,6 @@ KonqChildView* KonqViewManager::split (KonqFrameBase* splitFrame,
 
     printSizeInfo( splitFrame, parentContainer, "before split");
 
-    if ( splitFrame->widget()->inherits( "KonqFrame" ) )
-      ((KonqFrame *)splitFrame->widget())->statusbar()->showStuff();
-
     splitFrame->widget()->setUpdatesEnabled( false );
     parentContainer->setUpdatesEnabled( false );
 
@@ -148,7 +143,7 @@ KonqChildView* KonqViewManager::split (KonqFrameBase* splitFrame,
 
     //kdDebug(1202) << "Move out child" << endl;
     parentContainer->removeChildFrame( splitFrame );
-    splitFrame->widget()->reparent( m_pMainView, pos );
+    splitFrame->widget()->reparent( m_pMainWindow, pos );
     splitFrame->widget()->hide(); // Can't hide before, but after is better than nothing
     splitFrame->widget()->resize( 100, 30 ); // bring it to the QWidget defaultsize, so that both container childs are equally size after split
 
@@ -181,22 +176,16 @@ KonqChildView* KonqViewManager::split (KonqFrameBase* splitFrame,
   }
   else // We had no main container, create one
   {
-    m_pMainContainer = new KonqFrameContainer( orientation, m_pMainView );
-    m_pMainView->setView( m_pMainContainer );
+    m_pMainContainer = new KonqFrameContainer( orientation, m_pMainWindow );
+    m_pMainWindow->setView( m_pMainContainer );
     m_pMainContainer->setOpaqueResize();
-    m_pMainContainer->setGeometry( 0, 0, m_pMainView->width(), m_pMainView->height() );
+    m_pMainContainer->setGeometry( 0, 0, m_pMainWindow->width(), m_pMainWindow->height() );
 
     childView = setupView( m_pMainContainer, newViewFactory, service, partServiceOffers, appServiceOffers, serviceType );
 
-    if ( m_dummyWidget )
-      delete (QWidget *)m_dummyWidget;
-
-    // exclude the splitter and all child widgets from the part focus handling
-    // where's the code for that comment ?? (David)
-
     m_pMainContainer->show();
 
-    childView->frame()->statusbar()->hideStuff();
+    //childView->frame()->statusbar()->hideStuff();
 
     if ( newFrameContainer )
       *newFrameContainer = m_pMainContainer;
@@ -207,19 +196,19 @@ KonqChildView* KonqViewManager::split (KonqFrameBase* splitFrame,
   return childView;
 }
 
-void KonqViewManager::removeView( KonqChildView *view )
+void KonqViewManager::removeView( KonqView *view )
 {
   //kdDebug(1202) << "---------------- removeView" << view << endl;
-  if ( activePart() == view->view() )
+  if ( activePart() == view->part() )
   {
-    KonqChildView *nextView = chooseNextView( view );
+    KonqView *nextView = chooseNextView( view );
     // Don't remove the last view
     if ( nextView == 0L )
       return;
     // Ensure this is not the active view anymore
-    //kdDebug(1202) << "Setting part " << nextView->view() << " as active" << endl;
-    nextView->view()->widget()->setFocus(); // hack ?
-    setActivePart( nextView->view() );
+    //kdDebug(1202) << "Setting part " << nextView->part() << " as active" << endl;
+    nextView->part()->widget()->setFocus(); // Will set the part as active
+    //setActivePart( nextView->part() );
   }
 
   KonqFrameContainer* parentContainer = view->frame()->parentContainer();
@@ -237,11 +226,11 @@ void KonqViewManager::removeView( KonqChildView *view )
 
   QPoint pos = otherFrame->widget()->pos();
 
-  otherFrame->reparentFrame( m_pMainView, pos );
+  otherFrame->reparentFrame( m_pMainWindow, pos );
   otherFrame->widget()->hide(); // Can't hide before, but after is better than nothing
   otherFrame->widget()->resize( 100, 30 ); // bring it to the QWidget defaultsize
 
-  m_pMainView->removeChildView( view );
+  m_pMainWindow->removeChildView( view );
 
   parentContainer->removeChildFrame( view->frame() );
   //kdDebug(1202) << "Deleting view frame" << view->frame() << endl;
@@ -267,14 +256,14 @@ void KonqViewManager::removeView( KonqChildView *view )
 // reimplemented from PartManager
 void KonqViewManager::removePart( KParts::Part * part )
 {
-  kdDebug() << "KonqViewManager::removePart ( " << part << " )" << endl;
+  kdDebug(1202) << "KonqViewManager::removePart ( " << part << " )" << endl;
   // This is called when a part auto-deletes itself (case 1), or when
   // the "delete view" above deletes, in turn, the part (case 2)
 
   // If we were called by PartManager::slotObjectDestroyed, then the inheritance has
   // been deleted already... Can't use inherits().
 
-  KonqChildView * cv = m_pMainView->childView( static_cast<KParts::ReadOnlyPart *>(part) );
+  KonqView * cv = m_pMainWindow->childView( static_cast<KParts::ReadOnlyPart *>(part) );
   if ( cv ) // the child view still exists, so we are in case 1
   {
       //kdDebug(1202) << "Found a child view" << endl;
@@ -288,14 +277,151 @@ void KonqViewManager::removePart( KParts::Part * part )
   //kdDebug(1202) << "KonqViewManager::removePart ( " << part << " ) done" << endl;
 }
 
-void KonqViewManager::saveViewProfile( KConfig &cfg )
+void KonqViewManager::viewCountChanged()
+{
+  bool bShowActiveViewIndicator = ( m_pMainWindow->activeViewsCount() > 1 );
+  bool bShowLinkedViewIndicator = ( m_pMainWindow->viewCount() > 1 );
+
+  KonqMainWindow::MapViews mapViews = m_pMainWindow->viewMap();
+  KonqMainWindow::MapViews::Iterator it = mapViews.begin();
+  KonqMainWindow::MapViews::Iterator end = mapViews.end();
+  for (  ; it != end ; ++it )
+  {
+      it.data()->frame()->statusbar()->showActiveViewIndicator(
+          bShowActiveViewIndicator && !it.data()->passiveMode()
+      );
+      it.data()->frame()->statusbar()->showLinkedViewIndicator( bShowLinkedViewIndicator );
+  }
+
+}
+void KonqViewManager::clear()
+{
+  kdDebug(1202) << "KonqViewManager::clear: " << endl;
+  QList<KonqView> viewList;
+  QListIterator<KonqView> it( viewList );
+
+  if (m_pMainContainer) {
+    m_pMainContainer->listViews( &viewList );
+
+    for ( it.toFirst(); it.current(); ++it ) {
+      m_pMainWindow->removeChildView( it.current() );
+      delete it.current();
+    }
+
+    //kdDebug(1202) << "deleting m_pMainContainer " << endl;
+    delete m_pMainContainer;
+    m_pMainContainer = 0L;
+  }
+}
+
+KonqView *KonqViewManager::chooseNextView( KonqView *view )
+{
+  kdDebug(1202) << "KonqViewManager(" << this << ")::chooseNextView(" << view << ")" << endl;
+  KonqMainWindow::MapViews mapViews = m_pMainWindow->viewMap();
+
+  KonqMainWindow::MapViews::Iterator it = mapViews.begin();
+  KonqMainWindow::MapViews::Iterator end = mapViews.end();
+  if ( view ) // find it in the map - can't use the key since view->part() might be 0L
+      while ( it != end && it.data() != view )
+          ++it;
+
+  KonqMainWindow::MapViews::Iterator startIt = it;
+
+  // the view should always be in the list, shouldn't it?
+  // maybe use assert( it != end )?
+   if ( it == end ) {
+     kdWarning() << "View " << view << " is not in list !" << endl;
+     it = mapViews.begin();
+     if ( it == end )
+       return 0L; // wow, that certainly caught all possibilities!
+   }
+
+  while ( true )
+  {
+
+    if ( ++it == end ) // move to next
+      it = mapViews.begin(); // rewind on end
+ 	
+    if ( it == startIt && view )
+      break; // no next view found
+
+    KonqView *nextView = it.data();
+    if ( nextView && !nextView->passiveMode() )
+      return nextView;
+  }
+
+  return 0L; // no next view found
+}
+
+KonqViewFactory KonqViewManager::createView( const QString &serviceType,
+					  const QString &serviceName,
+					  KService::Ptr &service,
+					  KTrader::OfferList &partServiceOffers,
+					  KTrader::OfferList &appServiceOffers )
+{
+  kdDebug(1202) << "KonqViewManager::createView" << endl;
+  KonqViewFactory viewFactory;
+
+  if( serviceType.isEmpty() && m_pMainWindow->currentView() ) {
+    //clone current view
+    KonqView *cv = m_pMainWindow->currentView();
+
+    viewFactory = KonqFactory::createView( cv->serviceType(), cv->service()->name(),
+				           &service, &partServiceOffers, &appServiceOffers );
+  }
+  else {
+    //create view with the given servicetype
+    viewFactory = KonqFactory::createView( serviceType, serviceName,
+		       	                   &service, &partServiceOffers, &appServiceOffers );
+  }
+
+  return viewFactory;
+}
+
+KonqView *KonqViewManager::setupView( KonqFrameContainer *parentContainer,
+                                           KonqViewFactory &viewFactory,
+				           const KService::Ptr &service,
+				           const KTrader::OfferList &partServiceOffers,
+					   const KTrader::OfferList &appServiceOffers,
+					   const QString &serviceType )
+{
+  kdDebug(1202) << "KonqViewManager::setupView" << endl;
+
+  QString sType = serviceType;
+
+  if ( sType.isEmpty() )
+    sType = m_pMainWindow->currentView()->serviceType();
+
+  KonqFrame* newViewFrame = new KonqFrame( parentContainer, "KonqFrame" );
+
+  kdDebug(1202) << "Creating KonqView" << endl;
+  KonqView *v = new KonqView( viewFactory, newViewFrame,
+                              m_pMainWindow, service, partServiceOffers, appServiceOffers, sType );
+  kdDebug(1202) << "KonqView created" << endl;
+
+  QObject::connect( v, SIGNAL( sigPartChanged( KonqView *, KParts::ReadOnlyPart *, KParts::ReadOnlyPart * ) ),
+                    m_pMainWindow, SLOT( slotPartChanged( KonqView *, KParts::ReadOnlyPart *, KParts::ReadOnlyPart * ) ) );
+
+  m_pMainWindow->insertChildView( v );
+
+  newViewFrame->show();
+
+  addPart( v->part(), false );
+
+  kdDebug(1202) << "KonqViewManager::setupView done" << endl;
+  return v;
+}
+
+///////////////// Profile stuff ////////////////
+
+void KonqViewManager::saveViewProfile( KConfig &cfg, bool saveURLs )
 {
   kdDebug(1202) << "KonqViewManager::saveViewProfile" << endl;
-  if( m_pMainContainer->firstChild() ) {
+  if( m_pMainContainer && m_pMainContainer->firstChild() ) {
     cfg.writeEntry( "RootItem", m_pMainContainer->firstChild()->frameType() + QString("%1").arg( 0 ) );
     QString prefix = m_pMainContainer->firstChild()->frameType() + QString("%1").arg( 0 );
     prefix.append( '_' );
-    m_pMainContainer->firstChild()->saveConfig( &cfg, prefix, 0, 1 );
+    m_pMainContainer->firstChild()->saveConfig( &cfg, prefix, saveURLs, 0, 1 );
   }
 
   cfg.sync();
@@ -303,7 +429,10 @@ void KonqViewManager::saveViewProfile( KConfig &cfg )
 
 void KonqViewManager::loadViewProfile( KConfig &cfg )
 {
-  kdDebug(1202) << "KonqViewManager::loadViewProfile" << endl;
+  KURL defaultURL;
+  if ( m_pMainWindow->currentView() )
+    defaultURL = m_pMainWindow->currentView()->url();
+
   clear();
 
   QString rootItem = cfg.readEntry( "RootItem" );
@@ -312,49 +441,45 @@ void KonqViewManager::loadViewProfile( KConfig &cfg )
     // Config file doesn't contain anything about view profiles, fallback to defaults
     rootItem = "InitialView";
   }
+  kdDebug(1202) << "KonqViewManager::loadViewProfile : loading RootItem " << rootItem << endl;
 
-  kdDebug(1202) << "Load RootItem " << debugString(rootItem) << endl;
-
-  m_pMainContainer = new KonqFrameContainer( Qt::Horizontal, m_pMainView );
-  m_pMainView->setView( m_pMainContainer );
+  m_pMainContainer = new KonqFrameContainer( Qt::Horizontal, m_pMainWindow );
+  m_pMainWindow->setView( m_pMainContainer );
   m_pMainContainer->setOpaqueResize();
-  m_pMainContainer->setGeometry( 0, 0, m_pMainView->width(), m_pMainView->height() );
+  m_pMainContainer->setGeometry( 0, 0, m_pMainWindow->width(), m_pMainWindow->height() );
   m_pMainContainer->show();
 
-  if ( m_dummyWidget )
-    delete (QWidget *)m_dummyWidget;
+  loadItem( cfg, m_pMainContainer, rootItem, defaultURL );
 
-  loadItem( cfg, m_pMainContainer, rootItem );
+  KonqView *nextChildView = chooseNextView( 0L );
+  setActivePart( nextChildView ? nextChildView->part() : 0L );
+  //if ( nextChildView )
+  //  nextChildView->part()->widget()->setFocus();
 
-  KonqChildView *nextChildView = chooseNextView( 0L );
-  setActivePart( nextChildView->view() );
+  // Window size
+  int width = cfg.readNumEntry( "Width", -1 );
+  int height = cfg.readNumEntry( "Height", -1 );
+  if ( width > -1 && height > -1 )
+    m_pMainWindow->resize( width, height );
 
-  //if ( lst.count() == 1 && !childView->passiveMode() )
-  //  childView->frame()->statusbar()->hideStuff();
   kdDebug(1202) << "KonqViewManager::loadViewProfile done" << endl;
   printFullHierarchy( m_pMainContainer );
 }
 
 void KonqViewManager::loadItem( KConfig &cfg, KonqFrameContainer *parent,
-				const QString &name )
+                                const QString &name, const KURL & defaultURL )
 {
   QString prefix;
   if( name != "InitialView" )
     prefix = name + '_';
 
-  kdDebug(1202) << "begin loadItem: " << debugString(name) << endl;
+  kdDebug(1202) << "begin loadItem: " << name << endl;
 
   if( name.find("View") != -1 ) {
     kdDebug(1202) << "Item is View" << endl;
     //load view config
-    QString url = cfg.readEntry( QString::fromLatin1( "URL" ).prepend( prefix ), QDir::homeDirPath() );
-
-    if ( url == "file:$HOME" ) // HACK
-      url = QDir::homeDirPath().prepend( "file:" );
-
-    kdDebug(1202) << "URL: " << debugString(url) << endl;
     QString serviceType = cfg.readEntry( QString::fromLatin1( "ServiceType" ).prepend( prefix ), "inode/directory");
-    kdDebug(1202) << "ServiceType: " << debugString(serviceType) << endl;
+    kdDebug(1202) << "ServiceType: " << serviceType << endl;
 
     QString serviceName = cfg.readEntry( QString::fromLatin1( "ServiceName" ).prepend( prefix ) );
 
@@ -372,7 +497,7 @@ void KonqViewManager::loadItem( KConfig &cfg, KonqFrameContainer *parent,
     }
 
     kdDebug(1202) << "Creating View Stuff" << endl;
-    KonqChildView *childView = setupView( parent, viewFactory, service, partServiceOffers, appServiceOffers, serviceType );
+    KonqView *childView = setupView( parent, viewFactory, service, partServiceOffers, appServiceOffers, serviceType );
 
     childView->setPassiveMode( passiveMode );
     childView->setLinkedView( linkedView );
@@ -380,8 +505,17 @@ void KonqViewManager::loadItem( KConfig &cfg, KonqFrameContainer *parent,
     //QCheckBox *checkBox = childView->frame()->statusbar()->passiveModeCheckBox();
     //checkBox->setChecked( passiveMode );
 
-    childView->openURL( KURL( url ) );
-    childView->setLocationBarURL( url );
+    QString key = QString::fromLatin1( "URL" ).prepend( prefix );
+    KURL url( defaultURL );
+    if ( cfg.hasKey( key ) ) // if it has it, we load it, even if empty
+      url = KURL( cfg.readEntry( key ) );
+
+    if ( !url.isEmpty() )
+    {
+      kdDebug(1202) << "loadItem: calling openURL " << url.prettyURL() << endl;
+      childView->openURL( url );
+    }
+    childView->setLocationBarURL( url.prettyURL() );
   }
   else if( name.find("Container") != -1 ) {
     kdDebug(1202) << "Item is Container" << endl;
@@ -395,7 +529,7 @@ void KonqViewManager::loadItem( KConfig &cfg, KonqFrameContainer *parent,
     else if( ostr == "Horizontal" )
       o = Qt::Horizontal;
     else {
-      warning("Profile Loading Error: No orientation specified in %s", debugString(name));;
+	kdWarning() << "Profile Loading Error: No orientation specified in " << name << endl;
       o = Qt::Horizontal;
     }
 
@@ -405,9 +539,9 @@ void KonqViewManager::loadItem( KConfig &cfg, KonqFrameContainer *parent,
     QStrList childList;
     if( cfg.readListEntry( QString::fromLatin1( "Children" ).prepend( prefix ), childList ) < 2 )
     {
-      warning("Profile Loading Error: Less than two children in %s", debugString(name));
+      kdWarning() << "Profile Loading Error: Less than two children in " << name << endl;
       // fallback to defaults
-      loadItem( cfg, parent, "InitialView" );
+      loadItem( cfg, parent, "InitialView", defaultURL );
     }
     else
     {
@@ -415,75 +549,16 @@ void KonqViewManager::loadItem( KConfig &cfg, KonqFrameContainer *parent,
       newContainer->setOpaqueResize();
       newContainer->show();
 
-      loadItem( cfg, newContainer, childList.at(0) );
-      loadItem( cfg, newContainer, childList.at(1) );
+      loadItem( cfg, newContainer, childList.at(0), defaultURL );
+      loadItem( cfg, newContainer, childList.at(1), defaultURL );
 
       newContainer->setSizes( sizes );
     }
   }
   else
-    warning("Profile Loading Error: Unknown item %s", debugString(name));
+      kdWarning() << "Profile Loading Error: Unknown item " << name;
 
-  kdDebug(1202) << "end loadItem: " << debugString(name) << endl;
-}
-
-void KonqViewManager::clear()
-{
-  kdDebug(1202) << "KonqViewManager::clear: " << endl;
-  QList<KonqChildView> viewList;
-  QListIterator<KonqChildView> it( viewList );
-
-  if (m_pMainContainer) {
-    m_pMainContainer->listViews( &viewList );
-
-    for ( it.toFirst(); it.current(); ++it ) {
-      m_pMainView->removeChildView( it.current() );
-      delete it.current();
-    }
-
-    //kdDebug(1202) << "deleting m_pMainContainer " << endl;
-    delete m_pMainContainer;
-    m_pMainContainer = 0L;
-  }
-}
-
-KonqChildView *KonqViewManager::chooseNextView( KonqChildView *view )
-{
-  kdDebug() << "KonqViewManager(" << this << ")::chooseNextView(" << view << ")" << endl;
-  KonqMainView::MapViews mapViews = m_pMainView->viewMap();
-
-  KonqMainView::MapViews::Iterator it = mapViews.begin();
-  KonqMainView::MapViews::Iterator end = mapViews.end();
-  if ( view ) // find it in the map - can't use the key since view->view() might be 0L
-      while ( it != end && it.data() != view )
-          ++it;
-
-  KonqMainView::MapViews::Iterator startIt = it;
-
-  // the view should always be in the list, shouldn't it?
-  // maybe use assert( it != end )?
-   if ( it == end ) {
-       kdWarning() << "View " << view << " is not in list !" << endl;
-     it = mapViews.begin();
-     if ( it == end )
-       return 0L; // wow, that certainly caught all possibilities!
-   }
-
-  while ( true )
-  {
-
-    if ( ++it == end ) // move to next
-      it = mapViews.begin(); // rewind on end
- 	
-    if ( it == startIt )
-      break; // no next view found
-
-    KonqChildView *nextView = it.data();
-    if ( nextView && !nextView->passiveMode() )
-      return nextView;
-  }
-
-  return 0L; // no next view found
+  kdDebug(1202) << "end loadItem: " << name << endl;
 }
 
 void KonqViewManager::setProfiles( KActionMenu *profiles )
@@ -497,74 +572,27 @@ void KonqViewManager::setProfiles( KActionMenu *profiles )
     connect( m_pamProfiles->popupMenu(), SIGNAL( aboutToShow() ),
              this, SLOT( slotProfileListAboutToShow() ) );
   }	
-	
-  m_bProfileListDirty = true;
+  //KonqMainWindow::enableAllActions will call it anyway
+  //profileListDirty();
 }
 
 void KonqViewManager::slotProfileDlg()
 {
-  KonqProfileDlg dlg( this, m_pMainView );
+  KonqProfileDlg dlg( this, m_pMainWindow );
   dlg.exec();
+  profileListDirty();
+}
+
+void KonqViewManager::profileListDirty()
+{
+  kdDebug(1202) << "KonqViewManager::profileListDirty()" << endl;
   m_bProfileListDirty = true;
-}
-
-KonqViewFactory KonqViewManager::createView( const QString &serviceType,
-					  const QString &serviceName,
-					  KService::Ptr &service,
-					  KTrader::OfferList &partServiceOffers,
-					  KTrader::OfferList &appServiceOffers )
-{
-  kdDebug(1202) << "KonqViewManager::createView" << endl;
-  KonqViewFactory viewFactory;
-
-  if( serviceType.isEmpty() && m_pMainView->currentChildView() ) {
-    //clone current view
-    KonqChildView *cv = m_pMainView->currentChildView();
-
-    viewFactory = KonqFactory::createView( cv->serviceType(), cv->service()->name(),
-				           &service, &partServiceOffers, &appServiceOffers );
-  }
-  else {
-    //create view with the given servicetype
-    viewFactory = KonqFactory::createView( serviceType, serviceName,
-		       	                   &service, &partServiceOffers, &appServiceOffers );
-  }
-
-  return viewFactory;
-}
-
-KonqChildView *KonqViewManager::setupView( KonqFrameContainer *parentContainer,
-                                           KonqViewFactory &viewFactory,
-				           const KService::Ptr &service,
-				           const KTrader::OfferList &partServiceOffers,
-					   const KTrader::OfferList &appServiceOffers,
-					   const QString &serviceType )
-{
-  kdDebug(1202) << "KonqViewManager::setupView" << endl;
-
-  QString sType = serviceType;
-
-  if ( sType.isEmpty() )
-    sType = m_pMainView->currentChildView()->serviceType();
-
-  KonqFrame* newViewFrame = new KonqFrame( parentContainer, "KonqFrame" );
-
-  kdDebug(1202) << "Creating KonqChildView" << endl;
-  KonqChildView *v = new KonqChildView( viewFactory, newViewFrame,
-					m_pMainView, service, partServiceOffers, appServiceOffers, sType );
-  kdDebug(1202) << "KonqChildView created" << endl;
-
-  QObject::connect( v, SIGNAL( sigViewChanged( KonqChildView *, KParts::ReadOnlyPart *, KParts::ReadOnlyPart * ) ),
-                    m_pMainView, SLOT( slotViewChanged( KonqChildView *, KParts::ReadOnlyPart *, KParts::ReadOnlyPart * ) ) );
-
-  m_pMainView->insertChildView( v );
-
-  newViewFrame->show();
-
-  addPart( v->view(), false );
-
-  kdDebug(1202) << "KonqViewManager::setupView done" << endl;
-  return v;
+#if 0
+  // There's always one profile at least, now...
+  QStringList profiles = KonqFactory::instance()->dirs()->findAllResources( "data", "konqueror/profiles/*", false, true );
+  if ( m_pamProfiles )
+      m_pamProfiles->setEnabled( profiles.count() > 0 );
+#endif
 }
 
 void KonqViewManager::slotProfileActivated( int id )
@@ -575,6 +603,7 @@ void KonqViewManager::slotProfileActivated( int id )
     return;
 
   KConfig cfg( *nameIt, true );
+  cfg.setDollarExpansion( true );
   cfg.setGroup( "Profile" );
   loadViewProfile( cfg );
 }
@@ -587,27 +616,19 @@ void KonqViewManager::slotProfileListAboutToShow()
   QPopupMenu *popup = m_pamProfiles->popupMenu();
 
   popup->clear();
-  m_mapProfileNames.clear();
 
-  QStringList profiles = KonqFactory::instance()->dirs()->findAllResources( "data", "konqueror/profiles/*", false, true );
-  QStringList::ConstIterator pIt = profiles.begin();
-  QStringList::ConstIterator pEnd = profiles.end();
-  for (; pIt != pEnd; ++pIt )
-  {
-    QFileInfo info( *pIt );
-    QString profileName = info.baseName();
-    KSimpleConfig cfg( *pIt, true );
-    cfg.setGroup( "Profile" );
-    if ( cfg.hasKey( "Name" ) )
-      profileName = cfg.readEntry( "Name" );
+  m_mapProfileNames = KonqProfileDlg::readAllProfiles();
 
-    m_mapProfileNames.insert( profileName, *pIt );
-    popup->insertItem( profileName );
-  }
+  QMap<QString,QString>::ConstIterator eIt = m_mapProfileNames.begin();
+  QMap<QString,QString>::ConstIterator eEnd = m_mapProfileNames.end();
+  for (; eIt != eEnd; ++eIt )
+    popup->insertItem( eIt.key() );
 
   m_bProfileListDirty = false;
 }
 
+///////////////// Debug stuff ////////////////
+
 void KonqViewManager::printSizeInfo( KonqFrameBase* frame,
 				     KonqFrameContainer* parent,
 				     const char* msg )
@@ -640,7 +661,7 @@ void KonqViewManager::printFullHierarchy( KonqFrameContainer * container, int id
             printFullHierarchy( static_cast<KonqFrameContainer *>(child), ident + 2 );
         else
             kdDebug(1202) << spaces << "  " << "KonqFrame " << child << " containing a "
-                          << static_cast<KonqFrame *>(child)->view()->widget()->className() << endl;
+                          << static_cast<KonqFrame *>(child)->part()->widget()->className() << endl;
         child = container->secondChild();
         if ( !child )
             kdDebug(1202) << spaces << "  Null child ! " << endl;
@@ -648,7 +669,7 @@ void KonqViewManager::printFullHierarchy( KonqFrameContainer * container, int id
             printFullHierarchy( static_cast<KonqFrameContainer *>(child), ident + 2 );
         else
             kdDebug(1202) << spaces << "  " << "KonqFrame " << child << " containing a "
-                          << static_cast<KonqFrame *>(child)->view()->widget()->className() << endl;
+                          << static_cast<KonqFrame *>(child)->part()->widget()->className() << endl;
     }
     else
         kdDebug(1202) << "Null container ?!?!" << endl;
