@@ -18,7 +18,7 @@
 */
 
 #ifndef __konq_viewmgr_h__
-#define __konq_viewmgr_h__ $Id: konq_viewmgr.h,v 1.29 2000/05/05 01:03:37 faure Exp $
+#define __konq_viewmgr_h__ $Id: konq_viewmgr.h,v 1.39 2000/06/07 23:36:17 faure Exp $
 
 #include "konq_factory.h"
 
@@ -34,10 +34,10 @@
 class QString;
 class QStringList;
 class KConfig;
-class KonqMainView;
+class KonqMainWindow;
 class KonqFrameBase;
 class KonqFrameContainer;
-class KonqChildView;
+class KonqView;
 class BrowserView;
 class KActionMenu;
 
@@ -50,7 +50,7 @@ class KonqViewManager : public KParts::PartManager
 {
   Q_OBJECT
 public:
-  KonqViewManager( KonqMainView *mainView );
+  KonqViewManager( KonqMainWindow *mainWindow );
   ~KonqViewManager();
 
   /**
@@ -61,57 +61,77 @@ public:
    * If no Service Type was provided it takes the one from the current view.
    * Returns the newly created view or 0L if the view couldn't be created.
    */
-  KonqChildView* splitView( Qt::Orientation orientation,
-                            const KURL &url,
-                            QString serviceType = QString::null,
-                            const QString & serviceName = QString::null );
+  KonqView* splitView( Qt::Orientation orientation,
+                       const KURL &url,
+                       QString serviceType = QString::null,
+                       const QString & serviceName = QString::null );
 
   /**
    * Does basically the same as splitView() but inserts the new view at the top
    * of the view tree.
    * Returns the newly created view or 0L if the view couldn't be created.
    */
-  KonqChildView* splitWindow( Qt::Orientation orientation );
+  KonqView* splitWindow( Qt::Orientation orientation );
 
   /**
    * Do the actual splitting. The new View will be created from serviceType.
    * Returns the newly created view or 0L if the new view couldn't be created.
    */
-  KonqChildView* split (KonqFrameBase* splitFrame,
-                        Qt::Orientation orientation,
-                        const QString &serviceType = QString::null,
-                        const QString &serviceName = QString::null,
-                        KonqFrameContainer **newFrameContainer = 0L );
+  KonqView* split (KonqFrameBase* splitFrame,
+                   Qt::Orientation orientation,
+                   const QString &serviceType = QString::null,
+                   const QString &serviceName = QString::null,
+                   KonqFrameContainer **newFrameContainer = 0L );
 
   /**
    * Guess!:-)
    * Also takes care of setting another view as active if @p view was the active view
    */
-  void removeView( KonqChildView *view );
+  void removeView( KonqView *view );
+
+  /**
+   * Saves the current view layout to a config file.
+   * Remove config file before saving, especially if saveURLs is false.
+   * @param cfg the config file
+   * @param saveURLs whether to save the URLs in the profile or not
+   */
+  void saveViewProfile( KConfig &cfg, bool saveURLs );
 
   /**
    * Loads a view layout from a config file. Removes all views before loading.
-   */
-  void saveViewProfile( KConfig &cfg );
-
-  /**
-   * Savess the current view layout to a config file.
+   * @param cfg the config file
    */
   void loadViewProfile( KConfig &cfg );
 
   /**
    * Load the config entries for a view.
+   * @param cfg the config file
+   * ...
+   * @param defaultURL the URL to use if the profile doesn't contain urls
    */
-  void loadItem( KConfig &cfg, KonqFrameContainer *parent, const QString &name );
+  void loadItem( KConfig &cfg, KonqFrameContainer *parent,
+                 const QString &name, const KURL & defaultURL );
 
   void clear();
 
-  KonqChildView *chooseNextView( KonqChildView *view );
+  KonqView *chooseNextView( KonqView *view );
+
+  /**
+   * Called whenever
+   * - the total number of views changed
+   * - the number of views in passive mode changed
+   * The implementation takes care of showing or hiding the statusbar indicators
+   */
+  void viewCountChanged();
 
   void setProfiles( KActionMenu *profiles );
 
+  void profileListDirty();
+
   KonqFrameContainer *mainContainer() const { return m_pMainContainer; }
 
+  KonqMainWindow *mainWindow() const { return m_pMainWindow; }
+
   /**
    * Reimplemented from PartManager
    */
@@ -124,6 +144,10 @@ protected slots:
 
   void slotProfileListAboutToShow();
 
+protected:
+
+  // Disabled - we do it ourselves
+  virtual void setActiveInstance( KInstance * ) {}
 
 private:
 
@@ -139,10 +163,10 @@ private:
 			      KTrader::OfferList &appServiceOffers );
 
   /**
-   * Mainly creates the backend structure(KonqChildView) for a view and
+   * Mainly creates the backend structure(KonqView) for a view and
    * connects it
    */
-  KonqChildView *setupView( KonqFrameContainer *parentContainer,
+  KonqView *setupView( KonqFrameContainer *parentContainer,
                             KonqViewFactory &viewFactory,
 		            const KService::Ptr &service,
 		            const KTrader::OfferList &partServiceOffers,
@@ -155,7 +179,7 @@ private:
 		      const char* msg );
   void printFullHierarchy( KonqFrameContainer * container, int ident = 0 );
 
-  KonqMainView *m_pMainView;
+  KonqMainWindow *m_pMainWindow;
 
   KonqFrameContainer *m_pMainContainer;
 
@@ -163,8 +187,6 @@ private:
   bool m_bProfileListDirty;
 
   QMap<QString, QString> m_mapProfileNames;
-
-  QGuardedPtr<QWidget> m_dummyWidget;
 };
 
 #endif
