@@ -41,6 +41,16 @@
 #include <stdlib.h>
 #include <assert.h>
 
+ColumnInfo::ColumnInfo()
+   :displayInColumn(-1)
+   ,name("")
+   ,desktopFileName("")
+   ,udsId(0)
+   ,displayThisOne(FALSE)
+   ,toggleThisOne(0)
+{};
+
+
 ColumnInfo::ColumnInfo(const char* n, const char* desktopName, int kioUds,int count,bool enabled,KToggleAction* someAction)
    :displayInColumn(count)
    ,name(n)
@@ -48,19 +58,28 @@ ColumnInfo::ColumnInfo(const char* n, const char* desktopName, int kioUds,int co
    ,udsId(kioUds)
    ,displayThisOne(enabled)
    ,toggleThisOne(someAction)
-{};
+{}
 
+void ColumnInfo::setData(const char* n, const char* desktopName, int kioUds,int count,bool enabled,KToggleAction* someAction)
+{
+   displayInColumn=count;
+   name=n;
+   desktopFileName=desktopName;
+   udsId=kioUds;
+   displayThisOne=enabled;
+   toggleThisOne=someAction;
+};
 
 
 KonqBaseListViewWidget::KonqBaseListViewWidget( KonqListView *parent, QWidget *parentWidget)
 :KListView(parentWidget )
+,sortedByColumn(0)
+,ascending(TRUE)
 ,m_dirLister(0L)
 ,m_dragOverItem(0L)
 ,m_pressed(FALSE)
 ,m_pressedItem(0L)
-,m_iconSize(KIcon::SizeSmall)
 ,m_filesSelected(FALSE)
-,m_checkMimeTypes(TRUE)
 ,m_showIcons(TRUE)
 ,m_filenameColumn(0)
 ,m_pBrowserView(parent)
@@ -75,10 +94,10 @@ KonqBaseListViewWidget::KonqBaseListViewWidget( KonqListView *parent, QWidget *p
    // All the listview view modes inherit the same properties defaults...
    m_pProps = new KonqPropsView( KonqListViewFactory::instance(), KonqListViewFactory::defaultViewProps() );
 
-   //Adjust QListView behaviour
-   setSelectionMode( Extended );
+   //Adjust KListView behaviour
+   setSelectionModeExt( Konqueror );
    setMultiSelection(TRUE);
-   setSorting(0);
+   //setSorting(m_filenameColumn);
 
    initConfig();
 
@@ -101,7 +120,7 @@ KonqBaseListViewWidget::KonqBaseListViewWidget( KonqListView *parent, QWidget *p
    //setFrameStyle( QFrame::NoFrame | QFrame::Plain );
    setShowSortIndicator(TRUE);
 
-   confColumns.setAutoDelete(TRUE);
+   //confColumns.setAutoDelete(TRUE);
 }
 
 KonqBaseListViewWidget::~KonqBaseListViewWidget()
@@ -110,225 +129,26 @@ KonqBaseListViewWidget::~KonqBaseListViewWidget()
 
   if ( m_dirLister ) delete m_dirLister;
   delete m_pProps;
-
-  iterator it = begin();
-  for( ; it != end(); ++it )
-    it->prepareToDie();
 }
 
-void KonqBaseListViewWidget::keyPressEvent( QKeyEvent *_ev )
-{
-   if ((_ev->state()==ShiftButton) && (!m_wasShiftEvent)) selectAll(FALSE);
-   m_wasShiftEvent=(_ev->state()==ShiftButton);
-   //cerr<<"keyPressEvent"<<endl;
-   // We are only interested in the insert key here
-   KonqListViewItem* item = (KonqListViewItem*)currentItem();
-   //insert without modifiers toggles the selection of the current item and moves to the next
-   if (item==0) return;
-   QListViewItem *nextItem(0);
-   int items(0);
-   if (((_ev->key() == Key_Enter)|| (_ev->key()==Key_Return)) && (_ev->state()==ControlButton))
-   {
-      KonqBaseListViewItem* item = (KonqBaseListViewItem*)currentItem();
-
-      if ( !item->isSelected() )
-      {
-         iterator it = begin();
-         for( ; it != end(); it++ )
-            if ( it->isSelected() )
-               setSelected( &*it, false );
-         setSelected( item, true );
-      }
-      QPoint p( width() / 2, height() / 2 );
-      p = mapToGlobal( p );
-      popupMenu( p );
-      return;
-   };
-   switch (_ev->key())
-   {
-   case Key_Escape:
-      selectAll(FALSE);
-      break;
-   case Key_Space:
-      //toggle selection of current item
-      item->setSelected(!item->isSelected());
-      item->repaint();
-      emit selectionChanged();
-      updateSelectedFilesInfo();
-      break;
-   case Key_Insert:
-      //toggle selection of current item and move to the next item
-      item->setSelected(!item->isSelected());
-      nextItem=item->itemBelow();
-      if (nextItem!=0)
-      {
-         setCurrentItem(nextItem);
-         ensureItemVisible(nextItem);
-      }
-      else item->repaint();
-      emit selectionChanged();
-      updateSelectedFilesInfo();
-      break;
-   case Key_Down:
-      //toggle selection of current item and move to the next item
-      if ((_ev->state()==ShiftButton) || (_ev->state()==(ControlButton|ShiftButton)))
-         item->setSelected(!item->isSelected());
-      nextItem=item->itemBelow();
-      if (nextItem!=0)
-      {
-         setCurrentItem(nextItem);
-         ensureItemVisible(nextItem);
-      }
-      else item->repaint();
-      if ((_ev->state()==ShiftButton) || (_ev->state()==(ControlButton|ShiftButton)))
-      {
-         emit selectionChanged();
-         updateSelectedFilesInfo();
-      };
-      break;
-   case Key_Up:
-      //move to the prev. item and toggle selection of this one
-      nextItem=item->itemAbove();
-      if (nextItem==0) break;
-      if ((_ev->state()==ShiftButton) || (_ev->state()==(ControlButton|ShiftButton)))
-         nextItem->setSelected(!nextItem->isSelected());
-      setCurrentItem(nextItem);
-      ensureItemVisible(nextItem);
-      if ((_ev->state()==ShiftButton) || (_ev->state()==(ControlButton|ShiftButton)))
-      {
-         emit selectionChanged();
-         updateSelectedFilesInfo();
-      };
-      break;
-   case Key_End:
-      //move to the last item and toggle selection of all items inbetween
-      nextItem=item;
-
-      while(nextItem!=0)
-      {
-         if ((_ev->state()==ShiftButton) || (_ev->state()==(ControlButton|ShiftButton)))
-            nextItem->setSelected(!nextItem->isSelected());
-         if (nextItem->itemBelow()==0)
-         {
-            nextItem->repaint();
-            ensureItemVisible(nextItem);
-            setCurrentItem(nextItem);
-         };
-         nextItem=nextItem->itemBelow();
-      };
-      if ((_ev->state()==ShiftButton) || (_ev->state()==(ControlButton|ShiftButton)))
-      {
-         emit selectionChanged();
-         updateSelectedFilesInfo();
-      };
-      break;
-   case Key_Home:
-      //move to the last item and toggle selection of all items inbetween
-      nextItem=item;
-
-      while(nextItem!=0)
-      {
-         if ((_ev->state()==ShiftButton) || (_ev->state()==(ControlButton|ShiftButton)))
-            nextItem->setSelected(!nextItem->isSelected());
-         if (nextItem->itemAbove()==0)
-         {
-            nextItem->repaint();
-            ensureItemVisible(nextItem);
-            setCurrentItem(nextItem);
-         };
-         nextItem=nextItem->itemAbove();
-      };
-      if ((_ev->state()==ShiftButton) || (_ev->state()==(ControlButton|ShiftButton)))
-      {
-         emit selectionChanged();
-         updateSelectedFilesInfo();
-      };
-
-      break;
-   case Key_Next:
-      items=visibleHeight()/item->height();
-      nextItem=item;
-      for (int i=0; i<items; i++)
-      {
-         if ((_ev->state()==ShiftButton) || (_ev->state()==(ControlButton|ShiftButton)))
-            nextItem->setSelected(!nextItem->isSelected());
-         //the end
-         if ((i==items-1) || (nextItem->itemBelow()==0))
-
-         {
-            if ((_ev->state()==ShiftButton) || (_ev->state()==(ControlButton|ShiftButton)))
-               nextItem->setSelected(!nextItem->isSelected());
-            nextItem->repaint();
-            ensureItemVisible(nextItem);
-            setCurrentItem(nextItem);
-            if ((_ev->state()==ShiftButton) || (_ev->state()==(ControlButton|ShiftButton)))
-            {
-               emit selectionChanged();
-               updateSelectedFilesInfo();
-            };
-            return;
-         };
-         nextItem=nextItem->itemBelow();
-      };
-      break;
-   case Key_Prior:
-      items=visibleHeight()/item->height();
-      nextItem=item;
-      for (int i=0; i<items; i++)
-      {
-         if ((nextItem!=item) &&((_ev->state()==ShiftButton) || (_ev->state()==(ControlButton|ShiftButton))))
-            nextItem->setSelected(!nextItem->isSelected());
-         //the end
-         if ((i==items-1) || (nextItem->itemAbove()==0))
-
-         {
-            nextItem->repaint();
-            ensureItemVisible(nextItem);
-            setCurrentItem(nextItem);
-            if ((_ev->state()==ShiftButton) || (_ev->state()==(ControlButton|ShiftButton)))
-            {
-               emit selectionChanged();
-               updateSelectedFilesInfo();
-            };
-            return;
-         };
-         nextItem=nextItem->itemAbove();
-      };
-
-      break;
-    case Key_Minus:
-       if ( item->isOpen() )
-          setOpen( item, FALSE );
-       break;
-    case Key_Plus:
-       if (  !item->isOpen() && (item->isExpandable() || item->childCount()) )
-          setOpen( item, TRUE );
-       break;
-   default:
-      KListView::keyPressEvent( _ev );
-      break;
-   };
-};
-
 void KonqBaseListViewWidget::readProtocolConfig( const QString & protocol )
 {
    kdDebug(1202)<<"readProtocolConfig: -"<<protocol<<"-"<<endl;
 
    KConfig * config = KGlobal::config();
-   //kdDebug(1202) << "in readProtocolConfig: protocol: -" <<protocol<<"-"<< endl;
    if ( config->hasGroup( "ListView_" + protocol ) )
       config->setGroup( "ListView_" + protocol );
    else
       config->setGroup( "ListView_default" );
 
+   sortedByColumn=config->readEntry("SortBy","FileName");
+   ascending=config->readBoolEntry("SortOrder",TRUE);
+
    QStringList lstColumns = config->readListEntry( "Columns" );
    if (lstColumns.isEmpty())
    {
-// Default column selection
-//      lstColumns.append( "Name" );
-//      lstColumns.append( "Type" );
+      // Default column selection
       lstColumns.append( "Size" );
-      //lstColumns.append( "Date" );
       lstColumns.append( "Modified" );
       lstColumns.append( "Permissions" );
       lstColumns.append( "Owner" );
@@ -336,46 +156,62 @@ void KonqBaseListViewWidget::readProtocolConfig( const QString & protocol )
       lstColumns.append( "Link" );
    }
 
-   for (unsigned int i=0; i<confColumns.count(); i++)
+   //disable everything
+   for (unsigned int i=0; i<NumberOfAtoms; i++)
    {
-      confColumns.at(i)->displayThisOne=FALSE;
-      confColumns.at(i)->toggleThisOne->setChecked(FALSE);
-      confColumns.at(i)->toggleThisOne->setEnabled(TRUE);
+      confColumns[i].displayThisOne=FALSE;
+      confColumns[i].displayInColumn=-1;
+      confColumns[i].toggleThisOne->setChecked(FALSE);
+      confColumns[i].toggleThisOne->setEnabled(TRUE);
    };
+   int currentColumn(m_filenameColumn+1);
    //check all columns in lstColumns
    for (unsigned int i=0; i<lstColumns.count(); i++)
    {
       //search the column in confColumns
-      for (unsigned int j=0; j<confColumns.count(); j++)
+      for (unsigned int j=0; j<NumberOfAtoms; j++)
       {
-         if (confColumns.at(j)->name==*lstColumns.at(i))
+         if (confColumns[j].name==*lstColumns.at(i))
          {
-            confColumns.at(j)->displayThisOne=TRUE;
-            confColumns.at(j)->toggleThisOne->setChecked(TRUE);
+            confColumns[j].displayThisOne=TRUE;
+            confColumns[j].displayInColumn=currentColumn;
+            confColumns[j].toggleThisOne->setChecked(TRUE);
+            currentColumn++;
             break;
-         };
-      };
-   };
+         }
+      }
+   }
+   //check what the protocol provides
    KProtocolManager *protocolManager=&KProtocolManager::self();
    QStringList listingList=protocolManager->listing(protocol);
    kdDebug(1202)<<"protocol: -"<<protocol<<"-"<<endl;
-   for (int j=0; j<listingList.count(); j++)
+   for (unsigned int j=0; j<listingList.count(); j++)
       kdDebug(1202)<<"listing: -"<<*listingList.at(j)<<"-"<<endl;
 
-   for (int i=0; i<confColumns.count(); i++)
-   {
-      int k(0);
-      for (k=0; k<listingList.count(); k++)
-         if (*listingList.at(k)==confColumns.at(i)->desktopFileName) break;
-      if (*listingList.at(k)!=confColumns.at(i)->desktopFileName)
-      {
-         confColumns.at(i)->displayThisOne=FALSE;
-         confColumns.at(i)->toggleThisOne->setEnabled(FALSE);
-         confColumns.at(i)->toggleThisOne->setChecked(FALSE);
-      };
-   };
-};
+   // Even if this is not given by the protocol, we can determine it.
+   // Please don't remove this ;-). It makes it possible to show the file type
+   // using the mimetype comment, which for most users is a nicer alternative
+   // than the raw mimetype name.
+   listingList.append( "MimeType" );
 
+   for (unsigned int i=0; i<NumberOfAtoms; i++)
+   {
+      if ((confColumns[i].udsId==KIO::UDS_URL) || (confColumns[i].udsId==KIO::UDS_MIME_TYPE))
+         continue;
+      unsigned int k(0);
+      for (k=0; k<listingList.count(); k++)
+         if (*listingList.at(k)==confColumns[i].desktopFileName) break;
+      if (*listingList.at(k)!=confColumns[i].desktopFileName)
+      {
+         for (unsigned int l=0; l<NumberOfAtoms; l++)
+            if (confColumns[i].displayInColumn>confColumns[i].displayInColumn)
+               confColumns[i].displayInColumn--;
+         confColumns[i].displayThisOne=FALSE;
+         confColumns[i].toggleThisOne->setEnabled(FALSE);
+         confColumns[i].toggleThisOne->setChecked(FALSE);
+      }
+   }
+}
 
 void KonqBaseListViewWidget::stop()
 {
@@ -407,7 +243,7 @@ void KonqBaseListViewWidget::updateSelectedFilesInfo()
             fileCount++;
          }
       }
-   };
+   }
    if (m_filesSelected)
    {
       int items(fileCount+dirCount);
@@ -427,10 +263,10 @@ void KonqBaseListViewWidget::updateSelectedFilesInfo()
          m_selectedFilesStatusText+= i18n("One Directory");
       else
          m_selectedFilesStatusText+= i18n("%1 Directories").arg(dirCount);
-   };
+   }
    emit m_pBrowserView->setStatusBarText(m_selectedFilesStatusText);
    //cerr<<"KonqTextViewWidget::updateSelectedFilesInfo"<<endl;
-};
+}
 
 /*QStringList KonqBaseListViewWidget::readProtocolConfig( const QString & protocol )
 {
@@ -611,7 +447,8 @@ void KonqBaseListViewWidget::viewportMousePressEvent( QMouseEvent *_ev )
 {
   KListView::viewportMousePressEvent( _ev );
 
-  QPoint globalPos = mapToGlobal( _ev->pos() );
+  //what was it intended for ? (alex)
+  //QPoint globalPos = mapToGlobal( _ev->pos() );
   m_pressed = false;
 
   KonqBaseListViewItem *item = (KonqBaseListViewItem*)itemAt( _ev->pos() );
@@ -684,7 +521,7 @@ void KonqBaseListViewWidget::viewportMouseMoveEvent( QMouseEvent *_mouse )
             hotspot.setX( m_pressedItem->pixmap( 0 )->width() / 2 );
             hotspot.setY( m_pressedItem->pixmap( 0 )->height() / 2 );
             d->setPixmap( *(m_pressedItem->pixmap( 0 )), hotspot );
-         };
+         }
          d->drag();
       }
    }
@@ -728,7 +565,7 @@ void KonqBaseListViewWidget::slotOnViewport()
    //TODO: Display summary in DetailedList in statusbar, like iconview does
 }
 
-void KonqBaseListViewWidget::slotExecuted( QListViewItem* _item )
+void KonqBaseListViewWidget::slotExecuted( QListViewItem* )
 {
   //if ( isSingleClickArea( _mouse->pos() ) )
   {
@@ -760,17 +597,17 @@ KURL::List KonqBaseListViewWidget::selectedUrls()
 void KonqBaseListViewWidget::emitCompleted()
 {
    emit m_pBrowserView->completed();
-};
+}
 
 void KonqBaseListViewWidget::emitOpenURLRequest(const KURL& url, const KParts::URLArgs& args)
 {
    emit m_pBrowserView->extension()->openURLRequest(url,args);
-};
+}
 
 void KonqBaseListViewWidget::emitStarted( KIO::Job * job)
 {
    emit m_pBrowserView->started( job );
-};
+}
 
 void KonqBaseListViewWidget::slotReturnPressed( QListViewItem *_item )
 {
@@ -786,12 +623,29 @@ void KonqBaseListViewWidget::slotReturnPressed( QListViewItem *_item )
     if (KonqFMSettings::settings()->alwaysNewWin() && fileItem->mode() & S_IFDIR) {
 	fileItem->run();
     } else {
-        KParts::URLArgs args;
-        args.serviceType = fileItem->mimetype();
-        emitOpenURLRequest( fileItem->url(), args );
+        // We want to emit openURLRequest, but not right now, because
+        // the listview is going to emit other signals (mouse release).
+        // Let's not destroy it while it isn't finished emitting.
+        openURLRequestFileItem = fileItem;
+        QTimer::singleShot( 0, this, SLOT(slotOpenURLRequest()) );
     }
 }
 
+void KonqBaseListViewWidget::slotOpenURLRequest()
+{
+  if ( !openURLRequestFileItem )
+    // This shouldn't happen. Well, it can, if one double-clicks on an icon
+    // or for any other reason, two singleshots get fired before we get here.
+    kdWarning(1202) << "Null openURLRequestFileItem in KonqBaseListViewWidget !" << endl;
+  else
+  {
+    KParts::URLArgs args;
+    args.serviceType = openURLRequestFileItem->mimetype();
+    emit m_pBrowserView->extension()->openURLRequest( openURLRequestFileItem->url(), args );
+    openURLRequestFileItem = 0L;
+  }
+}
+
 /*void KonqBaseListViewWidget::slotReturnPressed( QListViewItem *_item )
 {
   if ( !_item )
@@ -809,7 +663,7 @@ void KonqBaseListViewWidget::slotReturnPressed( QListViewItem *_item )
   }
 }*/
 
-void KonqBaseListViewWidget::slotRightButtonPressed( QListViewItem *_item, const QPoint &_global, int )
+void KonqBaseListViewWidget::slotRightButtonPressed( QListViewItem *, const QPoint &_global, int )
 {
   popupMenu( _global );
 }
@@ -835,31 +689,33 @@ void KonqBaseListViewWidget::popupMenu( const QPoint& _global )
 void KonqBaseListViewWidget::createColumns()
 {
    //this column is always required, so add it
-   if (columns()<1) addColumn(i18n("Name"));
+   if (columns()<=m_filenameColumn) addColumn(i18n("Name"));
+   setSorting(m_filenameColumn,TRUE);
 
    //remove all but the first column
    for (int i=columns()-1; i>0; i--)
       removeColumn(i);
    //now add the checked columns
-   //start with 1, since we have the name column always
-   int currentColumn(1);
-   for (int i=0; i<confColumns.count(); i++)
+   int currentColumn(m_filenameColumn+1);
+   for (int i=0; i<NumberOfAtoms; i++)
    {
-      if (confColumns.at(i)->displayThisOne)
+      if ((confColumns[i].displayThisOne) && (confColumns[i].displayInColumn==currentColumn))
       {
-         addColumn(i18n(confColumns.at(i)->name ));
-         if (confColumns.at(i)->udsId==KIO::UDS_SIZE) setColumnAlignment(currentColumn,AlignRight);
-         confColumns.at(i)->displayInColumn=currentColumn;
+         addColumn(i18n(confColumns[i].name ));
+         if (sortedByColumn==confColumns[i].desktopFileName)
+            setSorting(currentColumn,ascending);
+         if (confColumns[i].udsId==KIO::UDS_SIZE) setColumnAlignment(currentColumn,AlignRight);
+         i=-1;
          currentColumn++;
-      };
-   };
-};
+      }
+   }
+}
 
 void KonqBaseListViewWidget::updateListContents()
 {
    for (KonqBaseListViewWidget::iterator it = begin(); it != end(); it++ )
       it->updateContents();
-};
+}
 
 bool KonqBaseListViewWidget::openURL( const KURL &url )
 {
@@ -867,7 +723,7 @@ bool KonqBaseListViewWidget::openURL( const KURL &url )
    if ( !m_dirLister )
    {
       // Create the directory lister
-      m_dirLister = new KonqDirLister(true);
+      m_dirLister = new KonqDirLister(m_showIcons==FALSE);
 
       QObject::connect( m_dirLister, SIGNAL( started( const QString & ) ),
                         this, SLOT( slotStarted( const QString & ) ) );
@@ -878,6 +734,10 @@ bool KonqBaseListViewWidget::openURL( const KURL &url )
                         this, SLOT( slotNewItems( const KFileItemList & ) ) );
       QObject::connect( m_dirLister, SIGNAL( deleteItem( KFileItem * ) ),
                         this, SLOT( slotDeleteItem( KFileItem * ) ) );
+      QObject::connect( m_dirLister, SIGNAL( refreshItems( const KFileItemList & ) ),
+                        this, SLOT( slotRefreshItems( const KFileItemList & ) ) );
+      QObject::connect( m_dirLister, SIGNAL( redirection( const KURL & ) ),
+                        this, SLOT( slotRedirection( const KURL & ) ) );
    }
 
    // The first time or new protocol ? So create the columns first
@@ -887,16 +747,32 @@ bool KonqBaseListViewWidget::openURL( const KURL &url )
    {
       readProtocolConfig( url.protocol() );
       createColumns();
-   };
+   }
    m_bTopLevelComplete = false;
 
    m_url=url;
 
-   m_pProps->enterDir( url );
+   //settings changed ?
+   if (m_pProps->enterDir( url ))
+   {
+      switch (m_pProps->iconSize())
+      {
+      case KIcon::SizeSmall:
+         m_pBrowserView->m_paSmallIcons->setChecked(TRUE);
+         break;
+      case KIcon::SizeMedium:
+         m_pBrowserView->m_paMediumIcons->setChecked(TRUE);
+         break;
+      case KIcon::SizeLarge:
+         m_pBrowserView->m_paLargeIcons->setChecked(TRUE);
+         break;
+      default:
+         break;
+      };
+   };
    // TODO: setChecked on the actions, depending on isShowing...
 
    // Start the directory lister !
-   //m_dirLister->openURL( url, m_pProps->m_bShowDot, false /* new url */ );
    m_dirLister->openURL( url, m_pProps->isShowingDotFiles(), false /* new url */ );
 
    //  setCaptionFromURL( m_sURL );
@@ -955,6 +831,26 @@ void KonqBaseListViewWidget::slotDeleteItem( KFileItem * _fileitem )
     }
 }
 
+void KonqBaseListViewWidget::slotRefreshItems( const KFileItemList & entries )
+{
+   QListIterator<KFileItem> kit ( entries );
+   for( ; kit.current(); ++kit )
+   {
+       iterator it = begin();
+       for( ; it != end(); ++it )
+           if ( (*it).item() == kit.current() )
+           {
+               it->updateContents();
+               break;
+           }
+   }
+}
+
+void KonqBaseListViewWidget::slotRedirection( const KURL & url )
+{
+    emit m_pBrowserView->extension()->setLocationBarURL( url.prettyURL() );
+}
+
 KonqBaseListViewWidget::iterator& KonqBaseListViewWidget::iterator::operator++()
 {
   if ( !m_p ) return *this;
@@ -1034,10 +930,4 @@ void KonqBaseListViewWidget::focusInEvent( QFocusEvent* _event )
   KListView::focusInEvent( _event );
 }
 
-void KonqBaseListViewWidget::slotResult( KIO::Job * job )
-{
-    if (job->error())
-        job->showErrorDialog(this);
-}
-
 #include "konq_listviewwidget.moc"
