@@ -20,12 +20,13 @@
  *      -  Should randomize the various hex numbers printed.
  */
 
+#include <config.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <unistd.h>
 #include <string.h>
 #include <math.h>
-#ifndef __FreeBSD__
+#ifdef HAVE_TIME_H
 #include <time.h>
 #endif
 
@@ -52,6 +53,8 @@
 #include "atari.xbm"
 #include "mac.xbm"
 
+#include <config.h>
+
 #ifndef isupper
 # define isupper(c)  ((c) >= 'A' && (c) <= 'Z')
 #endif
@@ -59,8 +62,6 @@
 # define _tolower(c)  ((c) - 'A' + 'a')
 #endif
 
-extern KLocale *glocale;
-
 #define progname "bsod"
 #define MAXDELAY 50
 #define MINDELAY 3
@@ -581,7 +582,7 @@ amiga (Window window, int delay)
   int height;
   unsigned long fg, bg, bg2;
   Pixmap pixmap = 0;
-  int pix_w, pix_h;
+  int pix_w = 0, pix_h = 0;
   KConfig *config = KApplication::kApplication()->config();
 
   const char *string =
@@ -1077,7 +1078,7 @@ macsbug (Window window, int delay)
 void BSODSaver::draw_bsod (Window win)
 {
       int i=-1;
-      i = (random()%8);
+      i = (kapp->random()%8);
       switch (i) {
 	case 0: windows(win, delay, True); break;
 	case 1: windows(win, delay, False); break;
@@ -1144,11 +1145,6 @@ config->sync();
 BSODSaver::BSODSaver (Drawable d)
  : kScreenSaver(d)
 {
-#ifdef __FreeBSD__
-	srandomdev();
-#else
-	srandom(time(0));
-#endif
 	timer = new QTimer(this);
 
     // Clear to background colour when exposed
