@@ -7,7 +7,7 @@
 //
 // layout management added 1998/04/19 by Mario Weilguni <mweilguni@kde.org>
 
-
+#include <config.h>
 #include <stdlib.h>
 #include <time.h>
 #include <qcolor.h>
@@ -30,10 +30,6 @@
 
 #undef Below
 
-// this refers to klock.po. If you want an extra dictionary, 
-// create an extra KLocale instance here.
-//extern KLocale *glocale;
-
 #define MAXLENGTH	256
 
 static kLinesSaver *saver = NULL;
@@ -336,7 +332,6 @@ void kLinesSetup::slotOkPressed(){
 kLinesSaver::kLinesSaver(Drawable drawable):kScreenSaver(drawable){
 	readSettings();
 	lines=new Lines(numLines);
-	srandom((int)time((time_t *)NULL));
 	colorContext=QColor::enterAllocContext();
 	blank();
 	initialiseColor();
@@ -433,10 +428,10 @@ void kLinesSaver::initialiseLines(){
 	if(lines) delete lines;
 	lines=new Lines(numLines);
 	lines->reset();
-	x1=random()%mWidth;
-	y1=random()%mHeight;
-	x2=random()%mWidth;
-	y2=random()%mHeight;
+	x1=rnd.getLong(mWidth);
+	y1=rnd.getLong(mHeight);
+	x2=rnd.getLong(mWidth);
+	y2=rnd.getLong(mHeight);
 	for(i=0; i<numLines; i++){
 		lines->setKoord(x1,y1,x2,y2);
 		lines->next();
