@@ -41,15 +41,13 @@
 #include <qslider.h>
 #include <kglobal.h>
 #include <kconfig.h>
+#include <krandomsequence.h>
 #include "xlock.h"
 #include "../config.h"
 
 #ifdef HAVE_GL
 
 #include <klocale.h>
-// this refers to klock.po. If you want an extra dictionary, 
-// create an extra KLocale instance here.
-//extern KLocale *glocale;
 
 #include <math.h>
 #include <X11/Intrinsic.h>
@@ -809,6 +807,7 @@ initmorph3d(Window window)
 	Display    *display = dsp;
 	morph3dstruct *mp;
 	XWindowAttributes xwa;
+	KRandomSequence rnd;
 
 	(void) XGetWindowAttributes(dsp, window, &xwa);
 
@@ -818,7 +817,7 @@ initmorph3d(Window window)
 			return;
 	}
 	mp = &morph3d[screen];
-	mp->step = NRAND(90);
+	mp->step = rnd.getLong(90);
 
 	if (mp->glx_context) {
 		glXDestroyContext(display, mp->glx_context);
@@ -870,7 +869,7 @@ initmorph3d(Window window)
 	reshape(xwa.width, xwa.height);
 	mp->object = batchcount;
 	if (mp->object <= 0 || mp->object > 5)
-		mp->object = NRAND(5) + 1;
+		mp->object = rnd.getLong(5) + 1;
 	pinit();
 }
 
