@@ -9,7 +9,7 @@
 #include <qtimer.h>
 #include <qlist.h>
 #include <qdialog.h>
-#include <qlined.h>
+#include <qlineedit.h>
 #include "saver.h"
 
 class kMorph3dSaver : public kScreenSaver
