@@ -5,6 +5,7 @@
 // Copyright (c)  Rene Beutler 1998
 //
 
+#include <config.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <math.h>
@@ -24,11 +25,13 @@
 
 #include <kapp.h> 
 #include <kglobal.h>
+#include <kglobalsettings.h>
 #include <kmessagebox.h> 
 #include <kbuttonbox.h>
 #include <klocale.h>
 #include <kconfig.h>
 #include <kstddirs.h>
+#include <krandomsequence.h>
 
 #include "helpers.h"
 #include "science.h"
@@ -51,7 +54,6 @@
 #undef Below
 
 static KScienceSaver *saver = 0;
-extern KLocale *glocale;
 
 struct {
 	char name[32];
@@ -132,7 +134,7 @@ KPrepareDlg::KPrepareDlg( QWidget *parent ) : QWidget( parent )
         frame->setFrameStyle( QFrame::Panel | QFrame::Raised );
         frame->setLineWidth( 2 );
 
-	QFont font = KGlobal::generalFont();
+	QFont font = KGlobalSettings::generalFont();
 	font.setPointSize(18);
 
 	label = new QLabel( QString(), frame );
@@ -257,13 +259,13 @@ void KScienceSaver::myAssert( bool term, const char *eMsg )
 
 void KScienceSaver::initialize()
 {
+	KRandomSequence rnd;
 	initLens();
 	signed int ws = (signed int) (mWidth -  diam);
 	signed int hs = (signed int) (mHeight - diam);
 
-	srandom( (int) time( (time_t *) NULL ) );
-	x = (double) ( (ws > 0) ? (random() % ws ) : 0 );
-	y = (double) ( (hs > 0) ? (random() % hs ) : 0 );
+	x = (ws > 0) ? (rnd.getDouble() * ws ) : 0.0;
+	y = (hs > 0) ? (rnd.getDouble() * hs ) : 0.0;
 
 	xcoord = (int) x;
 	ycoord = (int) y;		
