@@ -5,7 +5,7 @@
 #include <qtimer.h>
 #include <qlist.h>
 #include <qdialog.h>
-#include <qlined.h>
+#include <qlineedit.h>
 #include "saver.h"
 
 class kSpaceSaver : public kScreenSaver
