@@ -5,6 +5,7 @@ Copyright (C) 1999, 2000 Matthias Ettrich <ettrich@kde.org>
 ******************************************************************/
 #include <klocale.h>
 #include <kapp.h>
+#include <kdebug.h>
 #include <dcopclient.h>
 #include <qapplication.h>
 #include <qcursor.h>
@@ -323,10 +324,11 @@ bool WindowWrapper::x11Event( XEvent * e)
   Creates a client on workspace \a ws for window \a w.
  */
 Client::Client( Workspace *ws, WId w, QWidget *parent, const char *name, WFlags f )
-    : QWidget( parent, name, f | WStyle_Customize | WStyle_NoBorder ),
-      avoid_(false),
-      anchorEdge_(AnchorNorth)
+    : QWidget( parent, name, f | WStyle_Customize | WStyle_NoBorder )
 {
+    avoid = false;
+    anchor = AnchorNorth;
+
     wspace = ws;
     win = w;
     XWindowAttributes attr;
@@ -349,6 +351,7 @@ Client::Client( Workspace *ws, WId w, QWidget *parent, const char *name, WFlags
     active = FALSE;
     shaded = FALSE;
     transient_for = None;
+    passive_focus = FALSE;
     is_shape = FALSE;
     is_sticky = FALSE;
     may_move = TRUE;
@@ -365,6 +368,33 @@ Client::Client( Workspace *ws, WId w, QWidget *parent, const char *name, WFlags
 	setSticky( TRUE );
 
     updateAvoidPolicy();
+
+    // should we open this window on a certain desktop?
+    Atom type;
+    int format;
+    unsigned long nitems, bytes;
+    long *data = 0L;
+
+    int status=XGetWindowProperty(qt_xdisplay(), w, atoms->kwin_initial_desktop, 0, 1L, 
+        False, atoms->kwin_initial_desktop, &type, &format, &nitems, &bytes, 
+        (unsigned char **)&data);
+
+    if (status==Success) {
+        if (nitems>0)
+            desk=data[0]; // window had the initial desktop property!
+
+        XFree((char *)data);
+    }
+
+    // if this window is transient, ensure that it is opened on the
+    // same window as its parent.  this is necessary when an application
+    // starts up on a different desktop than is currently displayed
+    //
+    // are there any other cases we need to check?
+    //
+    if (transient_for != None)
+        desk=KWM::desktop(transient_for);
+
 }
 
 /*!
@@ -373,6 +403,8 @@ Client::Client( Workspace *ws, WId w, QWidget *parent, const char *name, WFlags
 Client::~Client()
 {
     releaseWindow();
+    if (workspace()->activeClient() == this)
+       workspace()->setEnableFocusChange(true); // Safety
 }
 
 
@@ -383,7 +415,8 @@ Client::~Client()
 void Client::manage( bool isMapped )
 {
 
-    layout()->setResizeMode( QLayout::Minimum );
+    if (layout())
+      layout()->setResizeMode( QLayout::Minimum );
     QRect geom( original_geometry );
     bool placementDone = FALSE;
 
@@ -414,9 +447,9 @@ void Client::manage( bool isMapped )
 
     windowWrapper()->resize( geom.size() );
     // the clever activate() trick is necessary
-    layout()->activate();
+    activateLayout();
     resize ( sizeForWindowSize( geom.size() ) );
-    layout()->activate();
+    activateLayout();
 
     move( geom.x(), geom.y() );
     gravitate( FALSE );
@@ -444,10 +477,13 @@ void Client::manage( bool isMapped )
 	    XFree(hints);
     }
 
-    // initial desktop placement
+    // initial desktop placement - note we don't clobber desk if it is
+    // set to some value, in case the initial desktop code in the
+    // constructor has already set a value for us
     if ( info ) {
 	desk = info->desktop;
-    } else {
+    } else if (desk<=0) {
+        
 	// assume window wants to be visible on the current desktop
 	desk =  workspace()->currentDesktop();
 
@@ -455,9 +491,9 @@ void Client::manage( bool isMapped )
 	desk = KWM::desktop( win );
     }
 
+    // initial desktop code needs this now 
     KWM::moveToDesktop( win, desk ); // KDE 1.x compatibility
 
-
     setMappingState( state );
     if ( state == NormalState && isOnDesktop( workspace()->currentDesktop() ) ) {
 	Events::raise( isTransient() ? Events::TransNew : Events::New );
@@ -599,7 +635,9 @@ bool Client::mapRequest( XMapRequestEvent& /* e */  )
 	show();
 	break;
     case NormalState:
-	show(); // for safety
+	// only show window if we're on current desktop
+	if (desk == KWM::currentDesktop())
+		show(); // for safety
 	break;
     }
 
@@ -882,20 +920,40 @@ QSize Client::sizeForWindowSize( const QSize& wsize, bool ignore_height) const
  */
 void Client::mousePressEvent( QMouseEvent * e)
 {
-    if ( e->button() == LeftButton ) {
-	if ( options->focusPolicyIsReasonable() )
-	    workspace()->requestFocus( this );
-	workspace()->raiseClient( this );
-	mouseMoveEvent( e );
-	buttonDown = TRUE;
-	moveOffset = e->pos();
-	invertedMoveOffset = rect().bottomRight() - e->pos();
+    if (buttonDown) return;
+    if (e->state() & AltButton)
+    {
+	Options::MouseCommand com = Options::MouseNothing;
+	if ( e->button() == LeftButton ) {
+	    com = options->commandAll1();
+	}
+	else if (e->button() == MidButton) {
+	    com = options->commandAll2();
+	}
+	else if (e->button() == RightButton) {
+	    com = options->commandAll3();
+	}
+	else {
+	    return;
+	}
+	performMouseCommand( com, e->globalPos());
     }
-    else if ( !buttonDown && e->button() == MidButton ) {
-        workspace()->lowerClient( this );
-    }
-    else if ( !buttonDown && e->button() == RightButton ) {
-	workspace()->clientPopup( this ) ->popup( e->globalPos() );
+    else {
+        if ( e->button() == LeftButton ) {
+	    if ( options->focusPolicyIsReasonable() )
+	        workspace()->requestFocus( this );
+	    workspace()->raiseClient( this );
+	    mouseMoveEvent( e );
+	    buttonDown = TRUE;
+	    moveOffset = e->pos();
+	    invertedMoveOffset = rect().bottomRight() - e->pos();
+        }
+        else if ( e->button() == MidButton ) {
+            workspace()->lowerClient( this );
+        }
+        else if ( e->button() == RightButton ) {
+	    workspace()->clientPopup( this ) ->popup( e->globalPos() );
+        }
     }
 }
 
@@ -914,6 +972,7 @@ void Client::mouseReleaseEvent( QMouseEvent * e)
 	    setGeometry( geom );
 	    Events::raise( isResize() ? Events::ResizeEnd : Events::MoveEnd );
 	    moveResizeMode = FALSE;
+            workspace()->setEnableFocusChange(true);
 	    releaseMouse();
 	    releaseKeyboard();
 	}
@@ -937,6 +996,7 @@ void Client::mouseMoveEvent( QMouseEvent * e)
     if ( !buttonDown ) {
 	mode = mousePosition( e->pos() );
 	setMouseCursor( mode );
+        geom = geometry();
 	return;
     }
 
@@ -945,8 +1005,9 @@ void Client::mouseMoveEvent( QMouseEvent * e)
     if ( !moveResizeMode )
     {
 	QPoint p( e->pos() - moveOffset );
-	if ( (QABS( p.x()) >= 4) || (QABS( p.y() ) >= 4 )) {
+	if (p.manhattanLength() >= 6) {
 	    moveResizeMode = TRUE;
+            workspace()->setEnableFocusChange(false);
 	    Events::raise( isResize() ? Events::ResizeStart : Events::MoveStart );
 	    grabMouse( cursor() ); // to keep the right cursor
 	    if ( ( isMove() && options->moveMode != Options::Opaque )
@@ -1005,11 +1066,24 @@ void Client::mouseMoveEvent( QMouseEvent * e)
 	geom.moveTopLeft( pp );
 	break;
     default:
+//fprintf(stderr, "KWin::mouseMoveEvent with mode = %d\n", mode); 
 	break;
     }
 
+    QRect desktopArea = workspace()->clientArea();
+    int marge = 5;
+
     if ( isResize() && geom.size() != size() ) {
-	geom.setSize( adjustedSize( geom.size() ) );
+        if (geom.bottom() < desktopArea.top()+marge)
+            geom.setBottom(desktopArea.top()+marge);
+        if (geom.top() > desktopArea.bottom()-marge)
+            geom.setTop(desktopArea.bottom()-marge);
+        if (geom.right() < desktopArea.left()+marge)
+            geom.setRight(desktopArea.left()+marge);
+        if (geom.left() > desktopArea.right()-marge)
+            geom.setLeft(desktopArea.right()-marge);
+
+        geom.setSize( adjustedSize( geom.size() ) );
 	if  (options->resizeMode == Options::Opaque ) {
 	    setGeometry( geom );
 	} else if ( options->resizeMode == Options::Transparent ) {
@@ -1019,15 +1093,23 @@ void Client::mouseMoveEvent( QMouseEvent * e)
     }
     else if ( isMove() && geom.topLeft() != geometry().topLeft() ) {
 	geom.moveTopLeft( workspace()->adjustClientPosition( this, geom.topLeft() ) );
-	switch ( options->moveMode ) {
-	case Options::Opaque:
-	    move( geom.topLeft() );
-	    break;
-	case Options::Transparent:
-	    clearbound();
-	    drawbound( geom );
-	    break;
-	}
+        if (geom.bottom() < desktopArea.top()+marge)
+            geom.moveBottomLeft( QPoint( geom.left(), desktopArea.top()+marge));
+        if (geom.top() > desktopArea.bottom()-marge)
+            geom.moveTopLeft( QPoint( geom.left(), desktopArea.bottom()-marge));
+        if (geom.right() < desktopArea.left()+marge)
+            geom.moveTopRight( QPoint( desktopArea.left()+marge, geom.top()));
+        if (geom.left() > desktopArea.right()-marge)
+            geom.moveTopLeft( QPoint( desktopArea.right()-marge, geom.top()));
+        switch ( options->moveMode ) {
+        case Options::Opaque:
+            move( geom.topLeft() );
+            break;
+        case Options::Transparent:
+            clearbound();
+            drawbound( geom );
+            break;
+        }
     }
 
     QApplication::syncX(); // process our own configure events synchronously.
@@ -1192,6 +1274,9 @@ void Client::invalidateWindow()
 
 void Client::iconify()
 {
+    if (!mayMove())
+       return;
+
     if ( isShade() )
 	setShade( FALSE );
     if ( workspace()->iconifyMeansWithdraw( this ) ) {
@@ -1221,14 +1306,27 @@ void Client::closeWindow()
     }
 }
 
+void Client::killWindow()
+{
+    // not sure if we need an Events::Kill or not.. until then, use
+    // Events::Close
+    Events::raise( Events::Close );
+
+    // always kill this client at the server
+    XKillClient(qt_xdisplay(), win );
+    workspace()->destroyClient( this );
+}
+
 void Client::maximize( MaximizeMode m)
 {
+    if (!mayMove())
+       return;
+
     QRect clientArea = workspace()->clientArea();
 
     if (isShade())
 	setShade( FALSE );
 
-
     if (geom_restore.isNull()) {
 
 	Events::raise( Events::Maximize );
@@ -1273,6 +1371,9 @@ void Client::maximize( MaximizeMode m)
 
 void Client::toggleSticky()
 {
+    if (!mayMove())
+       return;
+
     setSticky( !isSticky() );
 }
 
@@ -1365,7 +1466,9 @@ void Client::gravitate( bool invert )
 bool Client::x11Event( XEvent * e)
 {
     if ( e->type == EnterNotify ) {
-	if ( options->focusPolicy != Options::ClickToFocus )
+	if (( options->focusPolicy != Options::ClickToFocus ) &&
+	    (( options->focusPolicy != Options::FocusFollowsMouse) ||
+               !passiveFocus()))
 	    workspace()->requestFocus( this );
 	return TRUE;
     }
@@ -1458,6 +1561,9 @@ bool Client::isShade() const
 
 void Client::setShade( bool s )
 {
+    if (!mayMove())
+       return;
+
     if ( shaded == s )
 	return;
 
@@ -1500,7 +1606,7 @@ void Client::setShade( bool s )
 	clearWFlags( WNorthWestGravity );
 	resize ( s );
 	windowWrapper()->show();
-	layout()->activate();
+	activateLayout();
 	repaint();
 	if ( isActive() )
 	    workspace()->requestFocus( this );
@@ -1709,6 +1815,7 @@ bool Client::performMouseCommand( Options::MouseCommand command, QPoint globalPo
            break;
 	mode = Center;
 	moveResizeMode = TRUE;
+        workspace()->setEnableFocusChange(false);
 	buttonDown = TRUE;
 	moveOffset = mapFromGlobal( globalPos );
 	invertedMoveOffset = rect().bottomRight() - moveOffset;
@@ -1721,6 +1828,7 @@ bool Client::performMouseCommand( Options::MouseCommand command, QPoint globalPo
         if (!mayMove())
            break;
 	moveResizeMode = TRUE;
+        workspace()->setEnableFocusChange(false);
 	buttonDown = TRUE;
 	moveOffset = mapFromGlobal( globalPos );
 	if ( moveOffset.x() < width()/2) {
@@ -1854,6 +1962,7 @@ void Client::keyPressEvent( QKeyEvent * e )
 	    XUngrabServer( qt_xdisplay() );
 	setGeometry( geom );
 	moveResizeMode = FALSE;
+        workspace()->setEnableFocusChange(true);
 	releaseMouse();
 	releaseKeyboard();
 	buttonDown = FALSE;
@@ -1901,66 +2010,62 @@ QCString Client::sessionId()
     return result;
 }
 
+void Client::activateLayout()
+{
+    if ( layout() )
+	layout()->activate();
+}
+
 void Client::updateAvoidPolicy()
 {
-//  qDebug("kwin: Client::updateAvoidPolicy() - win id == %x", (int)win);
+    avoid = false;
+
     // Find out if we should be avoided.
-
-  // If this atom isn't set, set it now.
     XTextProperty avoidProp;
+    if (  XGetTextProperty(
+	 qt_xdisplay(),
+	 win,
+	 &avoidProp,
+	 atoms->net_avoid_spec
+	 ) == 0 )
+	return;
 
-    Status avoidStatus = XGetTextProperty(qt_xdisplay(), win, &avoidProp, atoms->net_avoid_spec );
-
-    if (avoidStatus) {
-
-	//    qDebug("XGetTextProperty worked for atom _NET_AVOID_SPEC");
-
-	char ** avoidList;
-	int avoidListCount;
-
-	Status convertStatus = XTextPropertyToStringList(&avoidProp, &avoidList, &avoidListCount);
-
-	if (convertStatus) {
-
-	    //      qDebug("XTextPropertyToStringList succeded");
-
-	    avoid_ = true;
-
-	    if (avoidListCount != 1) {
-		qDebug( "kwin: Client::updateAvoidPolicy(): "
-			"Extra values in avoidance list. Ignoring.");
-	    }
-
-	    char * itemZero = avoidList[0];
-
-	    //      qDebug("Anchoring to border %s", itemZero);
-
-	    switch (*itemZero) {
-
-	    case 'N':
-		anchorEdge_ = AnchorNorth;
-		break;
-	    case 'S':
-		anchorEdge_ = AnchorSouth;
-		break;
-	    case 'E':
-		anchorEdge_ = AnchorEast;
-		break;
-	    case 'W':
-		anchorEdge_ = AnchorWest;
-		break;
-	    default:
-		avoid_ = false;
-		break;
-	    }
-
-	    XFreeStringList(avoidList);
-
-	} else
-	    qDebug( "kwin: Client::updateAvoidPolicy(): "
-		    "XTextPropertyToStringList failed");
+    char ** avoidList;
+    int avoidListCount;
 
+    if ( XTextPropertyToStringList( 
+	  &avoidProp, &avoidList, &avoidListCount) == 0 ) {
+	kdDebug() << "kwin: Client::updateAvoidPolicy: " << endl;
+	return;
     }
+
+    // Must be one value only in string list.
+    if (avoidListCount != 1) {
+	kdDebug() << "kwin: Client::updateAvoidPolicy(): " << endl;
+	return;
+    }
+
+    // Which border is the client anchored to ?
+    avoid = true;
+    switch (avoidList[0][0]) {
+    case 'N': 
+	anchor = AnchorNorth;
+	break;
+    case 'S': 
+	anchor = AnchorSouth;
+	break;
+    case 'E': 
+	anchor = AnchorEast;	
+	break;
+    case 'W': 
+	anchor = AnchorWest;	
+	break;
+    default:		
+	avoid = false;
+	break;
+    }
+
+    XFreeStringList(avoidList);
 }
 
 NoBorderClient::NoBorderClient( Workspace *ws, WId w, QWidget *parent, const char *name )
