@@ -39,13 +39,15 @@ class TitleBar : public QWidget
 {
   public:
 
-    TitleBar(QWidget * parent, Manager * client);
+    TitleBar(Manager * client);
     virtual ~TitleBar();
 
     void updateDisplay();
     void updateText();
     void updateMaximise(bool);
 
+    void setActive(bool);
+
   protected:
 
     void resizeEvent(QResizeEvent *);
@@ -59,8 +61,6 @@ class TitleBar : public QWidget
 
     IconifyButton * iconify_;
     MaximiseButton * maximise_;
-
-    Manager * client_;
 };
 
 } // End namespace
