@@ -5,6 +5,7 @@ Copyright (C) 1999, 2000 Matthias Ettrich <ettrich@kde.org>
 ******************************************************************/
 #include <kconfig.h>
 #include <kglobal.h>
+#include <kglobalsettings.h>
 #include <kglobalaccel.h>
 #include <klocale.h>
 #include <stdlib.h>
@@ -12,6 +13,7 @@ Copyright (C) 1999, 2000 Matthias Ettrich <ettrich@kde.org>
 #include <qdatastream.h>
 #include <kapp.h>
 #include <dcopclient.h>
+#include <kdebug.h>
 
 #include "workspace.h"
 #include "client.h"
@@ -28,6 +30,7 @@ Copyright (C) 1999, 2000 Matthias Ettrich <ettrich@kde.org>
 #include <X11/keysym.h>
 #include <X11/keysymdef.h>
 #include <X11/extensions/shape.h>
+#include <X11/cursorfont.h>
 
 const int XIconicState = IconicState;
 #undef IconicState
@@ -124,18 +127,21 @@ Client* Workspace::clientFactory( Workspace *ws, WId w )
 	c->setSticky( TRUE );
 	c->setMayMove( FALSE );
 	ws->setDesktopClient( c );
+        c->setPassiveFocus( TRUE );
 	return c;
     }
-    if ( s == "Kicker" ) {
+    if ( s.lower().right(6) == "kicker" ) {
 	Client * c = new NoBorderClient( ws, w);
 	c->setSticky( TRUE );
 	c->setMayMove( FALSE );
+        c->setPassiveFocus( TRUE );
 	return c;
     }
     if ( s == "MAC MENU [menu]" ) {
 	Client * c = new NoBorderClient( ws, w);
 	c->setSticky( TRUE );
 	c->setMayMove( FALSE );
+        c->setPassiveFocus( TRUE );
 	return c;
     }
     if ( ( s.right(6) == "[menu]" ) || ( s.right(7) == "[tools]" ) ) {
@@ -163,6 +169,7 @@ Workspace::Workspace( bool restore )
     control_grab      (false),
     tab_grab          (false),
     mouse_emulation   (false),
+    focus_change      (true),
     tab_box           (0),
     popup             (0),
     desk_popup        (0),
@@ -263,7 +270,6 @@ void Workspace::init()
 		setDesktopClient( c );
 	    if ( root != qt_xrootwin() ) {
 		// TODO may use QWidget:.create
-		qDebug(" create a mdi client");
 		XReparentWindow( qt_xdisplay(), c->winId(), root, 0, 0 );
 		c->move(0,0);
 	    }
@@ -617,7 +623,7 @@ bool Workspace::keyPress(XKeyEvent key)
 		tab_box->reset();
 	    }
 	    tab_box->nextPrev( (km & ShiftMask) == 0 );
-	    tab_box->show();
+	    tab_box->delayedShow();
 	}
     }
 
@@ -648,7 +654,7 @@ bool Workspace::keyPress(XKeyEvent key)
 		tab_box->reset();
 	    }
 	    tab_box->nextPrev( (km & ShiftMask) == 0 );
-	    tab_box->show();
+	    tab_box->delayedShow();
 	}
     }
 
@@ -931,6 +937,8 @@ bool Workspace::hasCaption( const QString& caption )
  */
 void Workspace::requestFocus( Client* c)
 {
+    if (!focusChangeEnabled())
+        return;
     //TODO will be different for non-root clients. (subclassing?)
     if ( !c ) {
 	focusToNull();
@@ -962,21 +970,25 @@ void Workspace::requestFocus( Client* c)
  */
 void Workspace::clientHidden( Client* c )
 {
-    if ( c == active_client || ( !active_client && c == should_get_focus ) ) {
+    if ( c == active_client || ( !active_client && c == should_get_focus ) )
+    {
 	active_client = 0;
 	should_get_focus = 0;
-	if ( clients.contains( c ) ) {
-	    focus_chain.remove( c );
-	    focus_chain.prepend( c );
-	}
-	if ( !block_focus && options->focusPolicyIsReasonable() ) {
-	    for ( ClientList::ConstIterator it = focus_chain.fromLast(); it != focus_chain.begin(); --it) {
-		if ( (*it)->isVisible() ) {
-		    requestFocus( *it );
-		    break;
-		}
-	    }
-	}
+        if (!block_focus &&
+            options->focusPolicyIsReasonable() &&
+	    !focus_chain.isEmpty()
+	   )
+	{
+	    for (ClientList::ConstIterator it = focus_chain.fromLast();
+	         it != focus_chain.end();
+	         --it)
+	    {
+	        if ((*it)->isVisible()) {
+	            requestFocus(*it);
+	            break;
+	        }
+ 	    }
+        }	
     }
 }
 
@@ -987,16 +999,16 @@ QPopupMenu* Workspace::clientPopup( Client* c )
     if ( !popup ) {
 	popup = new QPopupMenu;
 	popup->setCheckable( TRUE );
-	popup->setFont(KGlobal::menuFont());
+	popup->setFont(KGlobalSettings::menuFont());
 	connect( popup, SIGNAL( aboutToShow() ), this, SLOT( clientPopupAboutToShow() ) );
 	connect( popup, SIGNAL( activated(int) ), this, SLOT( clientPopupActivated(int) ) );
 
 	PluginMenu *deco = new PluginMenu(&mgr, popup);
-	deco->setFont(KGlobal::menuFont());
+	deco->setFont(KGlobalSettings::menuFont());
 
 	desk_popup = new QPopupMenu( popup );
 	desk_popup->setCheckable( TRUE );
-	desk_popup->setFont(KGlobal::menuFont());
+	desk_popup->setFont(KGlobalSettings::menuFont());
 	connect( desk_popup, SIGNAL( activated(int) ), this, SLOT( sendToDesktop(int) ) );
 	connect( desk_popup, SIGNAL( aboutToShow() ), this, SLOT( desktopPopupAboutToShow() ) );
 
@@ -1410,7 +1422,7 @@ void Workspace::raiseClient( Client* c )
     if ( !c )
 	return;
     ClientList saveset;
-    
+
     if ( c == desktop_client ) {
 	saveset.clear();
 	saveset.append( c );
@@ -1526,29 +1538,29 @@ void Workspace::setDesktopClient( Client* c)
   propages the new desktop to the world
  */
 void Workspace::setCurrentDesktop( int new_desktop ){
-    if (new_desktop == current_desktop || new_desktop < 1 || new_desktop > number_of_desktops )
+    if (new_desktop < 1 || new_desktop > number_of_desktops )
 	return;
 
     active_client = 0;
     block_focus = TRUE;
 
-    /*
-       optimized Desktop switching: unmapping done from back to front
-       mapping done from front to back => less exposure events
-    */
+    if (new_desktop != current_desktop) {
+       /*
+          optimized Desktop switching: unmapping done from back to front
+          mapping done from front to back => less exposure events
+        */
 
-    for ( ClientList::ConstIterator it = stacking_order.begin(); it != stacking_order.end(); ++it) {
-	if ( (*it)->isVisible() && !(*it)->isOnDesktop( new_desktop ) ) {
-	    (*it)->hide();
-	}
+       for ( ClientList::ConstIterator it = stacking_order.begin(); it != stacking_order.end(); ++it) {
+          if ( (*it)->isVisible() && !(*it)->isOnDesktop( new_desktop ) ) {
+             (*it)->hide();
+	  }
+       }
+       for ( ClientList::ConstIterator it = stacking_order.fromLast(); it != stacking_order.end(); --it) {
+          if ( (*it)->isOnDesktop( new_desktop ) && !(*it)->isIconified() ) {
+             (*it)->show();
+          }
+       }
     }
-    for ( ClientList::ConstIterator it = stacking_order.fromLast(); it != stacking_order.end(); --it) {
-	if ( (*it)->isOnDesktop( new_desktop ) && !(*it)->isIconified() ) {
-	    (*it)->show();
-	}
-    }
-
-
     current_desktop = new_desktop;
 
     XChangeProperty(qt_xdisplay(), qt_xrootwin(),
@@ -1558,25 +1570,35 @@ void Workspace::setCurrentDesktop( int new_desktop ){
 
     // restore the focus on this desktop
     block_focus = FALSE;
-    Client* c = active_client?active_client:previousClient(0);
-    Client* stop = c;
-    while ( c && !c->isVisible() ) {
-	c = previousClient( c );
-	if ( c == stop )
-	    break;
+    Client* c = 0;
+
+    if ( options->focusPolicyIsReasonable()) {
+       if (options->focusPolicy == Options::FocusFollowsMouse) {
+          // Search in focus chain
+          for( ClientList::ConstIterator it = focus_chain.fromLast(); it != focus_chain.end(); --it) {
+             if ( (*it)->isVisible() && !(*it)->passiveFocus() ) {
+	        c = *it;
+                break;	
+	     }
+          }
+       }
+   
+
+       if (!c) {
+          // Search top-most visible window
+          for ( ClientList::ConstIterator it = stacking_order.fromLast(); it != stacking_order.end(); --it) {
+	     if ( (*it)->isVisible() && !(*it)->passiveFocus() ) {
+	        c = *it;
+	        break;
+	     }
+          }
+       }
     }
 
-    if ( !c || !c->isVisible() ) {
-	// there's no suitable client in the focus chain. Try to find any other client then.
-	for ( ClientList::ConstIterator it = stacking_order.begin(); it != stacking_order.end(); ++it) {
-	    if ( (*it)->isVisible() ) {
-		c = *it;
-		break;
-	    }
-	}
-    }
-    if ( c && c->isVisible() )
-	requestFocus( c );
+    if ( c )
+       requestFocus( c );
+    else
+       focusToNull();
 
     QApplication::syncX();
     KWM::switchToDesktop( current_desktop ); // ### compatibility
@@ -1752,6 +1774,10 @@ void Workspace::createKeybindings(){
     keys->connectItem( "Window resize", this, SLOT( slotWindowResize() ) );
 
     keys->connectItem( "Mouse emulation", this, SLOT( slotMouseEmulation() ) );
+
+    keys->connectItem( "Logout", this, SLOT( slotLogout() ) );
+
+    keys->connectItem( "Kill Window", this, SLOT( slotKillWindow() ) );
     keys->readSettings();
 }
 
@@ -1840,6 +1866,90 @@ void Workspace::slotMouseEmulation()
     }
 }
 
+void Workspace::slotLogout()
+{
+  kapp->requestShutDown();
+}
+
+void Workspace::slotKillWindow()
+{
+    static Cursor kill_cursor = 0;
+    if (!kill_cursor)
+        kill_cursor = XCreateFontCursor(qt_xdisplay(), XC_pirate);
+
+    if (XGrabPointer(qt_xdisplay(), qt_xrootwin(), False,
+                     ButtonPressMask | ButtonReleaseMask |
+                     PointerMotionMask |
+                     EnterWindowMask | LeaveWindowMask,
+                     GrabModeAsync, GrabModeAsync, None,
+                     kill_cursor, CurrentTime) == GrabSuccess)
+    {
+        XGrabKeyboard(qt_xdisplay(), qt_xrootwin(), False,
+                      GrabModeAsync, GrabModeAsync, CurrentTime);
+
+        XEvent ev;
+        int return_pressed  = 0;
+        int escape_pressed  = 0;
+        int button_released = 0;
+
+        XGrabServer(qt_xdisplay());
+
+        while (!return_pressed && !escape_pressed && !button_released)
+        {
+            XMaskEvent(qt_xdisplay(), KeyPressMask | ButtonPressMask |
+                       ButtonReleaseMask | PointerMotionMask, &ev);
+
+            if (ev.type == KeyPress)
+            {
+                int kc = XKeycodeToKeysym(qt_xdisplay(), ev.xkey.keycode, 0);
+                int mx = 0;
+                int my = 0;
+                return_pressed = (kc == XK_Return) || (kc == XK_space);
+                escape_pressed = (kc == XK_Escape);
+                if (kc == XK_Left)  mx = -10;
+                if (kc == XK_Right) mx = 10;
+                if (kc == XK_Up)    my = -10;
+                if (kc == XK_Down)  my = 10;
+                if (ev.xkey.state & ControlMask)
+                {
+                    mx /= 10;
+                    my /= 10;
+                }
+                QCursor::setPos(QCursor::pos()+QPoint(mx, my));
+            }
+
+            if (ev.type == ButtonRelease)
+            {
+                button_released = (ev.xbutton.button == Button1);
+                killWindowAtPosition(ev.xbutton.x_root, ev.xbutton.y_root);
+            }
+            continue;
+        }
+        if (return_pressed)
+            killWindowAtPosition(QCursor::pos().x(), QCursor::pos().y());
+
+        XUngrabServer(qt_xdisplay());
+
+        XUngrabKeyboard(qt_xdisplay(), CurrentTime);
+        XUngrabPointer(qt_xdisplay(), CurrentTime);
+    }
+}
+
+void Workspace::killWindowAtPosition(int x, int y)
+{
+    ClientList::ConstIterator it(stacking_order.fromLast());
+    for ( ; it != stacking_order.end(); --it)
+    {
+        Client *client = (*it);
+        if ( client->frameGeometry().contains(QPoint(x, y)) &&
+             client->isOnDesktop( currentDesktop() ) &&
+             !client->isIconified() )
+        {
+            client->killWindow();
+            return;
+        }
+    }
+}
 
 /*!
   Adjusts the desktop popup to the current values and the location of
@@ -1916,6 +2026,9 @@ void Workspace::slotWindowOperations()
 {
     if ( !active_client )
 	return;
+    if ( !active_client->mayMove())
+        return;
+
     QPopupMenu* p = clientPopup( active_client );
     p->popup( active_client->mapToGlobal( active_client->windowWrapper()->geometry().topLeft() ) );
 }
@@ -1962,9 +2075,9 @@ QPoint Workspace::adjustClientPosition( Client* c, QPoint pos )
 
     QRect maxRect = clientArea();
     int xmin = maxRect.left();
-    int xmax = maxRect.right();               //desk size
+    int xmax = maxRect.right()+1;               //desk size
     int ymin = maxRect.top();
-    int ymax = maxRect.bottom();
+    int ymax = maxRect.bottom()+1;
     int cx, cy, rx, ry, cw, ch;                 //these don't change
 
     int nx, ny;                         //buffers
@@ -1985,7 +2098,7 @@ QPoint Workspace::adjustClientPosition( Client* c, QPoint pos )
 	nx = xmin;
       }
       if ((QABS(xmax-rx) < snap) && (QABS(xmax-rx) < deltaX)) {
-	deltaX = abs(xmax-rx);
+	deltaX = QABS(xmax-rx);
 	nx = xmax - cw;
       }
 
@@ -2022,7 +2135,7 @@ QPoint Workspace::adjustClientPosition( Client* c, QPoint pos )
 	    }
 	    if ( ( QABS( rx - lx ) < snap )    &&
 		 ( QABS( rx - lx ) < deltaX ) ) {
-	      deltaX = abs(rx - lx);
+	      deltaX = QABS(rx - lx);
 	      nx = lx - cw;
 	    }
 	  }
@@ -2231,74 +2344,54 @@ SessionInfo* Workspace::takeSessionInfo( Client* c )
     return 0;
 }
 
-  void
-Workspace::updateClientArea()
+void Workspace::updateClientArea()
 {
-//  qDebug("KWin: Updating client area");
+    QRect area = QApplication::desktop()->geometry();
+    QRect edgeArea = QApplication::desktop()->geometry();
 
-  clientArea_ = QApplication::desktop()->geometry();
-  edgeClientArea_ = QApplication::desktop()->geometry();
+    for (ClientList::ConstIterator it(clients.begin()); it != clients.end(); ++it) {
+	(*it)->updateAvoidPolicy();
 
-  for (ClientList::ConstIterator it(clients.begin()); it != clients.end(); ++it)
-  {
-    (*it)->updateAvoidPolicy();
+	if ((*it)->isAvoid() ) {
+	    switch (AnchorEdge((*it)->anchorEdge())) {
 
-    if ((*it)->avoid()) {
+	    case AnchorNorth:
+		area.setTop(QMAX(area.top(), (*it)->geometry().bottom()));
+		break;
 
-//      qDebug("Looking at client " + (KWM::title((*it)->winId())));
+	    case AnchorSouth:
+		area.setBottom(QMIN(area.bottom(), (*it)->geometry().top() - 1));
+		break;
 
-      switch (AnchorEdge((*it)->anchorEdge())) {
+	    case AnchorEast:
+		area.setRight(QMIN(area.right(), (*it)->geometry().left() - 1));
+		break;
 
-        case AnchorNorth:
-//          qDebug("KWin: Ignoring at edge N");
-          clientArea_
-            .setTop(QMAX(clientArea_.top(), (*it)->geometry().bottom()));
-          break;
+	    case AnchorWest:
+		area.setLeft(QMAX(area.left(), (*it)->geometry().right()));
+		break;
 
-        case AnchorSouth:
-//          qDebug("KWin: Ignoring at edge S");
-          clientArea_
-            .setBottom(QMIN(clientArea_.bottom(), (*it)->geometry().top() - 1));
-          break;
+	    default:
+		break;
+	    }
+	}
 
-        case AnchorEast:
-//          qDebug("KWin: Ignoring at edge E");
-          clientArea_
-            .setRight(QMIN(clientArea_.right(), (*it)->geometry().left() - 1));
-          break;
-
-        case AnchorWest:
-//          qDebug("KWin: Ignoring at edge W");
-          clientArea_
-            .setLeft(QMAX(clientArea_.left(), (*it)->geometry().right()));
-          break;
-
-        default:
-//          qDebug("KWin: Not ignoring");
-          break;
-      }
+	// FIXME: Using the hackish method...
+	if (KWM::title((*it)->winId()) == "MAC MENU [menu]")
+	    edgeArea.setTop((*it)->geometry().bottom());
+    }
+    
+    edgeClientArea_ = edgeArea;
+    
+    if ( clientArea_ != area ) {
+	// something changed, remember it and notify kdesktop
+	clientArea_ = area;
+	
+	QByteArray data;
+	QDataStream arg( data, IO_WriteOnly );
+	arg << clientArea_;
+	kapp->dcopClient()->send("kdesktop", "KDesktopIface", "clientAreaUpdated(QRect)", data);
     }
-
-    // FIXME: Using the hackish method...
-    if (KWM::title((*it)->winId()) == "MAC MENU [menu]")
-      edgeClientArea_.setTop((*it)->geometry().bottom());
-  }
-
-  DCOPClient * client = kapp->dcopClient();
-
-  if (!client->isAttached())
-    client->attach();
-
-  QByteArray param;
-  QDataStream str(param, IO_WriteOnly);
-
-  str << clientArea_;
-
-  client->send("kdesktop", "KDesktopIface", "clientAreaUpdated(QRect)", param);
-
-// Useful when you want to see whether the client area has been
-// updated correctly...
-//  qDebug("clientArea now == l: %d, r: %d, t: %d, b: %d", clientArea_.left(), clientArea_.top(), clientArea_.right(), clientArea_.bottom());
 }
 
 QRect Workspace::clientArea()
