@@ -1,10 +1,16 @@
 #include <stdio.h>
 #include <string.h>
+
+#ifdef __hpux
+#include <dl.h>
+#else
 #include <dlfcn.h>
+#endif
 
 #define XP_UNIX 1
 #include "sdk/npupp.h"
 
+
 NPNetscapeFuncs gNetscapeFuncs;	/* Netscape Function table */
 NPNetscapeFuncs gExtNetscapeFuncs;	/* table that is passed to the plugin*/
 NPPluginFuncs gPluginFuncs;
@@ -19,13 +25,26 @@ NP_Initialize_t *gNP_Initialize = NULL;
 NP_Shutdown_t *gNP_Shutdown = NULL;
 NP_GetValue_t *gNP_GetValue = NULL;
 
+#ifdef __hpux
+shl_t gLib;
+#else
 void *gLib = 0L;
+#endif
 FILE *ef = 0L;
 
 #define DEB fprintf
 
 static
 void UnloadPlugin() {
+#ifdef __hpux
+   if (gLib) {
+		DEB( ef, "-> UnloadPlugin\n" );
+      shl_unload(gLib);
+		DEB( ef, "<- UnloadPlugin\n" );
+               
+      gLib=0L;
+   }
+#else
 	if ( gLib )	{
 		DEB( ef, "-> UnloadPlugin\n" );
 		dlclose( gLib );
@@ -35,6 +54,7 @@ void UnloadPlugin() {
 		
 		if (ef) fclose( ef );
 	}
+#endif
 }
 
 static
@@ -47,14 +67,25 @@ void LoadPlugin() {
 		setvbuf( ef, NULL, _IONBF, 0 );
 		DEB( ef, "-> LoadPlugin\n" );
 		
+#ifdef __hpux
+                gLib = shl_load("/tmp/plugin.so", BIND_IMMEDIATE, 0L);
+                if (shl_findsym(&gLib, "/tmp/plugin.so", (short) TYPE_PROCEDURE, (void *) &gNP_GetMIMEDescription))
+                   gNP_GetMIMEDescription = NULL;
+                if (shl_findsym(&gLib, "/tmp/plugin.so", (short) TYPE_PROCEDURE, (void *) &gNP_Initialize))
+                   gNP_Initialize = NULL;
+                if (shl_findsym(&gLib, "/tmp/plugin.so", (short) TYPE_PROCEDURE, (void *) &gNP_Shutdown))
+                   gNP_Shutdown = NULL;
+                if (shl_findsym(&gLib, "/tmp/plugin.so", (short) TYPE_PROCEDURE, (void *) &gNP_GetValue))
+                   gNP_GetValue = NULL;
+#else
 		gLib = dlopen( "/tmp/plugin.so", RTLD_NOW );
 		DEB( ef, "gLib = %x\n", gLib );
-		
+
 		gNP_GetMIMEDescription = dlsym( gLib, "NP_GetMIMEDescription" );
 		gNP_Initialize = dlsym( gLib, "NP_Initialize" );
 		gNP_Shutdown = dlsym( gLib, "NP_Shutdown" );
 		gNP_GetValue = dlsym( gLib, "NP_GetValue" );
-		
+#endif
 		DEB( ef, "gNP_GetMIMEDescription = %x\n", NP_GetMIMEDescription );
 		DEB( ef, "gNP_Initialize = %x\n", gNP_Initialize );
 		DEB( ef, "gNP_Shutdown = %x\n", gNP_Shutdown );
@@ -239,16 +270,18 @@ void MyNPP_URLNotify(NPP instance, const char* url,
 	DEB(ef, "<- NPP_URLNotify\n");	
 }
 
-/*static
+#if 0
+static
 jref MyNPP_GetJavaClass(void)
 {
   jref ret;
 	DEB(ef, "-> NPP_GetJavaClass( )\n" );	
 	
-//	ret = gPluginFuncs.javaClass( );		
+/*	ret = gPluginFuncs.javaClass( );*/
 	DEB(ef, "<- NPP_GetJavaClass = %d\n", ret);
 	return ret;
-} */
+}
+#endif
 
 static
 NPError MyNPP_GetValue(void *instance, NPPVariable variable, void *value)
@@ -583,7 +616,7 @@ NPError NP_Initialize(NPNetscapeFuncs* nsTable, NPPluginFuncs* pluginFuncs)
 	err = gNP_Initialize( &gExtNetscapeFuncs, &gPluginFuncs );
 	
 	if (!err) {	
-		//memcpy(&pluginFuncs, gPluginFuncs, sizeof(gPluginFuncs));		
+		/*memcpy(&pluginFuncs, gPluginFuncs, sizeof(gPluginFuncs));*/
 				
 		/*pluginFuncs->initialize = MyNPP_Initialize;
 		pluginFuncs->shutdown = MyNPP_Shutdown;*/
@@ -598,7 +631,7 @@ NPError NP_Initialize(NPNetscapeFuncs* nsTable, NPPluginFuncs* pluginFuncs)
 		pluginFuncs->print = MyNPP_Print;
 		pluginFuncs->event = MyNPP_HandleEvent;
 		pluginFuncs->urlnotify = MyNPP_URLNotify;
-		pluginFuncs->javaClass = 0; //MyNPP_GetJavaClass;
+		pluginFuncs->javaClass = 0; /* MyNPP_GetJavaClass; */
 		pluginFuncs->getvalue = (NPP_GetValueUPP)MyNPP_GetValue;
 		pluginFuncs->setvalue = (NPP_SetValueUPP)MyNPP_SetValue;
 	
